@@ -8,11 +8,12 @@ from typing import TYPE_CHECKING, Any, ClassVar, TypedDict
 from typing_extensions import NotRequired
 
 from sqlspec.adapters.adbc._types import AdbcConnection
-from sqlspec.adapters.adbc.driver import AdbcCursor, AdbcDriver, get_adbc_statement_config
-from sqlspec.config import NoPoolSyncConfig
-from sqlspec.core.statement import StatementConfig
+from sqlspec.adapters.adbc.driver import AdbcCursor, AdbcDriver, AdbcExceptionHandler, get_adbc_statement_config
+from sqlspec.config import ExtensionConfigs, NoPoolSyncConfig
+from sqlspec.core import StatementConfig
 from sqlspec.exceptions import ImproperConfigurationError
 from sqlspec.utils.module_loader import import_string
+from sqlspec.utils.serializers import to_json
 
 if TYPE_CHECKING:
     from collections.abc import Generator
@@ -20,6 +21,8 @@ if TYPE_CHECKING:
 
     from sqlglot.dialects.dialect import DialectType
 
+    from sqlspec.observability import ObservabilityConfig
+
 logger = logging.getLogger("sqlspec.adapters.adbc")
 
 
@@ -101,6 +104,11 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
     driver_type: ClassVar[type[AdbcDriver]] = AdbcDriver
     connection_type: "ClassVar[type[AdbcConnection]]" = AdbcConnection
     supports_transactional_ddl: ClassVar[bool] = False
+    supports_native_arrow_export: "ClassVar[bool]" = True
+    supports_native_arrow_import: "ClassVar[bool]" = True
+    supports_native_parquet_export: "ClassVar[bool]" = True
+    supports_native_parquet_import: "ClassVar[bool]" = True
+    storage_partition_strategies: "ClassVar[tuple[str, ...]]" = ("fixed", "rows_per_chunk")
 
     def __init__(
         self,
@@ -110,7 +118,8 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
         statement_config: StatementConfig | None = None,
         driver_features: "AdbcDriverFeatures | dict[str, Any] | None" = None,
         bind_key: str | None = None,
-        extension_config: "dict[str, dict[str, Any]] | None" = None,
+        extension_config: "ExtensionConfigs | None" = None,
+        observability_config: "ObservabilityConfig | None" = None,
     ) -> None:
         """Initialize configuration.
 
@@ -121,6 +130,7 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
             driver_features: Driver feature configuration (AdbcDriverFeatures)
             bind_key: Optional unique identifier for this configuration
             extension_config: Extension-specific configuration (e.g., Litestar plugin settings)
+            observability_config: Adapter-level observability overrides for lifecycle hooks and observers
         """
         if connection_config is None:
             connection_config = {}
@@ -135,26 +145,34 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
             detected_dialect = str(self._get_dialect() or "sqlite")
             statement_config = get_adbc_statement_config(detected_dialect)
 
-        from sqlspec.utils.serializers import to_json
+        processed_driver_features: dict[str, Any] = dict(driver_features) if driver_features else {}
+        json_serializer = processed_driver_features.setdefault("json_serializer", to_json)
+        processed_driver_features.setdefault("enable_cast_detection", True)
+        processed_driver_features.setdefault("strict_type_coercion", False)
+        processed_driver_features.setdefault("arrow_extension_types", True)
 
-        if driver_features is None:
-            driver_features = {}
-        if "json_serializer" not in driver_features:
-            driver_features["json_serializer"] = to_json
-        if "enable_cast_detection" not in driver_features:
-            driver_features["enable_cast_detection"] = True
-        if "strict_type_coercion" not in driver_features:
-            driver_features["strict_type_coercion"] = False
-        if "arrow_extension_types" not in driver_features:
-            driver_features["arrow_extension_types"] = True
+        if json_serializer is not None:
+            parameter_config = statement_config.parameter_config
+            previous_list_converter = parameter_config.type_coercion_map.get(list)
+            previous_tuple_converter = parameter_config.type_coercion_map.get(tuple)
+            updated_parameter_config = parameter_config.with_json_serializers(json_serializer)
+            updated_map = dict(updated_parameter_config.type_coercion_map)
+            if previous_list_converter is not None:
+                updated_map[list] = previous_list_converter
+            if previous_tuple_converter is not None:
+                updated_map[tuple] = previous_tuple_converter
+            statement_config = statement_config.replace(
+                parameter_config=updated_parameter_config.replace(type_coercion_map=updated_map)
+            )
 
         super().__init__(
             connection_config=self.connection_config,
             migration_config=migration_config,
             statement_config=statement_config,
-            driver_features=dict(driver_features),
+            driver_features=processed_driver_features,
             bind_key=bind_key,
             extension_config=extension_config,
+            observability_config=observability_config,
         )
 
     def _resolve_driver_name(self) -> str:
@@ -353,9 +371,10 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
                     or self.statement_config
                     or get_adbc_statement_config(str(self._get_dialect() or "sqlite"))
                 )
-                yield self.driver_type(
+                driver = self.driver_type(
                     connection=connection, statement_config=final_statement_config, driver_features=self.driver_features
                 )
+                yield self._prepare_driver(driver)
 
         return session_manager()
 
@@ -400,13 +419,18 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
 
         return config
 
-    def get_signature_namespace(self) -> "dict[str, type[Any]]":
+    def get_signature_namespace(self) -> "dict[str, Any]":
         """Get the signature namespace for types.
 
         Returns:
             Dictionary mapping type names to types.
         """
-
         namespace = super().get_signature_namespace()
-        namespace.update({"AdbcConnection": AdbcConnection, "AdbcCursor": AdbcCursor})
+        namespace.update({
+            "AdbcConnection": AdbcConnection,
+            "AdbcConnectionParams": AdbcConnectionParams,
+            "AdbcCursor": AdbcCursor,
+            "AdbcDriver": AdbcDriver,
+            "AdbcExceptionHandler": AdbcExceptionHandler,
+        })
         return namespace
