@@ -8,7 +8,7 @@ MySQL, BigQuery, Snowflake).
 from functools import lru_cache
 from typing import Any, Final
 
-from sqlspec.core.type_conversion import BaseTypeConverter
+from sqlspec.core import BaseTypeConverter
 from sqlspec.utils.serializers import to_json
 
 ADBC_SPECIAL_CHARS: Final[frozenset[str]] = frozenset({"{", "[", "-", ":", "T", "."})
