@@ -7,20 +7,27 @@ from typing import TYPE_CHECKING, Any, ClassVar, TypedDict
 from typing_extensions import NotRequired
 
 from sqlspec.adapters.aiosqlite._types import AiosqliteConnection
-from sqlspec.adapters.aiosqlite.driver import AiosqliteCursor, AiosqliteDriver, aiosqlite_statement_config
+from sqlspec.adapters.aiosqlite.driver import (
+    AiosqliteCursor,
+    AiosqliteDriver,
+    AiosqliteExceptionHandler,
+    aiosqlite_statement_config,
+)
 from sqlspec.adapters.aiosqlite.pool import (
     AiosqliteConnectionPool,
     AiosqliteConnectTimeoutError,
     AiosqlitePoolClosedError,
     AiosqlitePoolConnection,
 )
-from sqlspec.config import AsyncDatabaseConfig
+from sqlspec.adapters.sqlite._type_handlers import register_type_handlers
+from sqlspec.config import AsyncDatabaseConfig, ExtensionConfigs
 from sqlspec.utils.serializers import from_json, to_json
 
 if TYPE_CHECKING:
     from collections.abc import AsyncGenerator, Callable
 
-    from sqlspec.core.statement import StatementConfig
+    from sqlspec.core import StatementConfig
+    from sqlspec.observability import ObservabilityConfig
 
 __all__ = ("AiosqliteConfig", "AiosqliteConnectionParams", "AiosqliteDriverFeatures", "AiosqlitePoolParams")
 
@@ -74,6 +81,10 @@ class AiosqliteConfig(AsyncDatabaseConfig["AiosqliteConnection", AiosqliteConnec
     driver_type: "ClassVar[type[AiosqliteDriver]]" = AiosqliteDriver
     connection_type: "ClassVar[type[AiosqliteConnection]]" = AiosqliteConnection
     supports_transactional_ddl: "ClassVar[bool]" = True
+    supports_native_arrow_export: "ClassVar[bool]" = True
+    supports_native_arrow_import: "ClassVar[bool]" = True
+    supports_native_parquet_export: "ClassVar[bool]" = True
+    supports_native_parquet_import: "ClassVar[bool]" = True
 
     def __init__(
         self,
@@ -84,7 +95,8 @@ class AiosqliteConfig(AsyncDatabaseConfig["AiosqliteConnection", AiosqliteConnec
         statement_config: "StatementConfig | None" = None,
         driver_features: "AiosqliteDriverFeatures | dict[str, Any] | None" = None,
         bind_key: "str | None" = None,
-        extension_config: "dict[str, dict[str, Any]] | None" = None,
+        extension_config: "ExtensionConfigs | None" = None,
+        observability_config: "ObservabilityConfig | None" = None,
     ) -> None:
         """Initialize AioSQLite configuration.
 
@@ -96,6 +108,7 @@ class AiosqliteConfig(AsyncDatabaseConfig["AiosqliteConnection", AiosqliteConnec
             driver_features: Optional driver feature configuration.
             bind_key: Optional unique identifier for this configuration.
             extension_config: Extension-specific configuration (e.g., Litestar plugin settings)
+            observability_config: Adapter-level observability overrides for lifecycle hooks and observers
         """
         config_dict = dict(pool_config) if pool_config else {}
 
@@ -113,24 +126,26 @@ class AiosqliteConfig(AsyncDatabaseConfig["AiosqliteConnection", AiosqliteConnec
                 config_dict["uri"] = True
 
         processed_driver_features: dict[str, Any] = dict(driver_features) if driver_features else {}
+        processed_driver_features.setdefault("enable_custom_adapters", True)
+        json_serializer = processed_driver_features.setdefault("json_serializer", to_json)
+        json_deserializer = processed_driver_features.setdefault("json_deserializer", from_json)
 
-        if "enable_custom_adapters" not in processed_driver_features:
-            processed_driver_features["enable_custom_adapters"] = True
-
-        if "json_serializer" not in processed_driver_features:
-            processed_driver_features["json_serializer"] = to_json
-
-        if "json_deserializer" not in processed_driver_features:
-            processed_driver_features["json_deserializer"] = from_json
+        base_statement_config = statement_config or aiosqlite_statement_config
+        if json_serializer is not None:
+            parameter_config = base_statement_config.parameter_config.with_json_serializers(
+                json_serializer, deserializer=json_deserializer
+            )
+            base_statement_config = base_statement_config.replace(parameter_config=parameter_config)
 
         super().__init__(
             pool_config=config_dict,
             pool_instance=pool_instance,
             migration_config=migration_config,
-            statement_config=statement_config or aiosqlite_statement_config,
+            statement_config=base_statement_config,
             driver_features=processed_driver_features,
             bind_key=bind_key,
             extension_config=extension_config,
+            observability_config=observability_config,
         )
 
     def _get_pool_config_dict(self) -> "dict[str, Any]":
@@ -195,11 +210,12 @@ class AiosqliteConfig(AsyncDatabaseConfig["AiosqliteConnection", AiosqliteConnec
             An AiosqliteDriver instance.
         """
         async with self.provide_connection(*_args, **_kwargs) as connection:
-            yield self.driver_type(
+            driver = self.driver_type(
                 connection=connection,
                 statement_config=statement_config or self.statement_config,
                 driver_features=self.driver_features,
             )
+            yield self._prepare_driver(driver)
 
     async def _create_pool(self) -> AiosqliteConnectionPool:
         """Create the connection pool instance.
@@ -236,8 +252,6 @@ class AiosqliteConfig(AsyncDatabaseConfig["AiosqliteConnection", AiosqliteConnec
         sync adapter, so this shares the implementation.
         """
         if self.driver_features.get("enable_custom_adapters", False):
-            from sqlspec.adapters.sqlite._type_handlers import register_type_handlers
-
             register_type_handlers(
                 json_serializer=self.driver_features.get("json_serializer"),
                 json_deserializer=self.driver_features.get("json_deserializer"),
@@ -269,23 +283,26 @@ class AiosqliteConfig(AsyncDatabaseConfig["AiosqliteConnection", AiosqliteConnec
             self.pool_instance = await self.create_pool()
         return self.pool_instance
 
-    def get_signature_namespace(self) -> "dict[str, type[Any]]":
+    def get_signature_namespace(self) -> "dict[str, Any]":
         """Get the signature namespace for aiosqlite types.
 
         Returns:
             Dictionary mapping type names to types.
         """
         namespace = super().get_signature_namespace()
-        namespace.update(
-            {
-                "AiosqliteConnection": AiosqliteConnection,
-                "AiosqliteConnectionPool": AiosqliteConnectionPool,
-                "AiosqliteConnectTimeoutError": AiosqliteConnectTimeoutError,
-                "AiosqliteCursor": AiosqliteCursor,
-                "AiosqlitePoolClosedError": AiosqlitePoolClosedError,
-                "AiosqlitePoolConnection": AiosqlitePoolConnection,
-            }
-        )
+        namespace.update({
+            "AiosqliteConnection": AiosqliteConnection,
+            "AiosqliteConnectionParams": AiosqliteConnectionParams,
+            "AiosqliteConnectionPool": AiosqliteConnectionPool,
+            "AiosqliteConnectTimeoutError": AiosqliteConnectTimeoutError,
+            "AiosqliteCursor": AiosqliteCursor,
+            "AiosqliteDriver": AiosqliteDriver,
+            "AiosqliteDriverFeatures": AiosqliteDriverFeatures,
+            "AiosqliteExceptionHandler": AiosqliteExceptionHandler,
+            "AiosqlitePoolClosedError": AiosqlitePoolClosedError,
+            "AiosqlitePoolConnection": AiosqlitePoolConnection,
+            "AiosqlitePoolParams": AiosqlitePoolParams,
+        })
         return namespace
 
     async def _close_pool(self) -> None:
