@@ -1,5 +1,10 @@
 from sqlspec.adapters.asyncmy._types import AsyncmyConnection
-from sqlspec.adapters.asyncmy.config import AsyncmyConfig, AsyncmyConnectionParams, AsyncmyPoolParams
+from sqlspec.adapters.asyncmy.config import (
+    AsyncmyConfig,
+    AsyncmyConnectionParams,
+    AsyncmyDriverFeatures,
+    AsyncmyPoolParams,
+)
 from sqlspec.adapters.asyncmy.driver import (
     AsyncmyCursor,
     AsyncmyDriver,
@@ -13,6 +18,7 @@ __all__ = (
     "AsyncmyConnectionParams",
     "AsyncmyCursor",
     "AsyncmyDriver",
+    "AsyncmyDriverFeatures",
     "AsyncmyExceptionHandler",
     "AsyncmyPoolParams",
     "asyncmy_statement_config",
