@@ -3,7 +3,7 @@ from typing import TYPE_CHECKING
 from asyncmy import Connection  # pyright: ignore
 
 if TYPE_CHECKING:
-    from typing_extensions import TypeAlias
+    from typing import TypeAlias
 
     AsyncmyConnection: TypeAlias = Connection
 else:
