@@ -11,8 +11,14 @@ from asyncmy.pool import Pool as AsyncmyPool  # pyright: ignore
 from typing_extensions import NotRequired
 
 from sqlspec.adapters.asyncmy._types import AsyncmyConnection
-from sqlspec.adapters.asyncmy.driver import AsyncmyCursor, AsyncmyDriver, asyncmy_statement_config
-from sqlspec.config import AsyncDatabaseConfig
+from sqlspec.adapters.asyncmy.driver import (
+    AsyncmyCursor,
+    AsyncmyDriver,
+    AsyncmyExceptionHandler,
+    asyncmy_statement_config,
+    build_asyncmy_statement_config,
+)
+from sqlspec.config import AsyncDatabaseConfig, ExtensionConfigs
 from sqlspec.utils.serializers import from_json, to_json
 
 if TYPE_CHECKING:
@@ -21,7 +27,8 @@ if TYPE_CHECKING:
     from asyncmy.cursors import Cursor, DictCursor  # pyright: ignore
     from asyncmy.pool import Pool  # pyright: ignore
 
-    from sqlspec.core.statement import StatementConfig
+    from sqlspec.core import StatementConfig
+    from sqlspec.observability import ObservabilityConfig
 
 
 __all__ = ("AsyncmyConfig", "AsyncmyConnectionParams", "AsyncmyDriverFeatures", "AsyncmyPoolParams")
@@ -84,6 +91,10 @@ class AsyncmyConfig(AsyncDatabaseConfig[AsyncmyConnection, "AsyncmyPool", Asyncm
     driver_type: ClassVar[type[AsyncmyDriver]] = AsyncmyDriver
     connection_type: "ClassVar[type[AsyncmyConnection]]" = AsyncmyConnection  # pyright: ignore
     supports_transactional_ddl: ClassVar[bool] = False
+    supports_native_arrow_export: ClassVar[bool] = True
+    supports_native_parquet_export: ClassVar[bool] = True
+    supports_native_arrow_import: ClassVar[bool] = True
+    supports_native_parquet_import: ClassVar[bool] = True
 
     def __init__(
         self,
@@ -94,7 +105,8 @@ class AsyncmyConfig(AsyncDatabaseConfig[AsyncmyConnection, "AsyncmyPool", Asyncm
         statement_config: "StatementConfig | None" = None,
         driver_features: "AsyncmyDriverFeatures | dict[str, Any] | None" = None,
         bind_key: "str | None" = None,
-        extension_config: "dict[str, dict[str, Any]] | None" = None,
+        extension_config: "ExtensionConfigs | None" = None,
+        observability_config: "ObservabilityConfig | None" = None,
     ) -> None:
         """Initialize Asyncmy configuration.
 
@@ -106,35 +118,33 @@ class AsyncmyConfig(AsyncDatabaseConfig[AsyncmyConnection, "AsyncmyPool", Asyncm
             driver_features: Driver feature configuration (TypedDict or dict)
             bind_key: Optional unique identifier for this configuration
             extension_config: Extension-specific configuration (e.g., Litestar plugin settings)
+            observability_config: Adapter-level observability overrides for lifecycle hooks and observers
         """
         processed_pool_config: dict[str, Any] = dict(pool_config) if pool_config else {}
         if "extra" in processed_pool_config:
             extras = processed_pool_config.pop("extra")
             processed_pool_config.update(extras)
 
-        if "host" not in processed_pool_config:
-            processed_pool_config["host"] = "localhost"
-        if "port" not in processed_pool_config:
-            processed_pool_config["port"] = 3306
-
-        if statement_config is None:
-            statement_config = asyncmy_statement_config
+        processed_pool_config.setdefault("host", "localhost")
+        processed_pool_config.setdefault("port", 3306)
 
         processed_driver_features: dict[str, Any] = dict(driver_features) if driver_features else {}
+        serializer = processed_driver_features.setdefault("json_serializer", to_json)
+        deserializer = processed_driver_features.setdefault("json_deserializer", from_json)
 
-        if "json_serializer" not in processed_driver_features:
-            processed_driver_features["json_serializer"] = to_json
-        if "json_deserializer" not in processed_driver_features:
-            processed_driver_features["json_deserializer"] = from_json
+        base_statement_config = statement_config or build_asyncmy_statement_config(
+            json_serializer=serializer, json_deserializer=deserializer
+        )
 
         super().__init__(
             pool_config=processed_pool_config,
             pool_instance=pool_instance,
             migration_config=migration_config,
-            statement_config=statement_config,
+            statement_config=base_statement_config,
             driver_features=processed_driver_features,
             bind_key=bind_key,
             extension_config=extension_config,
+            observability_config=observability_config,
         )
 
     async def _create_pool(self) -> "AsyncmyPool":  # pyright: ignore
@@ -200,9 +210,10 @@ class AsyncmyConfig(AsyncDatabaseConfig[AsyncmyConnection, "AsyncmyPool", Asyncm
         """
         async with self.provide_connection(*args, **kwargs) as connection:
             final_statement_config = statement_config or self.statement_config or asyncmy_statement_config
-            yield self.driver_type(
+            driver = self.driver_type(
                 connection=connection, statement_config=final_statement_config, driver_features=self.driver_features
             )
+            yield self._prepare_driver(driver)
 
     async def provide_pool(self, *args: Any, **kwargs: Any) -> "Pool":  # pyright: ignore
         """Provide async pool instance.
@@ -214,7 +225,7 @@ class AsyncmyConfig(AsyncDatabaseConfig[AsyncmyConnection, "AsyncmyPool", Asyncm
             self.pool_instance = await self.create_pool()
         return self.pool_instance
 
-    def get_signature_namespace(self) -> "dict[str, type[Any]]":
+    def get_signature_namespace(self) -> "dict[str, Any]":
         """Get the signature namespace for Asyncmy types.
 
         Returns:
@@ -222,7 +233,14 @@ class AsyncmyConfig(AsyncDatabaseConfig[AsyncmyConnection, "AsyncmyPool", Asyncm
         """
 
         namespace = super().get_signature_namespace()
-        namespace.update(
-            {"AsyncmyConnection": AsyncmyConnection, "AsyncmyPool": AsyncmyPool, "AsyncmyCursor": AsyncmyCursor}
-        )
+        namespace.update({
+            "AsyncmyConnection": AsyncmyConnection,
+            "AsyncmyConnectionParams": AsyncmyConnectionParams,
+            "AsyncmyCursor": AsyncmyCursor,
+            "AsyncmyDriver": AsyncmyDriver,
+            "AsyncmyDriverFeatures": AsyncmyDriverFeatures,
+            "AsyncmyExceptionHandler": AsyncmyExceptionHandler,
+            "AsyncmyPool": AsyncmyPool,
+            "AsyncmyPoolParams": AsyncmyPoolParams,
+        })
         return namespace
