@@ -5,15 +5,20 @@ type coercion, error handling, and transaction management.
 """
 
 import logging
-from typing import TYPE_CHECKING, Any, Final
+from typing import TYPE_CHECKING, Any, Final, cast
 
 import asyncmy.errors  # pyright: ignore
 from asyncmy.constants import FIELD_TYPE as ASYNC_MY_FIELD_TYPE  # pyright: ignore
 from asyncmy.cursors import Cursor, DictCursor  # pyright: ignore
 
-from sqlspec.core.cache import get_cache_config
-from sqlspec.core.parameters import ParameterStyle, ParameterStyleConfig
-from sqlspec.core.statement import StatementConfig
+from sqlspec.core import (
+    ArrowResult,
+    DriverParameterProfile,
+    ParameterStyle,
+    build_statement_config_from_profile,
+    get_cache_config,
+    register_driver_profile,
+)
 from sqlspec.driver import AsyncDriverAdapterBase
 from sqlspec.exceptions import (
     CheckViolationError,
@@ -27,18 +32,30 @@ from sqlspec.exceptions import (
     TransactionError,
     UniqueViolationError,
 )
-from sqlspec.utils.serializers import to_json
+from sqlspec.utils.serializers import from_json, to_json
 
 if TYPE_CHECKING:
     from collections.abc import Callable
     from contextlib import AbstractAsyncContextManager
 
     from sqlspec.adapters.asyncmy._types import AsyncmyConnection
-    from sqlspec.core.result import SQLResult
-    from sqlspec.core.statement import SQL
+    from sqlspec.core import SQL, SQLResult, StatementConfig
     from sqlspec.driver import ExecutionResult
     from sqlspec.driver._async import AsyncDataDictionaryBase
-__all__ = ("AsyncmyCursor", "AsyncmyDriver", "AsyncmyExceptionHandler", "asyncmy_statement_config")
+    from sqlspec.storage import (
+        AsyncStoragePipeline,
+        StorageBridgeJob,
+        StorageDestination,
+        StorageFormat,
+        StorageTelemetry,
+    )
+__all__ = (
+    "AsyncmyCursor",
+    "AsyncmyDriver",
+    "AsyncmyExceptionHandler",
+    "asyncmy_statement_config",
+    "build_asyncmy_statement_config",
+)
 
 logger = logging.getLogger(__name__)
 
@@ -50,24 +67,6 @@ MYSQL_ER_DUP_ENTRY = 1062
 MYSQL_ER_NO_DEFAULT_FOR_FIELD = 1364
 MYSQL_ER_CHECK_CONSTRAINT_VIOLATED = 3819
 
-asyncmy_statement_config = StatementConfig(
-    dialect="mysql",
-    parameter_config=ParameterStyleConfig(
-        default_parameter_style=ParameterStyle.QMARK,
-        supported_parameter_styles={ParameterStyle.QMARK, ParameterStyle.POSITIONAL_PYFORMAT},
-        default_execution_parameter_style=ParameterStyle.POSITIONAL_PYFORMAT,
-        supported_execution_parameter_styles={ParameterStyle.POSITIONAL_PYFORMAT},
-        type_coercion_map={dict: to_json, list: to_json, tuple: lambda v: to_json(list(v)), bool: int},
-        has_native_list_expansion=False,
-        needs_static_script_compilation=True,
-        preserve_parameter_format=True,
-    ),
-    enable_parsing=True,
-    enable_validation=True,
-    enable_caching=True,
-    enable_parameter_type_wrapping=True,
-)
-
 
 class AsyncmyCursor:
     """Context manager for AsyncMy cursor operations.
@@ -243,82 +242,11 @@ class AsyncmyDriver(AsyncDriverAdapterBase):
                 dialect="mysql",
             )
 
-        final_statement_config = self._apply_json_serializer_feature(final_statement_config, driver_features)
-
         super().__init__(
             connection=connection, statement_config=final_statement_config, driver_features=driver_features
         )
         self._data_dictionary: AsyncDataDictionaryBase | None = None
 
-    @staticmethod
-    def _clone_parameter_config(
-        parameter_config: ParameterStyleConfig, type_coercion_map: "dict[type[Any], Callable[[Any], Any]]"
-    ) -> ParameterStyleConfig:
-        """Create a copy of the parameter configuration with updated coercion map.
-
-        Args:
-            parameter_config: Existing parameter configuration to copy.
-            type_coercion_map: Updated coercion mapping for parameter serialization.
-
-        Returns:
-            ParameterStyleConfig with the updated type coercion map applied.
-        """
-
-        supported_execution_styles = (
-            set(parameter_config.supported_execution_parameter_styles)
-            if parameter_config.supported_execution_parameter_styles is not None
-            else None
-        )
-
-        return ParameterStyleConfig(
-            default_parameter_style=parameter_config.default_parameter_style,
-            supported_parameter_styles=set(parameter_config.supported_parameter_styles),
-            supported_execution_parameter_styles=supported_execution_styles,
-            default_execution_parameter_style=parameter_config.default_execution_parameter_style,
-            type_coercion_map=type_coercion_map,
-            has_native_list_expansion=parameter_config.has_native_list_expansion,
-            needs_static_script_compilation=parameter_config.needs_static_script_compilation,
-            allow_mixed_parameter_styles=parameter_config.allow_mixed_parameter_styles,
-            preserve_parameter_format=parameter_config.preserve_parameter_format,
-            preserve_original_params_for_many=parameter_config.preserve_original_params_for_many,
-            output_transformer=parameter_config.output_transformer,
-            ast_transformer=parameter_config.ast_transformer,
-        )
-
-    @staticmethod
-    def _apply_json_serializer_feature(
-        statement_config: "StatementConfig", driver_features: "dict[str, Any] | None"
-    ) -> "StatementConfig":
-        """Apply driver-level JSON serializer customization to the statement config.
-
-        Args:
-            statement_config: Base statement configuration for the driver.
-            driver_features: Driver feature mapping provided via configuration.
-
-        Returns:
-            StatementConfig with serializer adjustments applied when configured.
-        """
-
-        if not driver_features:
-            return statement_config
-
-        serializer = driver_features.get("json_serializer")
-        if serializer is None:
-            return statement_config
-
-        parameter_config = statement_config.parameter_config
-        type_coercion_map = dict(parameter_config.type_coercion_map)
-
-        def serialize_tuple(value: Any) -> Any:
-            return serializer(list(value))
-
-        type_coercion_map[dict] = serializer
-        type_coercion_map[list] = serializer
-        type_coercion_map[tuple] = serialize_tuple
-
-        updated_parameter_config = AsyncmyDriver._clone_parameter_config(parameter_config, type_coercion_map)
-        return statement_config.replace(parameter_config=updated_parameter_config)
-
     def with_cursor(self, connection: "AsyncmyConnection") -> "AsyncmyCursor":
         """Create cursor context manager for the connection.
 
@@ -512,6 +440,72 @@ class AsyncmyDriver(AsyncDriverAdapterBase):
         last_id = getattr(cursor, "lastrowid", None) if cursor.rowcount and cursor.rowcount > 0 else None
         return self.create_execution_result(cursor, rowcount_override=affected_rows, last_inserted_id=last_id)
 
+    async def select_to_storage(
+        self,
+        statement: "SQL | str",
+        destination: "StorageDestination",
+        /,
+        *parameters: Any,
+        statement_config: "StatementConfig | None" = None,
+        partitioner: "dict[str, Any] | None" = None,
+        format_hint: "StorageFormat | None" = None,
+        telemetry: "StorageTelemetry | None" = None,
+        **kwargs: Any,
+    ) -> "StorageBridgeJob":
+        """Execute a query and stream Arrow-formatted results into storage."""
+
+        self._require_capability("arrow_export_enabled")
+        arrow_result = await self.select_to_arrow(statement, *parameters, statement_config=statement_config, **kwargs)
+        async_pipeline: AsyncStoragePipeline = cast("AsyncStoragePipeline", self._storage_pipeline())
+        telemetry_payload = await self._write_result_to_storage_async(
+            arrow_result, destination, format_hint=format_hint, pipeline=async_pipeline
+        )
+        self._attach_partition_telemetry(telemetry_payload, partitioner)
+        return self._create_storage_job(telemetry_payload, telemetry)
+
+    async def load_from_arrow(
+        self,
+        table: str,
+        source: "ArrowResult | Any",
+        *,
+        partitioner: "dict[str, Any] | None" = None,
+        overwrite: bool = False,
+        telemetry: "StorageTelemetry | None" = None,
+    ) -> "StorageBridgeJob":
+        """Load Arrow data into MySQL using batched inserts."""
+
+        self._require_capability("arrow_import_enabled")
+        arrow_table = self._coerce_arrow_table(source)
+        if overwrite:
+            await self._truncate_table_async(table)
+
+        columns, records = self._arrow_table_to_rows(arrow_table)
+        if records:
+            insert_sql = _build_asyncmy_insert_statement(table, columns)
+            async with self.handle_database_exceptions(), self.with_cursor(self.connection) as cursor:
+                await cursor.executemany(insert_sql, records)
+
+        telemetry_payload = self._build_ingest_telemetry(arrow_table)
+        telemetry_payload["destination"] = table
+        self._attach_partition_telemetry(telemetry_payload, partitioner)
+        return self._create_storage_job(telemetry_payload, telemetry)
+
+    async def load_from_storage(
+        self,
+        table: str,
+        source: "StorageDestination",
+        *,
+        file_format: "StorageFormat",
+        partitioner: "dict[str, Any] | None" = None,
+        overwrite: bool = False,
+    ) -> "StorageBridgeJob":
+        """Load staged artifacts from storage into MySQL."""
+
+        arrow_table, inbound = await self._read_arrow_from_storage_async(source, file_format=file_format)
+        return await self.load_from_arrow(
+            table, arrow_table, partitioner=partitioner, overwrite=overwrite, telemetry=inbound
+        )
+
     async def begin(self) -> None:
         """Begin a database transaction.
 
@@ -551,6 +545,11 @@ class AsyncmyDriver(AsyncDriverAdapterBase):
             msg = f"Failed to commit MySQL transaction: {e}"
             raise SQLSpecError(msg) from e
 
+    async def _truncate_table_async(self, table: str) -> None:
+        statement = f"TRUNCATE TABLE {_format_mysql_identifier(table)}"
+        async with self.handle_database_exceptions(), self.with_cursor(self.connection) as cursor:
+            await cursor.execute(statement)
+
     @property
     def data_dictionary(self) -> "AsyncDataDictionaryBase":
         """Get the data dictionary for this driver.
@@ -563,3 +562,71 @@ class AsyncmyDriver(AsyncDriverAdapterBase):
 
             self._data_dictionary = MySQLAsyncDataDictionary()
         return self._data_dictionary
+
+
+def _bool_to_int(value: bool) -> int:
+    return int(value)
+
+
+def _quote_mysql_identifier(identifier: str) -> str:
+    normalized = identifier.replace("`", "``")
+    return f"`{normalized}`"
+
+
+def _format_mysql_identifier(identifier: str) -> str:
+    cleaned = identifier.strip()
+    if not cleaned:
+        msg = "Table name must not be empty"
+        raise SQLSpecError(msg)
+    parts = [part for part in cleaned.split(".") if part]
+    formatted = ".".join(_quote_mysql_identifier(part) for part in parts)
+    return formatted or _quote_mysql_identifier(cleaned)
+
+
+def _build_asyncmy_insert_statement(table: str, columns: "list[str]") -> str:
+    column_clause = ", ".join(_quote_mysql_identifier(column) for column in columns)
+    placeholders = ", ".join("%s" for _ in columns)
+    return f"INSERT INTO {_format_mysql_identifier(table)} ({column_clause}) VALUES ({placeholders})"
+
+
+def _build_asyncmy_profile() -> DriverParameterProfile:
+    """Create the AsyncMy driver parameter profile."""
+
+    return DriverParameterProfile(
+        name="AsyncMy",
+        default_style=ParameterStyle.QMARK,
+        supported_styles={ParameterStyle.QMARK, ParameterStyle.POSITIONAL_PYFORMAT},
+        default_execution_style=ParameterStyle.POSITIONAL_PYFORMAT,
+        supported_execution_styles={ParameterStyle.POSITIONAL_PYFORMAT},
+        has_native_list_expansion=False,
+        preserve_parameter_format=True,
+        needs_static_script_compilation=True,
+        allow_mixed_parameter_styles=False,
+        preserve_original_params_for_many=False,
+        json_serializer_strategy="helper",
+        custom_type_coercions={bool: _bool_to_int},
+        default_dialect="mysql",
+    )
+
+
+_ASYNCMY_PROFILE = _build_asyncmy_profile()
+
+register_driver_profile("asyncmy", _ASYNCMY_PROFILE)
+
+
+def build_asyncmy_statement_config(
+    *, json_serializer: "Callable[[Any], str] | None" = None, json_deserializer: "Callable[[str], Any] | None" = None
+) -> "StatementConfig":
+    """Construct the AsyncMy statement configuration with optional JSON codecs."""
+
+    serializer = json_serializer or to_json
+    deserializer = json_deserializer or from_json
+    return build_statement_config_from_profile(
+        _ASYNCMY_PROFILE,
+        statement_overrides={"dialect": "mysql"},
+        json_serializer=serializer,
+        json_deserializer=deserializer,
+    )
+
+
+asyncmy_statement_config = build_asyncmy_statement_config()
