@@ -1,6 +1,6 @@
 """AsyncPG adapter for SQLSpec."""
 
-from sqlspec.adapters.asyncpg._types import AsyncpgConnection, AsyncpgPool
+from sqlspec.adapters.asyncpg._types import AsyncpgConnection, AsyncpgPool, AsyncpgPreparedStatement
 from sqlspec.adapters.asyncpg.config import AsyncpgConfig, AsyncpgConnectionConfig, AsyncpgPoolConfig
 from sqlspec.adapters.asyncpg.driver import (
     AsyncpgCursor,
@@ -18,5 +18,6 @@ __all__ = (
     "AsyncpgExceptionHandler",
     "AsyncpgPool",
     "AsyncpgPoolConfig",
+    "AsyncpgPreparedStatement",
     "asyncpg_statement_config",
 )
