@@ -8,10 +8,17 @@ from google.cloud.bigquery import LoadJobConfig, QueryJobConfig
 from typing_extensions import NotRequired
 
 from sqlspec.adapters.bigquery._types import BigQueryConnection
-from sqlspec.adapters.bigquery.driver import BigQueryCursor, BigQueryDriver, bigquery_statement_config
-from sqlspec.config import NoPoolSyncConfig
+from sqlspec.adapters.bigquery.driver import (
+    BigQueryCursor,
+    BigQueryDriver,
+    BigQueryExceptionHandler,
+    build_bigquery_statement_config,
+)
+from sqlspec.config import ExtensionConfigs, NoPoolSyncConfig
 from sqlspec.exceptions import ImproperConfigurationError
+from sqlspec.observability import ObservabilityConfig
 from sqlspec.typing import Empty
+from sqlspec.utils.serializers import to_json
 
 if TYPE_CHECKING:
     from collections.abc import Callable, Generator
@@ -20,7 +27,7 @@ if TYPE_CHECKING:
     from google.api_core.client_options import ClientOptions
     from google.auth.credentials import Credentials
 
-    from sqlspec.core.statement import StatementConfig
+    from sqlspec.core import StatementConfig
 
 
 logger = logging.getLogger(__name__)
@@ -100,6 +107,11 @@ class BigQueryConfig(NoPoolSyncConfig[BigQueryConnection, BigQueryDriver]):
     driver_type: ClassVar[type[BigQueryDriver]] = BigQueryDriver
     connection_type: "ClassVar[type[BigQueryConnection]]" = BigQueryConnection
     supports_transactional_ddl: ClassVar[bool] = False
+    supports_native_parquet_import: ClassVar[bool] = True
+    supports_native_arrow_export: ClassVar[bool] = True
+    supports_native_parquet_export: ClassVar[bool] = True
+    requires_staging_for_load: ClassVar[bool] = True
+    staging_protocols: ClassVar[tuple[str, ...]] = ("gs://",)
 
     def __init__(
         self,
@@ -109,7 +121,8 @@ class BigQueryConfig(NoPoolSyncConfig[BigQueryConnection, BigQueryDriver]):
         statement_config: "StatementConfig | None" = None,
         driver_features: "BigQueryDriverFeatures | dict[str, Any] | None" = None,
         bind_key: "str | None" = None,
-        extension_config: "dict[str, dict[str, Any]] | None" = None,
+        extension_config: "ExtensionConfigs | None" = None,
+        observability_config: "ObservabilityConfig | None" = None,
     ) -> None:
         """Initialize BigQuery configuration.
 
@@ -120,6 +133,7 @@ class BigQueryConfig(NoPoolSyncConfig[BigQueryConnection, BigQueryDriver]):
             driver_features: BigQuery-specific driver features
             bind_key: Optional unique identifier for this configuration
             extension_config: Extension-specific configuration (e.g., Litestar plugin settings)
+            observability_config: Adapter-level observability overrides for lifecycle hooks and observers
         """
 
         self.connection_config: dict[str, Any] = dict(connection_config) if connection_config else {}
@@ -127,33 +141,42 @@ class BigQueryConfig(NoPoolSyncConfig[BigQueryConnection, BigQueryDriver]):
             extras = self.connection_config.pop("extra")
             self.connection_config.update(extras)
 
-        self.driver_features: dict[str, Any] = dict(driver_features) if driver_features else {}
+        processed_driver_features: dict[str, Any] = dict(driver_features) if driver_features else {}
+        user_connection_hook = processed_driver_features.pop("on_connection_create", None)
+        processed_driver_features.setdefault("enable_uuid_conversion", True)
+        serializer = processed_driver_features.setdefault("json_serializer", to_json)
 
-        if "enable_uuid_conversion" not in self.driver_features:
-            self.driver_features["enable_uuid_conversion"] = True
-
-        if "json_serializer" not in self.driver_features:
-            from sqlspec.utils.serializers import to_json
-
-            self.driver_features["json_serializer"] = to_json
-
-        self._connection_instance: BigQueryConnection | None = self.driver_features.get("connection_instance")
+        self._connection_instance: BigQueryConnection | None = processed_driver_features.get("connection_instance")
 
         if "default_query_job_config" not in self.connection_config:
             self._setup_default_job_config()
 
-        if statement_config is None:
-            statement_config = bigquery_statement_config
+        base_statement_config = statement_config or build_bigquery_statement_config(json_serializer=serializer)
+
+        local_observability = observability_config
+        if user_connection_hook is not None:
+
+            def _wrap_hook(context: dict[str, Any]) -> None:
+                connection = context.get("connection")
+                if connection is None:
+                    return
+                user_connection_hook(connection)
+
+            lifecycle_override = ObservabilityConfig(lifecycle={"on_connection_create": [_wrap_hook]})
+            local_observability = ObservabilityConfig.merge(local_observability, lifecycle_override)
 
         super().__init__(
             connection_config=self.connection_config,
             migration_config=migration_config,
-            statement_config=statement_config,
-            driver_features=self.driver_features,
+            statement_config=base_statement_config,
+            driver_features=processed_driver_features,
             bind_key=bind_key,
             extension_config=extension_config,
+            observability_config=local_observability,
         )
 
+        self.driver_features = processed_driver_features
+
     def _setup_default_job_config(self) -> None:
         """Set up default job configuration."""
 
@@ -213,10 +236,6 @@ class BigQueryConfig(NoPoolSyncConfig[BigQueryConnection, BigQueryDriver]):
             if default_load_job_config is not None:
                 self.driver_features["default_load_job_config"] = default_load_job_config
 
-            on_connection_create = self.driver_features.get("on_connection_create")
-            if on_connection_create:
-                on_connection_create(connection)
-
             self._connection_instance = connection
         except Exception as e:
             project = self.connection_config.get("project", "Unknown")
@@ -259,9 +278,9 @@ class BigQueryConfig(NoPoolSyncConfig[BigQueryConnection, BigQueryDriver]):
             driver = self.driver_type(
                 connection=connection, statement_config=final_statement_config, driver_features=self.driver_features
             )
-            yield driver
+            yield self._prepare_driver(driver)
 
-    def get_signature_namespace(self) -> "dict[str, type[Any]]":
+    def get_signature_namespace(self) -> "dict[str, Any]":
         """Get the signature namespace for BigQuery types.
 
         Returns:
@@ -269,5 +288,11 @@ class BigQueryConfig(NoPoolSyncConfig[BigQueryConnection, BigQueryDriver]):
         """
 
         namespace = super().get_signature_namespace()
-        namespace.update({"BigQueryConnection": BigQueryConnection, "BigQueryCursor": BigQueryCursor})
+        namespace.update({
+            "BigQueryConnection": BigQueryConnection,
+            "BigQueryConnectionParams": BigQueryConnectionParams,
+            "BigQueryCursor": BigQueryCursor,
+            "BigQueryDriver": BigQueryDriver,
+            "BigQueryExceptionHandler": BigQueryExceptionHandler,
+        })
         return namespace
