@@ -5,18 +5,30 @@ type coercion, error handling, and query job management.
 """
 
 import datetime
+import io
 import logging
+import os
+from collections.abc import Callable
 from decimal import Decimal
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, cast
 
 import sqlglot
-import sqlglot.expressions as exp
-from google.cloud.bigquery import ArrayQueryParameter, QueryJob, QueryJobConfig, ScalarQueryParameter
+from google.api_core.retry import Retry
+from google.cloud.bigquery import ArrayQueryParameter, LoadJobConfig, QueryJob, QueryJobConfig, ScalarQueryParameter
 from google.cloud.exceptions import GoogleCloudError
 
 from sqlspec.adapters.bigquery._types import BigQueryConnection
 from sqlspec.adapters.bigquery.type_converter import BigQueryTypeConverter
-from sqlspec.core import ParameterStyle, ParameterStyleConfig, StatementConfig, get_cache_config
+from sqlspec.core import (
+    DriverParameterProfile,
+    ParameterStyle,
+    StatementConfig,
+    build_literal_inlining_transform,
+    build_statement_config_from_profile,
+    create_arrow_result,
+    get_cache_config,
+    register_driver_profile,
+)
 from sqlspec.driver import ExecutionResult, SyncDriverAdapterBase
 from sqlspec.exceptions import (
     DatabaseConnectionError,
@@ -25,6 +37,7 @@ from sqlspec.exceptions import (
     OperationalError,
     SQLParsingError,
     SQLSpecError,
+    StorageCapabilityError,
     UniqueViolationError,
 )
 from sqlspec.utils.serializers import to_json
@@ -34,14 +47,26 @@ if TYPE_CHECKING:
     from contextlib import AbstractContextManager
 
     from sqlspec.builder import QueryBuilder
-    from sqlspec.core import SQL, SQLResult, Statement, StatementFilter
-    from sqlspec.core.result import ArrowResult
+    from sqlspec.core import SQL, ArrowResult, SQLResult, Statement, StatementFilter
     from sqlspec.driver import SyncDataDictionaryBase
-    from sqlspec.typing import StatementParameters
+    from sqlspec.storage import (
+        StorageBridgeJob,
+        StorageDestination,
+        StorageFormat,
+        StorageTelemetry,
+        SyncStoragePipeline,
+    )
+    from sqlspec.typing import ArrowReturnFormat, StatementParameters
 
 logger = logging.getLogger(__name__)
 
-__all__ = ("BigQueryCursor", "BigQueryDriver", "BigQueryExceptionHandler", "bigquery_statement_config")
+__all__ = (
+    "BigQueryCursor",
+    "BigQueryDriver",
+    "BigQueryExceptionHandler",
+    "bigquery_statement_config",
+    "build_bigquery_statement_config",
+)
 
 HTTP_CONFLICT = 409
 HTTP_NOT_FOUND = 404
@@ -50,7 +75,12 @@ HTTP_FORBIDDEN = 403
 HTTP_SERVER_ERROR = 500
 
 
-_default_type_converter = BigQueryTypeConverter()
+def _identity(value: Any) -> Any:
+    return value
+
+
+def _tuple_to_list(value: tuple[Any, ...]) -> list[Any]:
+    return list(value)
 
 
 _BQ_TYPE_MAP: dict[type, tuple[str, str | None]] = {
@@ -108,91 +138,6 @@ def _create_scalar_parameter(name: str, value: Any, param_type: str) -> ScalarQu
     return ScalarQueryParameter(name, param_type, value)
 
 
-def _create_literal_node(value: Any, json_serializer: "Callable[[Any], str]") -> "exp.Expression":
-    """Create a SQLGlot literal expression from a Python value.
-
-    Args:
-        value: Python value to convert to SQLGlot literal.
-        json_serializer: Function to serialize dict/list to JSON string.
-
-    Returns:
-        SQLGlot expression representing the literal value.
-    """
-    if value is None:
-        return exp.Null()
-    if isinstance(value, bool):
-        return exp.Boolean(this=value)
-    if isinstance(value, (int, float)):
-        return exp.Literal.number(str(value))
-    if isinstance(value, str):
-        return exp.Literal.string(value)
-    if isinstance(value, (list, tuple)):
-        items = [_create_literal_node(item, json_serializer) for item in value]
-        return exp.Array(expressions=items)
-    if isinstance(value, dict):
-        json_str = json_serializer(value)
-        return exp.Literal.string(json_str)
-
-    return exp.Literal.string(str(value))
-
-
-def _replace_placeholder_node(
-    node: "exp.Expression",
-    parameters: Any,
-    placeholder_counter: dict[str, int],
-    json_serializer: "Callable[[Any], str]",
-) -> "exp.Expression":
-    """Replace placeholder or parameter nodes with literal values.
-
-    Handles both positional placeholders (?) and named parameters (@name, :name).
-    Converts values to SQLGlot literal expressions for safe embedding in SQL.
-
-    Args:
-        node: SQLGlot expression node to check and potentially replace.
-        parameters: Parameter values (dict, list, or tuple).
-        placeholder_counter: Mutable counter dict for positional placeholders.
-        json_serializer: Function to serialize dict/list to JSON string.
-
-    Returns:
-        Literal expression if replacement made, otherwise original node.
-    """
-    if isinstance(node, exp.Placeholder):
-        if isinstance(parameters, (list, tuple)):
-            current_index = placeholder_counter["index"]
-            placeholder_counter["index"] += 1
-            if current_index < len(parameters):
-                return _create_literal_node(parameters[current_index], json_serializer)
-        return node
-
-    if isinstance(node, exp.Parameter):
-        param_name = str(node.this) if hasattr(node.this, "__str__") else node.this
-
-        if isinstance(parameters, dict):
-            possible_names = [param_name, f"@{param_name}", f":{param_name}", f"param_{param_name}"]
-            for name in possible_names:
-                if name in parameters:
-                    actual_value = getattr(parameters[name], "value", parameters[name])
-                    return _create_literal_node(actual_value, json_serializer)
-            return node
-
-        if isinstance(parameters, (list, tuple)):
-            try:
-                if param_name.startswith("param_"):
-                    param_index = int(param_name[6:])
-                    if param_index < len(parameters):
-                        return _create_literal_node(parameters[param_index], json_serializer)
-
-                if param_name.isdigit():
-                    param_index = int(param_name)
-                    if param_index < len(parameters):
-                        return _create_literal_node(parameters[param_index], json_serializer)
-            except (ValueError, IndexError, AttributeError):
-                pass
-        return node
-
-    return node
-
-
 def _get_bq_param_type(value: Any) -> tuple[str | None, str | None]:
     """Determine BigQuery parameter type from Python value.
 
@@ -280,60 +225,12 @@ def _create_bq_parameters(
                 raise SQLSpecError(msg)
 
     elif isinstance(parameters, (list, tuple)):
-        logger.warning("BigQuery received positional parameters instead of named parameters")
-        return []
+        msg = "BigQuery driver requires named parameters (e.g., @name); positional parameters are not supported"
+        raise SQLSpecError(msg)
 
     return bq_parameters
 
 
-def _get_bigquery_type_coercion_map(type_converter: BigQueryTypeConverter) -> dict[type, Any]:
-    """Get BigQuery type coercion map with configurable type converter.
-
-    Args:
-        type_converter: BigQuery type converter instance
-
-    Returns:
-        Type coercion map for BigQuery
-    """
-    return {
-        tuple: list,
-        bool: lambda x: x,
-        int: lambda x: x,
-        float: lambda x: x,
-        str: type_converter.convert_if_detected,
-        bytes: lambda x: x,
-        datetime.datetime: lambda x: x,
-        datetime.date: lambda x: x,
-        datetime.time: lambda x: x,
-        Decimal: lambda x: x,
-        dict: lambda x: x,
-        list: lambda x: x,
-        type(None): lambda _: None,
-    }
-
-
-bigquery_type_coercion_map = _get_bigquery_type_coercion_map(_default_type_converter)
-
-
-bigquery_statement_config = StatementConfig(
-    dialect="bigquery",
-    parameter_config=ParameterStyleConfig(
-        default_parameter_style=ParameterStyle.NAMED_AT,
-        supported_parameter_styles={ParameterStyle.NAMED_AT, ParameterStyle.QMARK},
-        default_execution_parameter_style=ParameterStyle.NAMED_AT,
-        supported_execution_parameter_styles={ParameterStyle.NAMED_AT},
-        type_coercion_map=bigquery_type_coercion_map,
-        has_native_list_expansion=True,
-        needs_static_script_compilation=False,
-        preserve_original_params_for_many=True,
-    ),
-    enable_parsing=True,
-    enable_validation=True,
-    enable_caching=True,
-    enable_parameter_type_wrapping=True,
-)
-
-
 class BigQueryCursor:
     """BigQuery cursor with resource management."""
 
@@ -457,7 +354,16 @@ class BigQueryDriver(SyncDriverAdapterBase):
     type coercion, error handling, and query job management.
     """
 
-    __slots__ = ("_data_dictionary", "_default_query_job_config", "_json_serializer", "_type_converter")
+    __slots__ = (
+        "_data_dictionary",
+        "_default_query_job_config",
+        "_job_retry",
+        "_job_retry_deadline",
+        "_json_serializer",
+        "_literal_inliner",
+        "_type_converter",
+        "_using_emulator",
+    )
     dialect = "bigquery"
 
     def __init__(
@@ -468,42 +374,26 @@ class BigQueryDriver(SyncDriverAdapterBase):
     ) -> None:
         features = driver_features or {}
 
-        json_serializer = features.get("json_serializer")
-        if json_serializer is None:
-            json_serializer = to_json
-
-        self._json_serializer: Callable[[Any], str] = json_serializer
-
         enable_uuid_conversion = features.get("enable_uuid_conversion", True)
         self._type_converter = BigQueryTypeConverter(enable_uuid_conversion=enable_uuid_conversion)
 
         if statement_config is None:
             cache_config = get_cache_config()
-            type_coercion_map = _get_bigquery_type_coercion_map(self._type_converter)
+            statement_config = bigquery_statement_config.replace(cache_config=cache_config)
 
-            param_config = ParameterStyleConfig(
-                default_parameter_style=ParameterStyle.NAMED_AT,
-                supported_parameter_styles={ParameterStyle.NAMED_AT, ParameterStyle.QMARK},
-                default_execution_parameter_style=ParameterStyle.NAMED_AT,
-                supported_execution_parameter_styles={ParameterStyle.NAMED_AT},
-                type_coercion_map=type_coercion_map,
-                has_native_list_expansion=True,
-                needs_static_script_compilation=False,
-                preserve_original_params_for_many=True,
-            )
+        parameter_json_serializer = statement_config.parameter_config.json_serializer
+        if parameter_json_serializer is None:
+            parameter_json_serializer = features.get("json_serializer", to_json)
 
-            statement_config = StatementConfig(
-                dialect="bigquery",
-                parameter_config=param_config,
-                enable_parsing=True,
-                enable_validation=True,
-                enable_caching=cache_config.compiled_cache_enabled,
-                enable_parameter_type_wrapping=True,
-            )
+        self._json_serializer: Callable[[Any], str] = parameter_json_serializer
+        self._literal_inliner = build_literal_inlining_transform(json_serializer=self._json_serializer)
 
         super().__init__(connection=connection, statement_config=statement_config, driver_features=driver_features)
         self._default_query_job_config: QueryJobConfig | None = (driver_features or {}).get("default_query_job_config")
         self._data_dictionary: SyncDataDictionaryBase | None = None
+        self._using_emulator = self._detect_emulator_endpoint(connection)
+        self._job_retry_deadline = float(features.get("job_retry_deadline", 60.0))
+        self._job_retry = None if self._using_emulator else self._build_job_retry()
 
     def with_cursor(self, connection: "BigQueryConnection") -> "BigQueryCursor":
         """Create context manager for cursor management.
@@ -526,6 +416,51 @@ class BigQueryDriver(SyncDriverAdapterBase):
         """Handle database-specific exceptions and wrap them appropriately."""
         return BigQueryExceptionHandler()
 
+    @staticmethod
+    def _detect_emulator_endpoint(connection: BigQueryConnection) -> bool:
+        """Detect whether the BigQuery client targets an emulator endpoint."""
+
+        emulator_host = os.getenv("BIGQUERY_EMULATOR_HOST") or os.getenv("BIGQUERY_EMULATOR_HOST_HTTP")
+        if emulator_host:
+            return True
+
+        api_base_url = getattr(getattr(connection, "_connection", None), "API_BASE_URL", "")
+        if not api_base_url:
+            return False
+        return "googleapis.com" not in api_base_url
+
+    def _build_job_retry(self) -> Retry:
+        """Build retry policy for job restarts based on error reason codes."""
+
+        return Retry(predicate=self._should_retry_job_exception, deadline=self._job_retry_deadline)
+
+    @staticmethod
+    def _should_retry_job_exception(exception: Exception) -> bool:
+        """Return True when a BigQuery job exception is safe to retry."""
+
+        if not isinstance(exception, GoogleCloudError):
+            return False
+
+        errors = getattr(exception, "errors", None) or []
+        retryable_reasons = {
+            "backendError",
+            "internalError",
+            "jobInternalError",
+            "rateLimitExceeded",
+            "jobRateLimitExceeded",
+        }
+
+        for err in errors:
+            if not isinstance(err, dict):
+                continue
+            reason = err.get("reason")
+            message = (err.get("message") or "").lower()
+            if reason in retryable_reasons:
+                # Emulator sometimes reports invalid DML as jobInternalError; guard with obvious syntax hints
+                return not ("nonexistent_column" in message or ("column" in message and "not present" in message))
+
+        return False
+
     def _should_copy_attribute(self, attr: str, source_config: QueryJobConfig) -> bool:
         """Check if attribute should be copied between job configs.
 
@@ -562,6 +497,37 @@ class BigQueryDriver(SyncDriverAdapterBase):
             except (AttributeError, TypeError):
                 continue
 
+    def _map_source_format(self, file_format: "StorageFormat") -> str:
+        if file_format == "parquet":
+            return "PARQUET"
+        if file_format in {"json", "jsonl"}:
+            return "NEWLINE_DELIMITED_JSON"
+        msg = f"BigQuery does not support loading '{file_format}' artifacts via the storage bridge"
+        raise StorageCapabilityError(msg, capability="parquet_import_enabled")
+
+    def _build_load_job_config(self, file_format: "StorageFormat", overwrite: bool) -> LoadJobConfig:
+        job_config = LoadJobConfig()
+        job_config.source_format = self._map_source_format(file_format)
+        job_config.write_disposition = "WRITE_TRUNCATE" if overwrite else "WRITE_APPEND"
+        return job_config
+
+    def _build_load_job_telemetry(self, job: QueryJob, table: str, *, format_label: str) -> "StorageTelemetry":
+        properties = getattr(job, "_properties", {})
+        load_stats = properties.get("statistics", {}).get("load", {})
+        rows_processed = int(load_stats.get("outputRows") or getattr(job, "output_rows", 0) or 0)
+        bytes_processed = int(load_stats.get("outputBytes") or load_stats.get("inputFileBytes", 0) or 0)
+        duration = 0.0
+        if job.ended and job.started:
+            duration = (job.ended - job.started).total_seconds()
+        telemetry: StorageTelemetry = {
+            "destination": table,
+            "rows_processed": rows_processed,
+            "bytes_processed": bytes_processed,
+            "duration_s": duration,
+            "format": format_label,
+        }
+        return telemetry
+
     def _run_query_job(
         self,
         sql_str: str,
@@ -623,34 +589,14 @@ class BigQueryDriver(SyncDriverAdapterBase):
         _ = (cursor, statement)
         return None
 
-    def _transform_ast_with_literals(self, sql: str, parameters: Any) -> str:
-        """Transform SQL AST by replacing placeholders with literal values.
+    def _inline_literals(self, expression: "sqlglot.Expression", parameters: Any) -> str:
+        """Inline literal values into a parsed SQLGlot expression."""
 
-        Used for BigQuery script execution and execute_many operations where
-        parameter binding is not supported. Safely embeds values as SQL literals.
-
-        Args:
-            sql: SQL string to transform.
-            parameters: Parameters to embed as literals.
-
-        Returns:
-            Transformed SQL string with literals embedded.
-        """
         if not parameters:
-            return sql
+            return expression.sql(dialect="bigquery")
 
-        try:
-            ast = sqlglot.parse_one(sql, dialect="bigquery")
-        except sqlglot.ParseError:
-            return sql
-
-        placeholder_counter = {"index": 0}
-
-        transformed_ast = ast.transform(
-            lambda node: _replace_placeholder_node(node, parameters, placeholder_counter, self._json_serializer)
-        )
-
-        return transformed_ast.sql(dialect="bigquery")
+        transformed_expression, _ = self._literal_inliner(expression, parameters)
+        return cast("str", transformed_expression.sql(dialect="bigquery"))
 
     def _execute_script(self, cursor: Any, statement: "SQL") -> ExecutionResult:
         """Execute SQL script with statement splitting and parameter handling.
@@ -672,7 +618,7 @@ class BigQueryDriver(SyncDriverAdapterBase):
 
         for stmt in statements:
             job = self._run_query_job(stmt, prepared_parameters or {}, connection=cursor)
-            job.result()
+            job.result(job_retry=self._job_retry)
             last_job = job
             successful_count += 1
 
@@ -704,15 +650,24 @@ class BigQueryDriver(SyncDriverAdapterBase):
 
         base_sql = statement.sql
 
+        try:
+            parsed_expression = sqlglot.parse_one(base_sql, dialect="bigquery")
+        except sqlglot.ParseError:
+            parsed_expression = None
+
         script_statements = []
         for param_set in parameters_list:
-            transformed_sql = self._transform_ast_with_literals(base_sql, param_set)
-            script_statements.append(transformed_sql)
+            if parsed_expression is None:
+                script_statements.append(base_sql)
+                continue
+
+            expression_copy = parsed_expression.copy()
+            script_statements.append(self._inline_literals(expression_copy, param_set))
 
         script_sql = ";\n".join(script_statements)
 
         cursor.job = self._run_query_job(script_sql, None, connection=cursor)
-        cursor.job.result()
+        cursor.job.result(job_retry=self._job_retry)
 
         affected_rows = (
             cursor.job.num_dml_affected_rows if cursor.job.num_dml_affected_rows is not None else len(parameters_list)
@@ -733,7 +688,7 @@ class BigQueryDriver(SyncDriverAdapterBase):
         cursor.job = self._run_query_job(sql, parameters, connection=cursor)
 
         if statement.returns_rows():
-            job_result = cursor.job.result()
+            job_result = cursor.job.result(job_retry=self._job_retry)
             rows_list = self._rows_to_results(iter(job_result))
             column_names = [field.name for field in cursor.job.schema] if cursor.job.schema else []
 
@@ -745,7 +700,7 @@ class BigQueryDriver(SyncDriverAdapterBase):
                 is_select_result=True,
             )
 
-        cursor.job.result()
+        cursor.job.result(job_retry=self._job_retry)
         affected_rows = cursor.job.num_dml_affected_rows or 0
         return self.create_execution_result(cursor, rowcount_override=affected_rows)
 
@@ -788,7 +743,7 @@ class BigQueryDriver(SyncDriverAdapterBase):
         /,
         *parameters: "StatementParameters | StatementFilter",
         statement_config: "StatementConfig | None" = None,
-        return_format: str = "table",
+        return_format: "ArrowReturnFormat" = "table",
         native_only: bool = False,
         batch_size: int | None = None,
         arrow_schema: Any = None,
@@ -815,7 +770,6 @@ class BigQueryDriver(SyncDriverAdapterBase):
 
         Raises:
             MissingDependencyError: If pyarrow not installed, or if Storage API not available and native_only=True
-            SQLExecutionError: If query execution fails
 
         Example:
             >>> # Will use native Arrow if Storage API available, otherwise converts
@@ -865,8 +819,6 @@ class BigQueryDriver(SyncDriverAdapterBase):
         # Use native path with Storage API
         import pyarrow as pa
 
-        from sqlspec.core.result import create_arrow_result
-
         # Prepare statement
         config = statement_config or self.statement_config
         prepared_statement = self.prepare_statement(statement, parameters, statement_config=config, kwargs=kwargs)
@@ -895,3 +847,128 @@ class BigQueryDriver(SyncDriverAdapterBase):
 
         # Create ArrowResult
         return create_arrow_result(statement=prepared_statement, data=arrow_data, rows_affected=arrow_data.num_rows)
+
+    def select_to_storage(
+        self,
+        statement: "Statement | QueryBuilder | SQL | str",
+        destination: "StorageDestination",
+        /,
+        *parameters: "StatementParameters | StatementFilter",
+        statement_config: "StatementConfig | None" = None,
+        partitioner: "dict[str, Any] | None" = None,
+        format_hint: "StorageFormat | None" = None,
+        telemetry: "StorageTelemetry | None" = None,
+        **kwargs: Any,
+    ) -> "StorageBridgeJob":
+        """Execute a query and persist Arrow results to a storage backend."""
+
+        self._require_capability("arrow_export_enabled")
+        arrow_result = self.select_to_arrow(statement, *parameters, statement_config=statement_config, **kwargs)
+        sync_pipeline: SyncStoragePipeline = cast("SyncStoragePipeline", self._storage_pipeline())
+        telemetry_payload = self._write_result_to_storage_sync(
+            arrow_result, destination, format_hint=format_hint, pipeline=sync_pipeline
+        )
+        self._attach_partition_telemetry(telemetry_payload, partitioner)
+        return self._create_storage_job(telemetry_payload, telemetry)
+
+    def load_from_arrow(
+        self,
+        table: str,
+        source: "ArrowResult | Any",
+        *,
+        partitioner: "dict[str, Any] | None" = None,
+        overwrite: bool = False,
+        telemetry: "StorageTelemetry | None" = None,
+    ) -> "StorageBridgeJob":
+        """Load Arrow data by uploading a temporary Parquet payload to BigQuery."""
+
+        self._require_capability("parquet_import_enabled")
+        arrow_table = self._coerce_arrow_table(source)
+        from sqlspec.utils.module_loader import ensure_pyarrow
+
+        ensure_pyarrow()
+
+        import pyarrow.parquet as pq
+
+        buffer = io.BytesIO()
+        pq.write_table(arrow_table, buffer)
+        buffer.seek(0)
+        job_config = self._build_load_job_config("parquet", overwrite)
+        job = self.connection.load_table_from_file(buffer, table, job_config=job_config)
+        job.result()
+        telemetry_payload = self._build_load_job_telemetry(job, table, format_label="parquet")
+        if telemetry:
+            telemetry_payload.setdefault("extra", {})
+            telemetry_payload["extra"]["arrow_rows"] = telemetry.get("rows_processed")
+        self._attach_partition_telemetry(telemetry_payload, partitioner)
+        return self._create_storage_job(telemetry_payload)
+
+    def load_from_storage(
+        self,
+        table: str,
+        source: "StorageDestination",
+        *,
+        file_format: "StorageFormat",
+        partitioner: "dict[str, Any] | None" = None,
+        overwrite: bool = False,
+    ) -> "StorageBridgeJob":
+        """Load staged artifacts from storage into BigQuery."""
+
+        if file_format != "parquet":
+            msg = "BigQuery storage bridge currently supports Parquet ingest only"
+            raise StorageCapabilityError(msg, capability="parquet_import_enabled")
+        job_config = self._build_load_job_config(file_format, overwrite)
+        job = self.connection.load_table_from_uri(source, table, job_config=job_config)
+        job.result()
+        telemetry_payload = self._build_load_job_telemetry(job, table, format_label=file_format)
+        self._attach_partition_telemetry(telemetry_payload, partitioner)
+        return self._create_storage_job(telemetry_payload)
+
+
+def _build_bigquery_profile() -> DriverParameterProfile:
+    """Create the BigQuery driver parameter profile."""
+
+    return DriverParameterProfile(
+        name="BigQuery",
+        default_style=ParameterStyle.NAMED_AT,
+        supported_styles={ParameterStyle.NAMED_AT, ParameterStyle.QMARK},
+        default_execution_style=ParameterStyle.NAMED_AT,
+        supported_execution_styles={ParameterStyle.NAMED_AT},
+        has_native_list_expansion=True,
+        preserve_parameter_format=True,
+        needs_static_script_compilation=False,
+        allow_mixed_parameter_styles=False,
+        preserve_original_params_for_many=True,
+        json_serializer_strategy="helper",
+        custom_type_coercions={
+            int: _identity,
+            float: _identity,
+            bytes: _identity,
+            datetime.datetime: _identity,
+            datetime.date: _identity,
+            datetime.time: _identity,
+            Decimal: _identity,
+            dict: _identity,
+            list: _identity,
+            type(None): lambda _: None,
+        },
+        extras={"json_tuple_strategy": "tuple", "type_coercion_overrides": {list: _identity, tuple: _tuple_to_list}},
+        default_dialect="bigquery",
+    )
+
+
+_BIGQUERY_PROFILE = _build_bigquery_profile()
+
+register_driver_profile("bigquery", _BIGQUERY_PROFILE)
+
+
+def build_bigquery_statement_config(*, json_serializer: "Callable[[Any], str] | None" = None) -> StatementConfig:
+    """Construct the BigQuery statement configuration with optional JSON serializer."""
+
+    serializer = json_serializer or to_json
+    return build_statement_config_from_profile(
+        _BIGQUERY_PROFILE, statement_overrides={"dialect": "bigquery"}, json_serializer=serializer
+    )
+
+
+bigquery_statement_config = build_bigquery_statement_config()
