@@ -8,7 +8,7 @@ from functools import lru_cache
 from typing import Any, Final
 from uuid import UUID
 
-from sqlspec.core.type_conversion import BaseTypeConverter, convert_uuid
+from sqlspec.core import BaseTypeConverter, convert_uuid
 
 try:
     from google.cloud.bigquery import ScalarQueryParameter
