@@ -1,21 +1,27 @@
 """DuckDB database configuration with connection pooling."""
 
-from collections.abc import Sequence
+from collections.abc import Callable, Sequence
 from contextlib import contextmanager
-from typing import TYPE_CHECKING, Any, ClassVar, TypedDict
+from typing import TYPE_CHECKING, Any, ClassVar, TypedDict, cast
 
 from typing_extensions import NotRequired
 
 from sqlspec.adapters.duckdb._types import DuckDBConnection
-from sqlspec.adapters.duckdb.driver import DuckDBCursor, DuckDBDriver, duckdb_statement_config
+from sqlspec.adapters.duckdb.driver import (
+    DuckDBCursor,
+    DuckDBDriver,
+    DuckDBExceptionHandler,
+    build_duckdb_statement_config,
+)
 from sqlspec.adapters.duckdb.pool import DuckDBConnectionPool
-from sqlspec.config import SyncDatabaseConfig
+from sqlspec.config import ExtensionConfigs, SyncDatabaseConfig
+from sqlspec.observability import ObservabilityConfig
+from sqlspec.utils.serializers import to_json
 
 if TYPE_CHECKING:
     from collections.abc import Callable, Generator
 
-    from sqlspec.core.statement import StatementConfig
-
+    from sqlspec.core import StatementConfig
 __all__ = (
     "DuckDBConfig",
     "DuckDBConnectionParams",
@@ -24,10 +30,21 @@ __all__ = (
     "DuckDBPoolParams",
     "DuckDBSecretConfig",
 )
+EXTENSION_FLAG_KEYS: "tuple[str, ...]" = (
+    "allow_community_extensions",
+    "allow_unsigned_extensions",
+    "enable_external_access",
+)
 
 
 class DuckDBConnectionParams(TypedDict):
-    """DuckDB connection parameters."""
+    """DuckDB connection parameters.
+
+    Mirrors the keyword arguments accepted by duckdb.connect so callers can drive every DuckDB
+    configuration switch directly through SQLSpec. All keys are optional and forwarded verbatim
+    to DuckDB, either as top-level parameters or via the nested ``config`` dictionary when DuckDB
+    expects them there.
+    """
 
     database: NotRequired[str]
     read_only: NotRequired[bool]
@@ -68,7 +85,8 @@ class DuckDBConnectionParams(TypedDict):
 class DuckDBPoolParams(DuckDBConnectionParams):
     """Complete pool configuration for DuckDB adapter.
 
-    Combines standardized pool parameters with DuckDB-specific connection parameters.
+    Extends DuckDBConnectionParams with pool sizing and lifecycle settings so SQLSpec can manage
+    per-thread DuckDB connections safely while honoring DuckDB's thread-safety constraints.
     """
 
     pool_min_size: NotRequired[int]
@@ -121,6 +139,8 @@ class DuckDBDriverFeatures(TypedDict):
         enable_uuid_conversion: Enable automatic UUID string conversion.
             When True (default), UUID strings are automatically converted to UUID objects.
             When False, UUID strings are treated as regular strings.
+        extension_flags: Connection-level flags (e.g., allow_community_extensions) applied
+            via SET statements immediately after connection creation.
     """
 
     extensions: NotRequired[Sequence[DuckDBExtensionConfig]]
@@ -128,6 +148,7 @@ class DuckDBDriverFeatures(TypedDict):
     on_connection_create: NotRequired["Callable[[DuckDBConnection], DuckDBConnection | None]"]
     json_serializer: NotRequired["Callable[[Any], str]"]
     enable_uuid_conversion: NotRequired[bool]
+    extension_flags: NotRequired[dict[str, Any]]
 
 
 class DuckDBConfig(SyncDatabaseConfig[DuckDBConnection, DuckDBConnectionPool, DuckDBDriver]):
@@ -177,6 +198,11 @@ class DuckDBConfig(SyncDatabaseConfig[DuckDBConnection, DuckDBConnectionPool, Du
     driver_type: "ClassVar[type[DuckDBDriver]]" = DuckDBDriver
     connection_type: "ClassVar[type[DuckDBConnection]]" = DuckDBConnection
     supports_transactional_ddl: "ClassVar[bool]" = True
+    supports_native_arrow_export: "ClassVar[bool]" = True
+    supports_native_arrow_import: "ClassVar[bool]" = True
+    supports_native_parquet_export: "ClassVar[bool]" = True
+    supports_native_parquet_import: "ClassVar[bool]" = True
+    storage_partition_strategies: "ClassVar[tuple[str, ...]]" = ("fixed", "rows_per_chunk", "manifest")
 
     def __init__(
         self,
@@ -187,7 +213,8 @@ class DuckDBConfig(SyncDatabaseConfig[DuckDBConnection, DuckDBConnectionPool, Du
         statement_config: "StatementConfig | None" = None,
         driver_features: "DuckDBDriverFeatures | dict[str, Any] | None" = None,
         bind_key: "str | None" = None,
-        extension_config: "dict[str, dict[str, Any]] | None" = None,
+        extension_config: "ExtensionConfigs | None" = None,
+        observability_config: "ObservabilityConfig | None" = None,
     ) -> None:
         """Initialize DuckDB configuration.
 
@@ -200,27 +227,57 @@ class DuckDBConfig(SyncDatabaseConfig[DuckDBConnection, DuckDBConnectionPool, Du
                 and enable_uuid_conversion options
             bind_key: Optional unique identifier for this configuration
             extension_config: Extension-specific configuration (e.g., Litestar plugin settings)
+            observability_config: Adapter-level observability overrides for lifecycle hooks and observers
         """
         if pool_config is None:
             pool_config = {}
-        if "database" not in pool_config:
-            pool_config["database"] = ":memory:shared_db"
+        pool_config.setdefault("database", ":memory:shared_db")
 
         if pool_config.get("database") in {":memory:", ""}:
             pool_config["database"] = ":memory:shared_db"
 
-        processed_features = dict(driver_features) if driver_features else {}
-        if "enable_uuid_conversion" not in processed_features:
-            processed_features["enable_uuid_conversion"] = True
+        extension_flags: dict[str, Any] = {}
+        for key in tuple(pool_config.keys()):
+            if key in EXTENSION_FLAG_KEYS:
+                extension_flags[key] = pool_config.pop(key)  # type: ignore[misc]
+
+        processed_features: dict[str, Any] = dict(driver_features) if driver_features else {}
+        user_connection_hook = cast(
+            "Callable[[Any], None] | None", processed_features.pop("on_connection_create", None)
+        )
+        processed_features.setdefault("enable_uuid_conversion", True)
+        serializer = processed_features.setdefault("json_serializer", to_json)
+
+        if extension_flags:
+            existing_flags = cast("dict[str, Any]", processed_features.get("extension_flags", {}))
+            merged_flags = {**existing_flags, **extension_flags}
+            processed_features["extension_flags"] = merged_flags
+
+        local_observability = observability_config
+        if user_connection_hook is not None:
+
+            def _wrap_lifecycle_hook(context: dict[str, Any]) -> None:
+                connection = context.get("connection")
+                if connection is None:
+                    return
+                user_connection_hook(connection)
+
+            lifecycle_override = ObservabilityConfig(lifecycle={"on_connection_create": [_wrap_lifecycle_hook]})
+            local_observability = ObservabilityConfig.merge(local_observability, lifecycle_override)
+
+        base_statement_config = statement_config or build_duckdb_statement_config(
+            json_serializer=cast("Callable[[Any], str]", serializer)
+        )
 
         super().__init__(
             bind_key=bind_key,
             pool_config=dict(pool_config),
             pool_instance=pool_instance,
             migration_config=migration_config,
-            statement_config=statement_config or duckdb_statement_config,
+            statement_config=base_statement_config,
             driver_features=processed_features,
             extension_config=extension_config,
+            observability_config=local_observability,
         )
 
     def _get_connection_config_dict(self) -> "dict[str, Any]":
@@ -238,24 +295,16 @@ class DuckDBConfig(SyncDatabaseConfig[DuckDBConnection, DuckDBConnectionPool, Du
 
         extensions = self.driver_features.get("extensions", None)
         secrets = self.driver_features.get("secrets", None)
-        on_connection_create = self.driver_features.get("on_connection_create", None)
-
+        extension_flags = self.driver_features.get("extension_flags", None)
         extensions_dicts = [dict(ext) for ext in extensions] if extensions else None
         secrets_dicts = [dict(secret) for secret in secrets] if secrets else None
-
-        pool_callback = None
-        if on_connection_create:
-
-            def wrapped_callback(conn: DuckDBConnection) -> None:
-                on_connection_create(conn)
-
-            pool_callback = wrapped_callback
+        extension_flags_dict = dict(extension_flags) if extension_flags else None
 
         return DuckDBConnectionPool(
             connection_config=connection_config,
             extensions=extensions_dicts,
+            extension_flags=extension_flags_dict,
             secrets=secrets_dicts,
-            on_connection_create=pool_callback,
             **self.pool_config,
         )
 
@@ -319,9 +368,9 @@ class DuckDBConfig(SyncDatabaseConfig[DuckDBConnection, DuckDBConnectionPool, Du
                 statement_config=statement_config or self.statement_config,
                 driver_features=self.driver_features,
             )
-            yield driver
+            yield self._prepare_driver(driver)
 
-    def get_signature_namespace(self) -> "dict[str, type[Any]]":
+    def get_signature_namespace(self) -> "dict[str, Any]":
         """Get the signature namespace for DuckDB types.
 
         This provides all DuckDB-specific types that Litestar needs to recognize
@@ -332,5 +381,16 @@ class DuckDBConfig(SyncDatabaseConfig[DuckDBConnection, DuckDBConnectionPool, Du
         """
 
         namespace = super().get_signature_namespace()
-        namespace.update({"DuckDBConnection": DuckDBConnection, "DuckDBCursor": DuckDBCursor})
+        namespace.update({
+            "DuckDBConnection": DuckDBConnection,
+            "DuckDBConnectionParams": DuckDBConnectionParams,
+            "DuckDBConnectionPool": DuckDBConnectionPool,
+            "DuckDBCursor": DuckDBCursor,
+            "DuckDBDriver": DuckDBDriver,
+            "DuckDBDriverFeatures": DuckDBDriverFeatures,
+            "DuckDBExceptionHandler": DuckDBExceptionHandler,
+            "DuckDBExtensionConfig": DuckDBExtensionConfig,
+            "DuckDBPoolParams": DuckDBPoolParams,
+            "DuckDBSecretConfig": DuckDBSecretConfig,
+        })
         return namespace
