@@ -15,15 +15,18 @@ from sqlspec.adapters.oracledb._types import (
     OracleSyncConnection,
     OracleSyncConnectionPool,
 )
+from sqlspec.adapters.oracledb._uuid_handlers import register_uuid_handlers
 from sqlspec.adapters.oracledb.driver import (
     OracleAsyncCursor,
     OracleAsyncDriver,
+    OracleAsyncExceptionHandler,
     OracleSyncCursor,
     OracleSyncDriver,
+    OracleSyncExceptionHandler,
     oracledb_statement_config,
 )
 from sqlspec.adapters.oracledb.migrations import OracleAsyncMigrationTracker, OracleSyncMigrationTracker
-from sqlspec.config import AsyncDatabaseConfig, SyncDatabaseConfig
+from sqlspec.config import AsyncDatabaseConfig, ExtensionConfigs, SyncDatabaseConfig
 from sqlspec.typing import NUMPY_INSTALLED
 
 if TYPE_CHECKING:
@@ -31,7 +34,7 @@ if TYPE_CHECKING:
 
     from oracledb import AuthMode
 
-    from sqlspec.core.statement import StatementConfig
+    from sqlspec.core import StatementConfig
 
 
 __all__ = (
@@ -96,10 +99,17 @@ class OracleDriverFeatures(TypedDict):
     enable_lowercase_column_names: Normalize implicit Oracle uppercase column names to lowercase.
         Targets unquoted Oracle identifiers that default to uppercase while preserving quoted case-sensitive aliases.
         Defaults to True for compatibility with schema libraries expecting snake_case fields.
+    enable_uuid_binary: Enable automatic UUID ↔ RAW(16) binary conversion.
+        When True (default), Python UUID objects are automatically converted to/from
+        RAW(16) binary format for optimal storage efficiency (16 bytes vs 36 bytes).
+        Applies only to RAW(16) columns; other RAW sizes remain unchanged.
+        Uses Python's stdlib uuid module (no external dependencies).
+        Defaults to True for improved type safety and storage efficiency.
     """
 
     enable_numpy_vectors: NotRequired[bool]
     enable_lowercase_column_names: NotRequired[bool]
+    enable_uuid_binary: NotRequired[bool]
 
 
 class OracleSyncConfig(SyncDatabaseConfig[OracleSyncConnection, "OracleSyncConnectionPool", OracleSyncDriver]):
@@ -111,6 +121,10 @@ class OracleSyncConfig(SyncDatabaseConfig[OracleSyncConnection, "OracleSyncConne
     connection_type: "ClassVar[type[OracleSyncConnection]]" = OracleSyncConnection
     migration_tracker_type: "ClassVar[type[OracleSyncMigrationTracker]]" = OracleSyncMigrationTracker
     supports_transactional_ddl: ClassVar[bool] = False
+    supports_native_arrow_export: ClassVar[bool] = True
+    supports_native_arrow_import: ClassVar[bool] = True
+    supports_native_parquet_export: ClassVar[bool] = True
+    supports_native_parquet_import: ClassVar[bool] = True
 
     def __init__(
         self,
@@ -121,7 +135,7 @@ class OracleSyncConfig(SyncDatabaseConfig[OracleSyncConnection, "OracleSyncConne
         statement_config: "StatementConfig | None" = None,
         driver_features: "OracleDriverFeatures | dict[str, Any] | None" = None,
         bind_key: "str | None" = None,
-        extension_config: "dict[str, dict[str, Any]] | None" = None,
+        extension_config: "ExtensionConfigs | None" = None,
     ) -> None:
         """Initialize Oracle synchronous configuration.
 
@@ -142,10 +156,9 @@ class OracleSyncConfig(SyncDatabaseConfig[OracleSyncConnection, "OracleSyncConne
         statement_config = statement_config or oracledb_statement_config
 
         processed_driver_features: dict[str, Any] = dict(driver_features) if driver_features else {}
-        if "enable_numpy_vectors" not in processed_driver_features:
-            processed_driver_features["enable_numpy_vectors"] = NUMPY_INSTALLED
-        if "enable_lowercase_column_names" not in processed_driver_features:
-            processed_driver_features["enable_lowercase_column_names"] = True
+        processed_driver_features.setdefault("enable_numpy_vectors", NUMPY_INSTALLED)
+        processed_driver_features.setdefault("enable_lowercase_column_names", True)
+        processed_driver_features.setdefault("enable_uuid_binary", True)
 
         super().__init__(
             pool_config=processed_pool_config,
@@ -161,23 +174,30 @@ class OracleSyncConfig(SyncDatabaseConfig[OracleSyncConnection, "OracleSyncConne
         """Create the actual connection pool."""
         config = dict(self.pool_config)
 
-        if self.driver_features.get("enable_numpy_vectors", False):
+        needs_session_callback = self.driver_features.get("enable_numpy_vectors", False) or self.driver_features.get(
+            "enable_uuid_binary", False
+        )
+        if needs_session_callback:
             config["session_callback"] = self._init_connection
 
         return oracledb.create_pool(**config)
 
     def _init_connection(self, connection: "OracleSyncConnection", tag: str) -> None:
-        """Initialize connection with optional NumPy vector support.
+        """Initialize connection with optional type handlers.
+
+        Registers NumPy vector handlers and UUID binary handlers when enabled.
+        Registration order ensures handler chaining works correctly.
 
         Args:
             connection: Oracle connection to initialize.
             tag: Connection tag for session state (unused).
         """
         if self.driver_features.get("enable_numpy_vectors", False):
-            from sqlspec.adapters.oracledb._numpy_handlers import register_numpy_handlers
-
             register_numpy_handlers(connection)
 
+        if self.driver_features.get("enable_uuid_binary", False):
+            register_uuid_handlers(connection)
+
     def _close_pool(self) -> None:
         """Close the actual connection pool."""
         if self.pool_instance:
@@ -224,11 +244,12 @@ class OracleSyncConfig(SyncDatabaseConfig[OracleSyncConnection, "OracleSyncConne
         """
         _ = (args, kwargs)  # Mark as intentionally unused
         with self.provide_connection() as conn:
-            yield self.driver_type(
+            driver = self.driver_type(
                 connection=conn,
                 statement_config=statement_config or self.statement_config,
                 driver_features=self.driver_features,
             )
+            yield self._prepare_driver(driver)
 
     def provide_pool(self) -> "OracleSyncConnectionPool":
         """Provide pool instance.
@@ -240,7 +261,7 @@ class OracleSyncConfig(SyncDatabaseConfig[OracleSyncConnection, "OracleSyncConne
             self.pool_instance = self.create_pool()
         return self.pool_instance
 
-    def get_signature_namespace(self) -> "dict[str, type[Any]]":
+    def get_signature_namespace(self) -> "dict[str, Any]":
         """Get the signature namespace for OracleDB types.
 
         Provides OracleDB-specific types for Litestar framework recognition.
@@ -250,15 +271,21 @@ class OracleSyncConfig(SyncDatabaseConfig[OracleSyncConnection, "OracleSyncConne
         """
 
         namespace = super().get_signature_namespace()
-        namespace.update(
-            {
-                "OracleSyncConnection": OracleSyncConnection,
-                "OracleAsyncConnection": OracleAsyncConnection,
-                "OracleSyncConnectionPool": OracleSyncConnectionPool,
-                "OracleAsyncConnectionPool": OracleAsyncConnectionPool,
-                "OracleSyncCursor": OracleSyncCursor,
-            }
-        )
+        namespace.update({
+            "OracleAsyncConnection": OracleAsyncConnection,
+            "OracleAsyncConnectionPool": OracleAsyncConnectionPool,
+            "OracleAsyncCursor": OracleAsyncCursor,
+            "OracleAsyncDriver": OracleAsyncDriver,
+            "OracleAsyncExceptionHandler": OracleAsyncExceptionHandler,
+            "OracleConnectionParams": OracleConnectionParams,
+            "OracleDriverFeatures": OracleDriverFeatures,
+            "OraclePoolParams": OraclePoolParams,
+            "OracleSyncConnection": OracleSyncConnection,
+            "OracleSyncConnectionPool": OracleSyncConnectionPool,
+            "OracleSyncCursor": OracleSyncCursor,
+            "OracleSyncDriver": OracleSyncDriver,
+            "OracleSyncExceptionHandler": OracleSyncExceptionHandler,
+        })
         return namespace
 
 
@@ -271,6 +298,10 @@ class OracleAsyncConfig(AsyncDatabaseConfig[OracleAsyncConnection, "OracleAsyncC
     driver_type: ClassVar[type[OracleAsyncDriver]] = OracleAsyncDriver
     migration_tracker_type: "ClassVar[type[OracleAsyncMigrationTracker]]" = OracleAsyncMigrationTracker
     supports_transactional_ddl: ClassVar[bool] = False
+    supports_native_arrow_export: ClassVar[bool] = True
+    supports_native_arrow_import: ClassVar[bool] = True
+    supports_native_parquet_export: ClassVar[bool] = True
+    supports_native_parquet_import: ClassVar[bool] = True
 
     def __init__(
         self,
@@ -281,7 +312,7 @@ class OracleAsyncConfig(AsyncDatabaseConfig[OracleAsyncConnection, "OracleAsyncC
         statement_config: "StatementConfig | None" = None,
         driver_features: "OracleDriverFeatures | dict[str, Any] | None" = None,
         bind_key: "str | None" = None,
-        extension_config: "dict[str, dict[str, Any]] | None" = None,
+        extension_config: "ExtensionConfigs | None" = None,
     ) -> None:
         """Initialize Oracle asynchronous configuration.
 
@@ -301,10 +332,9 @@ class OracleAsyncConfig(AsyncDatabaseConfig[OracleAsyncConnection, "OracleAsyncC
             processed_pool_config.update(extras)
 
         processed_driver_features: dict[str, Any] = dict(driver_features) if driver_features else {}
-        if "enable_numpy_vectors" not in processed_driver_features:
-            processed_driver_features["enable_numpy_vectors"] = NUMPY_INSTALLED
-        if "enable_lowercase_column_names" not in processed_driver_features:
-            processed_driver_features["enable_lowercase_column_names"] = True
+        processed_driver_features.setdefault("enable_numpy_vectors", NUMPY_INSTALLED)
+        processed_driver_features.setdefault("enable_lowercase_column_names", True)
+        processed_driver_features.setdefault("enable_uuid_binary", True)
 
         super().__init__(
             pool_config=processed_pool_config,
@@ -320,13 +350,19 @@ class OracleAsyncConfig(AsyncDatabaseConfig[OracleAsyncConnection, "OracleAsyncC
         """Create the actual async connection pool."""
         config = dict(self.pool_config)
 
-        if self.driver_features.get("enable_numpy_vectors", False):
+        needs_session_callback = self.driver_features.get("enable_numpy_vectors", False) or self.driver_features.get(
+            "enable_uuid_binary", False
+        )
+        if needs_session_callback:
             config["session_callback"] = self._init_connection
 
         return oracledb.create_pool_async(**config)
 
     async def _init_connection(self, connection: "OracleAsyncConnection", tag: str) -> None:
-        """Initialize async connection with optional NumPy vector support.
+        """Initialize async connection with optional type handlers.
+
+        Registers NumPy vector handlers and UUID binary handlers when enabled.
+        Registration order ensures handler chaining works correctly.
 
         Args:
             connection: Oracle async connection to initialize.
@@ -335,6 +371,9 @@ class OracleAsyncConfig(AsyncDatabaseConfig[OracleAsyncConnection, "OracleAsyncC
         if self.driver_features.get("enable_numpy_vectors", False):
             register_numpy_handlers(connection)
 
+        if self.driver_features.get("enable_uuid_binary", False):
+            register_uuid_handlers(connection)
+
     async def _close_pool(self) -> None:
         """Close the actual async connection pool."""
         if self.pool_instance:
@@ -385,11 +424,12 @@ class OracleAsyncConfig(AsyncDatabaseConfig[OracleAsyncConnection, "OracleAsyncC
         """
         _ = (args, kwargs)  # Mark as intentionally unused
         async with self.provide_connection() as conn:
-            yield self.driver_type(
+            driver = self.driver_type(
                 connection=conn,
                 statement_config=statement_config or self.statement_config,
                 driver_features=self.driver_features,
             )
+            yield self._prepare_driver(driver)
 
     async def provide_pool(self) -> "OracleAsyncConnectionPool":
         """Provide async pool instance.
@@ -401,7 +441,7 @@ class OracleAsyncConfig(AsyncDatabaseConfig[OracleAsyncConnection, "OracleAsyncC
             self.pool_instance = await self.create_pool()
         return self.pool_instance
 
-    def get_signature_namespace(self) -> "dict[str, type[Any]]":
+    def get_signature_namespace(self) -> "dict[str, Any]":
         """Get the signature namespace for OracleDB async types.
 
         Provides OracleDB async-specific types for Litestar framework recognition.
@@ -411,14 +451,19 @@ class OracleAsyncConfig(AsyncDatabaseConfig[OracleAsyncConnection, "OracleAsyncC
         """
 
         namespace = super().get_signature_namespace()
-        namespace.update(
-            {
-                "OracleSyncConnection": OracleSyncConnection,
-                "OracleAsyncConnection": OracleAsyncConnection,
-                "OracleSyncConnectionPool": OracleSyncConnectionPool,
-                "OracleAsyncConnectionPool": OracleAsyncConnectionPool,
-                "OracleSyncCursor": OracleSyncCursor,
-                "OracleAsyncCursor": OracleAsyncCursor,
-            }
-        )
+        namespace.update({
+            "OracleAsyncConnection": OracleAsyncConnection,
+            "OracleAsyncConnectionPool": OracleAsyncConnectionPool,
+            "OracleAsyncCursor": OracleAsyncCursor,
+            "OracleAsyncDriver": OracleAsyncDriver,
+            "OracleAsyncExceptionHandler": OracleAsyncExceptionHandler,
+            "OracleConnectionParams": OracleConnectionParams,
+            "OracleDriverFeatures": OracleDriverFeatures,
+            "OraclePoolParams": OraclePoolParams,
+            "OracleSyncConnection": OracleSyncConnection,
+            "OracleSyncConnectionPool": OracleSyncConnectionPool,
+            "OracleSyncCursor": OracleSyncCursor,
+            "OracleSyncDriver": OracleSyncDriver,
+            "OracleSyncExceptionHandler": OracleSyncExceptionHandler,
+        })
         return namespace
