@@ -2,7 +2,6 @@
 # cspell:ignore pdbs
 
 import re
-from contextlib import suppress
 from typing import TYPE_CHECKING, Any, cast
 
 from sqlspec.driver import (
@@ -28,7 +27,17 @@ ORACLE_MIN_JSON_BLOB_VERSION = 12
 ORACLE_MIN_OSON_VERSION = 19
 
 # Compiled regex patterns
-ORACLE_VERSION_PATTERN = re.compile(r"Oracle Database (\d+)c?.* Release (\d+)\.(\d+)\.(\d+)")
+VERSION_NUMBER_PATTERN = re.compile(r"(\d+)")
+VERSION_COMPONENT_COUNT = 3
+
+COMPONENT_VERSION_SQL = (
+    'SELECT product AS "product", version AS "version", status AS "status" '
+    "FROM product_component_version WHERE product LIKE 'Oracle%' "
+    "ORDER BY TO_NUMBER(REGEXP_SUBSTR(version, '^[0-9]+')) DESC, version DESC "
+    "FETCH FIRST 1 ROWS ONLY"
+)
+
+AUTONOMOUS_SERVICE_SQL = "SELECT sys_context('USERENV','CLOUD_SERVICE') AS \"service\" FROM dual"
 
 __all__ = ("OracleAsyncDataDictionary", "OracleSyncDataDictionary", "OracleVersionInfo")
 
@@ -130,6 +139,74 @@ class OracleDataDictionaryMixin:
             ORDER BY column_id
         """
 
+    def _select_component_version_row(self, driver: "OracleSyncDriver") -> "dict[str, Any] | None":
+        """Fetch the latest Oracle component version row.
+
+        Args:
+            driver: Oracle sync driver instance.
+
+        Returns:
+            First matching row from product_component_version or None.
+        """
+
+        result = driver.execute(COMPONENT_VERSION_SQL)
+        data = result.get_data()
+        if not data:
+            logger.warning("No rows returned from product_component_version")
+            return None
+        return data[0]
+
+    async def _select_component_version_row_async(self, driver: "OracleAsyncDriver") -> "dict[str, Any] | None":
+        """Async helper to fetch the latest Oracle component version row.
+
+        Args:
+            driver: Oracle async driver instance.
+
+        Returns:
+            First matching row from product_component_version or None.
+        """
+
+        result = await driver.execute(COMPONENT_VERSION_SQL)
+        data = result.get_data()
+        if not data:
+            logger.warning("No rows returned from product_component_version")
+            return None
+        return data[0]
+
+    def _build_version_info_from_row(self, row: "dict[str, Any] | None") -> "OracleVersionInfo | None":
+        """Build Oracle version metadata from a component version row.
+
+        Args:
+            row: Data dictionary row containing product/version fields.
+
+        Returns:
+            OracleVersionInfo if parsing succeeds, otherwise None.
+        """
+
+        if not row:
+            logger.warning("Unable to determine Oracle version without component data")
+            return None
+
+        version_value = row.get("version_full") or row.get("VERSION_FULL") or row.get("version") or row.get("VERSION")
+
+        if version_value is None:
+            logger.warning("Component version row missing VERSION column: %s", row)
+            return None
+
+        matches = VERSION_NUMBER_PATTERN.findall(str(version_value))
+        if not matches:
+            logger.warning("Unable to parse Oracle version from value: %s", version_value)
+            return None
+
+        numbers = [int(match) for match in matches[:VERSION_COMPONENT_COUNT]]
+        while len(numbers) < VERSION_COMPONENT_COUNT:
+            numbers.append(0)
+
+        version_info = OracleVersionInfo(numbers[0], numbers[1], numbers[2])
+        product_name = row.get("product") or row.get("PRODUCT") or "Oracle Database"
+        logger.debug("Detected Oracle component version for %s: %s", product_name, version_info)
+        return version_info
+
     def _get_oracle_version(self, driver: "OracleAsyncDriver | OracleSyncDriver") -> "OracleVersionInfo | None":
         """Get Oracle database version information.
 
@@ -139,30 +216,8 @@ class OracleDataDictionaryMixin:
         Returns:
             Oracle version information or None if detection fails
         """
-        banner = driver.select_value("SELECT banner AS \"banner\" FROM v$version WHERE banner LIKE 'Oracle%'")
-
-        # Parse version from banner like "Oracle Database 21c Enterprise Edition Release 21.0.0.0.0 - Production"
-        # or "Oracle Database 19c Standard Edition 2 Release 19.0.0.0.0 - Production"
-        version_match = ORACLE_VERSION_PATTERN.search(str(banner))
-
-        if not version_match:
-            logger.warning("Could not parse Oracle version from banner: %s", banner)
-            return None
-
-        major = int(version_match.group(1))
-        release_major = int(version_match.group(2))
-        minor = int(version_match.group(3))
-        patch = int(version_match.group(4))
-
-        # For Oracle 21c+, the major version is in the first group
-        # For Oracle 19c and earlier, use the release version
-        if major >= ORACLE_MIN_JSON_NATIVE_VERSION:
-            version_info = OracleVersionInfo(major, minor, patch)
-        else:
-            version_info = OracleVersionInfo(release_major, minor, patch)
-
-        logger.debug("Detected Oracle version: %s", version_info)
-        return version_info
+        row = self._select_component_version_row(cast("OracleSyncDriver", driver))
+        return self._build_version_info_from_row(row)
 
     def _get_oracle_compatible(self, driver: "OracleAsyncDriver | OracleSyncDriver") -> "str | None":
         """Get Oracle compatible parameter value.
@@ -220,8 +275,17 @@ class OracleSyncDataDictionary(OracleDataDictionaryMixin, SyncDataDictionaryBase
         Returns:
             True if this is an Autonomous Database, False otherwise
         """
-        result = driver.select_value_or_none('SELECT COUNT(1) AS "cnt" FROM v$pdbs WHERE cloud_identity IS NOT NULL')
-        return bool(result and int(result) > 0)
+        try:
+            service = driver.select_value_or_none(AUTONOMOUS_SERVICE_SQL)
+        except Exception:
+            logger.debug("Unable to detect Oracle cloud service via sys_context")
+            return False
+        if service is None:
+            return False
+        normalized = str(service).strip().upper()
+        if not normalized:
+            return False
+        return "AUTONOMOUS" in normalized or normalized.startswith(("ATP", "ADW"))
 
     def get_version(self, driver: SyncDriverAdapterBase) -> "OracleVersionInfo | None":
         """Get Oracle database version information.
@@ -348,28 +412,13 @@ class OracleAsyncDataDictionary(OracleDataDictionaryMixin, AsyncDataDictionaryBa
         Returns:
             Oracle version information or None if detection fails
         """
-        banner = await cast("OracleAsyncDriver", driver).select_value(
-            "SELECT banner AS \"banner\" FROM v$version WHERE banner LIKE 'Oracle%'"
-        )
+        oracle_driver = cast("OracleAsyncDriver", driver)
+        row = await self._select_component_version_row_async(oracle_driver)
+        version_info = self._build_version_info_from_row(row)
 
-        version_match = ORACLE_VERSION_PATTERN.search(str(banner))
-
-        if not version_match:
-            logger.warning("Could not parse Oracle version from banner: %s", banner)
+        if not version_info:
             return None
 
-        major = int(version_match.group(1))
-        release_major = int(version_match.group(2))
-        minor = int(version_match.group(3))
-        patch = int(version_match.group(4))
-
-        if major >= ORACLE_MIN_JSON_NATIVE_VERSION:
-            version_info = OracleVersionInfo(major, minor, patch)
-        else:
-            version_info = OracleVersionInfo(release_major, minor, patch)
-
-        # Enhance with additional information
-        oracle_driver = cast("OracleAsyncDriver", driver)
         compatible = await self._get_oracle_compatible_async(oracle_driver)
         is_autonomous = await self._is_oracle_autonomous_async(oracle_driver)
 
@@ -407,15 +456,19 @@ class OracleAsyncDataDictionary(OracleDataDictionaryMixin, AsyncDataDictionaryBa
         Returns:
             True if this is an Autonomous Database, False otherwise
         """
-        # Check for cloud_identity in v$pdbs (most reliable for Autonomous)
-        with suppress(Exception):
-            result = await driver.execute('SELECT COUNT(1) AS "cnt" FROM v$pdbs WHERE cloud_identity IS NOT NULL')
-            if result.data:
-                count = result.data[0]["cnt"] if isinstance(result.data[0], dict) else result.data[0][0]
-                if int(count) > 0:
-                    logger.debug("Detected Oracle Autonomous Database via v$pdbs")
-                    return True
-
+        try:
+            service = await driver.select_value_or_none(AUTONOMOUS_SERVICE_SQL)
+        except Exception:
+            logger.debug("Unable to detect Oracle cloud service via sys_context (async)")
+            return False
+        if service is None:
+            return False
+        normalized = str(service).strip().upper()
+        if not normalized:
+            return False
+        if "AUTONOMOUS" in normalized or normalized.startswith(("ATP", "ADW")):
+            logger.debug("Detected Oracle Autonomous Database via USERENV context")
+            return True
         logger.debug("Oracle Autonomous Database not detected")
         return False
 
