@@ -1,8 +1,9 @@
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
+    from typing import TypeAlias
+
     from psqlpy import Connection
-    from typing_extensions import TypeAlias
 
     PsqlpyConnection: TypeAlias = Connection
 else:
