@@ -3,8 +3,9 @@ from typing import TYPE_CHECKING
 from psycopg.rows import DictRow as PsycopgDictRow
 
 if TYPE_CHECKING:
+    from typing import TypeAlias
+
     from psycopg import AsyncConnection, Connection
-    from typing_extensions import TypeAlias
 
     PsycopgSyncConnection: TypeAlias = Connection[PsycopgDictRow]
     PsycopgAsyncConnection: TypeAlias = AsyncConnection[PsycopgDictRow]
