@@ -1,7 +1,7 @@
 """SQLite adapter for SQLSpec."""
 
 from sqlspec.adapters.sqlite._types import SqliteConnection
-from sqlspec.adapters.sqlite.config import SqliteConfig, SqliteConnectionParams
+from sqlspec.adapters.sqlite.config import SqliteConfig, SqliteConnectionParams, SqliteDriverFeatures
 from sqlspec.adapters.sqlite.driver import SqliteCursor, SqliteDriver, SqliteExceptionHandler, sqlite_statement_config
 from sqlspec.adapters.sqlite.pool import SqliteConnectionPool
 
@@ -12,6 +12,7 @@ __all__ = (
     "SqliteConnectionPool",
     "SqliteCursor",
     "SqliteDriver",
+    "SqliteDriverFeatures",
     "SqliteExceptionHandler",
     "sqlite_statement_config",
 )
