@@ -9,9 +9,9 @@ from typing_extensions import NotRequired
 
 from sqlspec.adapters.sqlite._type_handlers import register_type_handlers
 from sqlspec.adapters.sqlite._types import SqliteConnection
-from sqlspec.adapters.sqlite.driver import SqliteCursor, SqliteDriver, sqlite_statement_config
+from sqlspec.adapters.sqlite.driver import SqliteCursor, SqliteDriver, SqliteExceptionHandler, sqlite_statement_config
 from sqlspec.adapters.sqlite.pool import SqliteConnectionPool
-from sqlspec.config import SyncDatabaseConfig
+from sqlspec.config import ExtensionConfigs, SyncDatabaseConfig
 from sqlspec.utils.serializers import from_json, to_json
 
 logger = logging.getLogger(__name__)
@@ -19,7 +19,8 @@ logger = logging.getLogger(__name__)
 if TYPE_CHECKING:
     from collections.abc import Callable, Generator
 
-    from sqlspec.core.statement import StatementConfig
+    from sqlspec.core import StatementConfig
+    from sqlspec.observability import ObservabilityConfig
 
 
 class SqliteConnectionParams(TypedDict):
@@ -63,6 +64,10 @@ class SqliteConfig(SyncDatabaseConfig[SqliteConnection, SqliteConnectionPool, Sq
     driver_type: "ClassVar[type[SqliteDriver]]" = SqliteDriver
     connection_type: "ClassVar[type[SqliteConnection]]" = SqliteConnection
     supports_transactional_ddl: "ClassVar[bool]" = True
+    supports_native_arrow_export: "ClassVar[bool]" = True
+    supports_native_arrow_import: "ClassVar[bool]" = True
+    supports_native_parquet_export: "ClassVar[bool]" = True
+    supports_native_parquet_import: "ClassVar[bool]" = True
 
     def __init__(
         self,
@@ -73,7 +78,8 @@ class SqliteConfig(SyncDatabaseConfig[SqliteConnection, SqliteConnectionPool, Sq
         statement_config: "StatementConfig | None" = None,
         driver_features: "SqliteDriverFeatures | dict[str, Any] | None" = None,
         bind_key: "str | None" = None,
-        extension_config: "dict[str, dict[str, Any]] | None" = None,
+        extension_config: "ExtensionConfigs | None" = None,
+        observability_config: "ObservabilityConfig | None" = None,
     ) -> None:
         """Initialize SQLite configuration.
 
@@ -85,6 +91,7 @@ class SqliteConfig(SyncDatabaseConfig[SqliteConnection, SqliteConnectionPool, Sq
             driver_features: Optional driver feature configuration
             bind_key: Optional bind key for the configuration
             extension_config: Extension-specific configuration (e.g., Litestar plugin settings)
+            observability_config: Adapter-level observability overrides for lifecycle hooks and observers
         """
         if pool_config is None:
             pool_config = {}
@@ -102,24 +109,26 @@ class SqliteConfig(SyncDatabaseConfig[SqliteConnection, SqliteConnectionPool, Sq
                 pool_config["uri"] = True
 
         processed_driver_features: dict[str, Any] = dict(driver_features) if driver_features else {}
+        processed_driver_features.setdefault("enable_custom_adapters", True)
+        json_serializer = processed_driver_features.setdefault("json_serializer", to_json)
+        json_deserializer = processed_driver_features.setdefault("json_deserializer", from_json)
 
-        if "enable_custom_adapters" not in processed_driver_features:
-            processed_driver_features["enable_custom_adapters"] = True
-
-        if "json_serializer" not in processed_driver_features:
-            processed_driver_features["json_serializer"] = to_json
-
-        if "json_deserializer" not in processed_driver_features:
-            processed_driver_features["json_deserializer"] = from_json
+        base_statement_config = statement_config or sqlite_statement_config
+        if json_serializer is not None:
+            parameter_config = base_statement_config.parameter_config.with_json_serializers(
+                json_serializer, deserializer=json_deserializer
+            )
+            base_statement_config = base_statement_config.replace(parameter_config=parameter_config)
 
         super().__init__(
             bind_key=bind_key,
             pool_instance=pool_instance,
             pool_config=cast("dict[str, Any]", pool_config),
             migration_config=migration_config,
-            statement_config=statement_config or sqlite_statement_config,
+            statement_config=base_statement_config,
             driver_features=processed_driver_features,
             extension_config=extension_config,
+            observability_config=observability_config,
         )
 
     def _get_connection_config_dict(self) -> "dict[str, Any]":
@@ -186,18 +195,27 @@ class SqliteConfig(SyncDatabaseConfig[SqliteConnection, SqliteConnectionPool, Sq
             SqliteDriver: A driver instance with thread-local connection
         """
         with self.provide_connection(*args, **kwargs) as connection:
-            yield self.driver_type(
+            driver = self.driver_type(
                 connection=connection,
                 statement_config=statement_config or self.statement_config,
                 driver_features=self.driver_features,
             )
+            yield self._prepare_driver(driver)
 
-    def get_signature_namespace(self) -> "dict[str, type[Any]]":
+    def get_signature_namespace(self) -> "dict[str, Any]":
         """Get the signature namespace for SQLite types.
 
         Returns:
             Dictionary mapping type names to types.
         """
         namespace = super().get_signature_namespace()
-        namespace.update({"SqliteConnection": SqliteConnection, "SqliteCursor": SqliteCursor})
+        namespace.update({
+            "SqliteConnection": SqliteConnection,
+            "SqliteConnectionParams": SqliteConnectionParams,
+            "SqliteConnectionPool": SqliteConnectionPool,
+            "SqliteCursor": SqliteCursor,
+            "SqliteDriver": SqliteDriver,
+            "SqliteDriverFeatures": SqliteDriverFeatures,
+            "SqliteExceptionHandler": SqliteExceptionHandler,
+        })
         return namespace
