@@ -10,29 +10,35 @@ Classes:
 """
 
 from abc import ABC, abstractmethod
+from collections.abc import Iterable, Iterator
 from typing import TYPE_CHECKING, Any, Optional, cast, overload
 
 from mypy_extensions import mypyc_attr
 from typing_extensions import TypeVar
 
 from sqlspec.core.compiler import OperationType
+from sqlspec.core.statement import SQL
+from sqlspec.storage import (
+    AsyncStoragePipeline,
+    StorageDestination,
+    StorageFormat,
+    StorageTelemetry,
+    SyncStoragePipeline,
+)
 from sqlspec.utils.module_loader import ensure_pandas, ensure_polars, ensure_pyarrow
 from sqlspec.utils.schema import to_schema
 
 if TYPE_CHECKING:
-    from collections.abc import Iterator
-
-    from sqlspec.core.statement import SQL
     from sqlspec.typing import ArrowTable, PandasDataFrame, PolarsDataFrame, SchemaT
 
 
-__all__ = ("ArrowResult", "SQLResult", "StatementResult")
+__all__ = ("ArrowResult", "EmptyResult", "SQLResult", "StackResult", "StatementResult")
 
 T = TypeVar("T")
 
 
 @mypyc_attr(allow_interpreted_subclasses=False)
-class StatementResult(ABC):
+class StatementResult(ABC, Iterable[Any]):
     """Abstract base class for SQL statement execution results.
 
     Provides a common interface for handling different types of SQL operation
@@ -76,6 +82,10 @@ class StatementResult(ABC):
         self.execution_time = execution_time
         self.metadata = metadata if metadata is not None else {}
 
+    @abstractmethod
+    def __iter__(self) -> Iterator[Any]:
+        """Iterate over result rows."""
+
     @abstractmethod
     def is_success(self) -> bool:
         """Check if the operation was successful.
@@ -564,6 +574,32 @@ class SQLResult(StatementResult):
 
         return next(iter(row.values()))
 
+    def write_to_storage_sync(
+        self,
+        destination: "StorageDestination",
+        *,
+        format_hint: "StorageFormat | None" = None,
+        storage_options: "dict[str, Any] | None" = None,
+        pipeline: "SyncStoragePipeline | None" = None,
+    ) -> "StorageTelemetry":
+        active_pipeline = pipeline or SyncStoragePipeline()
+        rows = self.get_data()
+        return active_pipeline.write_rows(rows, destination, format_hint=format_hint, storage_options=storage_options)
+
+    async def write_to_storage_async(
+        self,
+        destination: "StorageDestination",
+        *,
+        format_hint: "StorageFormat | None" = None,
+        storage_options: "dict[str, Any] | None" = None,
+        pipeline: "AsyncStoragePipeline | None" = None,
+    ) -> "StorageTelemetry":
+        active_pipeline = pipeline or AsyncStoragePipeline()
+        rows = self.get_data()
+        return await active_pipeline.write_rows(
+            rows, destination, format_hint=format_hint, storage_options=storage_options
+        )
+
 
 @mypyc_attr(allow_interpreted_subclasses=False)
 class ArrowResult(StatementResult):
@@ -769,6 +805,36 @@ class ArrowResult(StatementResult):
 
         return cast("list[dict[str, Any]]", self.data.to_pylist())
 
+    def write_to_storage_sync(
+        self,
+        destination: "StorageDestination",
+        *,
+        format_hint: "StorageFormat | None" = None,
+        storage_options: "dict[str, Any] | None" = None,
+        compression: str | None = None,
+        pipeline: "SyncStoragePipeline | None" = None,
+    ) -> "StorageTelemetry":
+        table = self.get_data()
+        active_pipeline = pipeline or SyncStoragePipeline()
+        return active_pipeline.write_arrow(
+            table, destination, format_hint=format_hint, storage_options=storage_options, compression=compression
+        )
+
+    async def write_to_storage_async(
+        self,
+        destination: "StorageDestination",
+        *,
+        format_hint: "StorageFormat | None" = None,
+        storage_options: "dict[str, Any] | None" = None,
+        compression: str | None = None,
+        pipeline: "AsyncStoragePipeline | None" = None,
+    ) -> "StorageTelemetry":
+        table = self.get_data()
+        active_pipeline = pipeline or AsyncStoragePipeline()
+        return await active_pipeline.write_arrow(
+            table, destination, format_hint=format_hint, storage_options=storage_options, compression=compression
+        )
+
     def __len__(self) -> int:
         """Return number of rows in the Arrow table.
 
@@ -812,6 +878,113 @@ class ArrowResult(StatementResult):
         yield from self.data.to_pylist()
 
 
+class EmptyResult(StatementResult):
+    """Sentinel result used when a stack operation has no driver result."""
+
+    __slots__ = ()
+    _EMPTY_STATEMENT = SQL("-- empty stack result --")
+
+    def __init__(self) -> None:
+        super().__init__(statement=self._EMPTY_STATEMENT, data=[], rows_affected=0)
+
+    def __iter__(self) -> Iterator[Any]:
+        return iter(())
+
+    def is_success(self) -> bool:
+        return True
+
+    def get_data(self) -> list[Any]:
+        return []
+
+
+class StackResult:
+    """Wrapper for per-operation stack results that surfaces driver results directly."""
+
+    __slots__ = ("error", "metadata", "result", "rows_affected", "warning")
+
+    def __init__(
+        self,
+        result: "StatementResult | ArrowResult | None" = None,
+        *,
+        rows_affected: int | None = None,
+        error: Exception | None = None,
+        warning: Any | None = None,
+        metadata: "dict[str, Any] | None" = None,
+    ) -> None:
+        self.result: StatementResult | ArrowResult = result if result is not None else EmptyResult()
+        self.rows_affected = rows_affected if rows_affected is not None else _infer_rows_affected(self.result)
+        self.error = error
+        self.warning = warning
+        self.metadata = dict(metadata) if metadata else None
+
+    def get_result(self) -> "StatementResult | ArrowResult":
+        """Return the underlying driver result."""
+
+        return self.result
+
+    @property
+    def result_type(self) -> str:
+        """Describe the underlying result type (SQL operation, Arrow, or custom)."""
+
+        if isinstance(self.result, ArrowResult):
+            return "ARROW"
+        if isinstance(self.result, SQLResult):
+            return self.result.operation_type.upper()
+        return type(self.result).__name__.upper()
+
+    def is_sql_result(self) -> bool:
+        """Return True when the underlying result is an SQLResult."""
+
+        return isinstance(self.result, StatementResult) and not isinstance(self.result, ArrowResult)
+
+    def is_arrow_result(self) -> bool:
+        """Return True when the underlying result is an ArrowResult."""
+
+        return isinstance(self.result, ArrowResult)
+
+    def is_error(self) -> bool:
+        """Return True when the stack operation captured an error."""
+
+        return self.error is not None
+
+    def with_error(self, error: Exception) -> "StackResult":
+        """Return a copy of the result that records the provided error."""
+
+        return StackResult(
+            result=self.result,
+            rows_affected=self.rows_affected,
+            warning=self.warning,
+            metadata=self.metadata,
+            error=error,
+        )
+
+    @classmethod
+    def from_sql_result(cls, result: "SQLResult") -> "StackResult":
+        """Convert a standard SQLResult into a stack-friendly representation."""
+
+        metadata = dict(result.metadata) if result.metadata else None
+        warning = metadata.get("warning") if metadata else None
+        return cls(result=result, rows_affected=result.rows_affected, warning=warning, metadata=metadata)
+
+    @classmethod
+    def from_arrow_result(cls, result: "ArrowResult") -> "StackResult":
+        """Create a stack result from an ArrowResult instance."""
+
+        metadata = dict(result.metadata) if result.metadata else None
+        return cls(result=result, rows_affected=result.rows_affected, metadata=metadata)
+
+    @classmethod
+    def from_error(cls, error: Exception) -> "StackResult":
+        """Create an error-only stack result."""
+
+        return cls(result=EmptyResult(), rows_affected=0, error=error)
+
+
+def _infer_rows_affected(result: "StatementResult | ArrowResult") -> int:
+    rowcount = getattr(result, "rows_affected", None)
+    return int(rowcount) if isinstance(rowcount, int) else 0
+
+
 def create_sql_result(
     statement: "SQL",
     data: list[dict[str, Any]] | None = None,
