@@ -1,19 +1,22 @@
 """Asynchronous driver protocol implementation."""
 
 from abc import abstractmethod
+from time import perf_counter
 from typing import TYPE_CHECKING, Any, Final, TypeVar, overload
 
-from sqlspec.core import SQL, Statement
-from sqlspec.core.result import create_arrow_result
+from sqlspec.core import SQL, StackResult, Statement, create_arrow_result
+from sqlspec.core.stack import StackOperation, StatementStack
 from sqlspec.driver._common import (
     CommonDriverAttributesMixin,
     DataDictionaryMixin,
     ExecutionResult,
+    StackExecutionObserver,
     VersionInfo,
+    describe_stack_statement,
     handle_single_row_error,
 )
-from sqlspec.driver.mixins import SQLTranslatorMixin
-from sqlspec.exceptions import ImproperConfigurationError
+from sqlspec.driver.mixins import SQLTranslatorMixin, StorageDriverMixin
+from sqlspec.exceptions import ImproperConfigurationError, StackExecutionError
 from sqlspec.utils.arrow_helpers import convert_dict_to_arrow
 from sqlspec.utils.logging import get_logger
 from sqlspec.utils.module_loader import ensure_pyarrow
@@ -23,24 +26,25 @@ if TYPE_CHECKING:
     from contextlib import AbstractAsyncContextManager
 
     from sqlspec.builder import QueryBuilder
-    from sqlspec.core import SQLResult, StatementConfig, StatementFilter
-    from sqlspec.typing import SchemaT, StatementParameters
+    from sqlspec.core import ArrowResult, SQLResult, StatementConfig, StatementFilter
+    from sqlspec.typing import ArrowReturnFormat, SchemaT, StatementParameters
 
-_LOGGER_NAME: Final[str] = "sqlspec"
-logger = get_logger(_LOGGER_NAME)
 
 __all__ = ("AsyncDataDictionaryBase", "AsyncDriverAdapterBase", "AsyncDriverT")
 
 
 EMPTY_FILTERS: Final["list[StatementFilter]"] = []
+_LOGGER_NAME: Final[str] = "sqlspec"
+logger = get_logger(_LOGGER_NAME)
 
 AsyncDriverT = TypeVar("AsyncDriverT", bound="AsyncDriverAdapterBase")
 
 
-class AsyncDriverAdapterBase(CommonDriverAttributesMixin, SQLTranslatorMixin):
+class AsyncDriverAdapterBase(CommonDriverAttributesMixin, SQLTranslatorMixin, StorageDriverMixin):
     """Base class for asynchronous database drivers."""
 
     __slots__ = ()
+    is_async: bool = True
 
     @property
     @abstractmethod
@@ -61,19 +65,58 @@ class AsyncDriverAdapterBase(CommonDriverAttributesMixin, SQLTranslatorMixin):
         Returns:
             The result of the SQL execution
         """
-        async with self.handle_database_exceptions(), self.with_cursor(connection) as cursor:
-            special_result = await self._try_special_handling(cursor, statement)
-            if special_result is not None:
-                return special_result
+        runtime = self.observability
+        compiled_sql, execution_parameters = statement.compile()
+        processed_state = statement.get_processed_state()
+        operation = getattr(processed_state, "operation_type", statement.operation_type)
+        query_context = {
+            "sql": compiled_sql,
+            "parameters": execution_parameters,
+            "driver": type(self).__name__,
+            "operation": operation,
+            "is_many": statement.is_many,
+            "is_script": statement.is_script,
+        }
+        runtime.emit_query_start(**query_context)
+        span = runtime.start_query_span(compiled_sql, operation, type(self).__name__)
+        started = perf_counter()
 
-            if statement.is_script:
-                execution_result = await self._execute_script(cursor, statement)
-            elif statement.is_many:
-                execution_result = await self._execute_many(cursor, statement)
-            else:
-                execution_result = await self._execute_statement(cursor, statement)
+        try:
+            async with self.handle_database_exceptions(), self.with_cursor(connection) as cursor:
+                special_result = await self._try_special_handling(cursor, statement)
+                if special_result is not None:
+                    result = special_result
+                elif statement.is_script:
+                    execution_result = await self._execute_script(cursor, statement)
+                    result = self.build_statement_result(statement, execution_result)
+                elif statement.is_many:
+                    execution_result = await self._execute_many(cursor, statement)
+                    result = self.build_statement_result(statement, execution_result)
+                else:
+                    execution_result = await self._execute_statement(cursor, statement)
+                    result = self.build_statement_result(statement, execution_result)
+        except Exception as exc:  # pragma: no cover
+            runtime.span_manager.end_span(span, error=exc)
+            runtime.emit_error(exc, **query_context)
+            raise
 
-            return self.build_statement_result(statement, execution_result)
+        runtime.span_manager.end_span(span)
+        duration = perf_counter() - started
+        runtime.emit_query_complete(**{**query_context, "rows_affected": result.rows_affected})
+        runtime.emit_statement_event(
+            sql=compiled_sql,
+            parameters=execution_parameters,
+            driver=type(self).__name__,
+            operation=operation,
+            execution_mode=self.statement_config.execution_mode,
+            is_many=statement.is_many,
+            is_script=statement.is_script,
+            rows_affected=result.rows_affected,
+            duration_s=duration,
+            storage_backend=(result.metadata or {}).get("storage_backend") if hasattr(result, "metadata") else None,
+            started_at=started,
+        )
+        return result
 
     @abstractmethod
     def with_cursor(self, connection: Any) -> Any:
@@ -147,6 +190,89 @@ class AsyncDriverAdapterBase(CommonDriverAttributesMixin, SQLTranslatorMixin):
             cursor, statement_count=statement_count, successful_statements=successful_count, is_script_result=True
         )
 
+    async def execute_stack(
+        self, stack: "StatementStack", *, continue_on_error: bool = False
+    ) -> "tuple[StackResult, ...]":
+        """Execute a StatementStack sequentially using the adapter's primitives."""
+
+        if not isinstance(stack, StatementStack):
+            msg = "execute_stack expects a StatementStack instance"
+            raise TypeError(msg)
+        if not stack:
+            msg = "Cannot execute an empty StatementStack"
+            raise ValueError(msg)
+
+        results: list[StackResult] = []
+        single_transaction = not continue_on_error
+
+        with StackExecutionObserver(self, stack, continue_on_error, native_pipeline=False) as observer:
+            started_transaction = False
+
+            try:
+                if single_transaction and not self._connection_in_transaction():
+                    await self.begin()
+                    started_transaction = True
+
+                for index, operation in enumerate(stack.operations):
+                    try:
+                        result = await self._execute_stack_operation(operation)
+                    except Exception as exc:  # pragma: no cover - exercised via tests
+                        stack_error = StackExecutionError(
+                            index,
+                            describe_stack_statement(operation.statement),
+                            exc,
+                            adapter=type(self).__name__,
+                            mode="continue-on-error" if continue_on_error else "fail-fast",
+                        )
+
+                        if started_transaction and not continue_on_error:
+                            try:
+                                await self.rollback()
+                            except Exception as rollback_error:  # pragma: no cover - diagnostics only
+                                logger.debug("Rollback after stack failure failed: %s", rollback_error)
+                            started_transaction = False
+
+                        if continue_on_error:
+                            await self._rollback_after_stack_error_async()
+                            observer.record_operation_error(stack_error)
+                            results.append(StackResult.from_error(stack_error))
+                            continue
+
+                        raise stack_error from exc
+
+                    results.append(StackResult(result=result))
+
+                    if continue_on_error:
+                        await self._commit_after_stack_operation_async()
+
+                if started_transaction:
+                    await self.commit()
+            except Exception:
+                if started_transaction:
+                    try:
+                        await self.rollback()
+                    except Exception as rollback_error:  # pragma: no cover - diagnostics only
+                        logger.debug("Rollback after stack failure failed: %s", rollback_error)
+                raise
+
+        return tuple(results)
+
+    async def _rollback_after_stack_error_async(self) -> None:
+        """Attempt to rollback after a stack operation error (async)."""
+
+        try:
+            await self.rollback()
+        except Exception as rollback_error:  # pragma: no cover - driver-specific cleanup
+            logger.debug("Rollback after stack error failed: %s", rollback_error)
+
+    async def _commit_after_stack_operation_async(self) -> None:
+        """Attempt to commit after a successful stack operation when not batching (async)."""
+
+        try:
+            await self.commit()
+        except Exception as commit_error:  # pragma: no cover - driver-specific cleanup
+            logger.debug("Commit after stack operation failed: %s", commit_error)
+
     @abstractmethod
     async def _execute_many(self, cursor: Any, statement: "SQL") -> ExecutionResult:
         """Execute SQL with multiple parameter sets (executemany).
@@ -351,12 +477,12 @@ class AsyncDriverAdapterBase(CommonDriverAttributesMixin, SQLTranslatorMixin):
         /,
         *parameters: "StatementParameters | StatementFilter",
         statement_config: "StatementConfig | None" = None,
-        return_format: str = "table",
+        return_format: "ArrowReturnFormat" = "table",
         native_only: bool = False,
         batch_size: int | None = None,
         arrow_schema: Any = None,
         **kwargs: Any,
-    ) -> "Any":
+    ) -> "ArrowResult":
         """Execute query and return results as Apache Arrow format (async).
 
         This base implementation uses the conversion path: execute() → dict → Arrow.
@@ -367,10 +493,10 @@ class AsyncDriverAdapterBase(CommonDriverAttributesMixin, SQLTranslatorMixin):
             statement: SQL query string, Statement, or QueryBuilder
             *parameters: Query parameters (same format as execute()/select())
             statement_config: Optional statement configuration override
-            return_format: "table" for pyarrow.Table (default), "reader" for RecordBatchReader,
-                         "batches" for iterator of RecordBatches
+            return_format: "table" for pyarrow.Table (default), "batch" for single RecordBatch,
+                         "batches" for iterator of RecordBatches, "reader" for RecordBatchReader
             native_only: If True, raise error if native Arrow unavailable (default: False)
-            batch_size: Rows per batch for "batches" format (default: None = all rows)
+            batch_size: Rows per batch for "batch"/"batches" format (default: None = all rows)
             arrow_schema: Optional pyarrow.Schema for type casting
             **kwargs: Additional keyword arguments
 
@@ -392,10 +518,8 @@ class AsyncDriverAdapterBase(CommonDriverAttributesMixin, SQLTranslatorMixin):
             ...     "SELECT * FROM users", native_only=True
             ... )
         """
-        # Check pyarrow is available
         ensure_pyarrow()
 
-        # Check if native_only requested but not supported
         if native_only:
             msg = (
                 f"Adapter '{self.__class__.__name__}' does not support native Arrow results. "
@@ -404,15 +528,9 @@ class AsyncDriverAdapterBase(CommonDriverAttributesMixin, SQLTranslatorMixin):
             )
             raise ImproperConfigurationError(msg)
 
-        # Execute query using standard path
         result = await self.execute(statement, *parameters, statement_config=statement_config, **kwargs)
 
-        # Convert dict results to Arrow
-        arrow_data = convert_dict_to_arrow(
-            result.data,
-            return_format=return_format,  # type: ignore[arg-type]
-            batch_size=batch_size,
-        )
+        arrow_data = convert_dict_to_arrow(result.data, return_format=return_format, batch_size=batch_size)
         if arrow_schema is not None:
             import pyarrow as pa
 
@@ -420,7 +538,7 @@ class AsyncDriverAdapterBase(CommonDriverAttributesMixin, SQLTranslatorMixin):
                 msg = f"arrow_schema must be a pyarrow.Schema, got {type(arrow_schema).__name__}"
                 raise TypeError(msg)
 
-            arrow_data = arrow_data.cast(arrow_schema)
+            arrow_data = arrow_data.cast(arrow_schema)  # type: ignore[union-attr]
         return create_arrow_result(
             statement=result.statement,
             data=arrow_data,
@@ -522,6 +640,29 @@ class AsyncDriverAdapterBase(CommonDriverAttributesMixin, SQLTranslatorMixin):
 
         return (select_result.get_data(schema_type=schema_type), count_result.scalar())
 
+    async def _execute_stack_operation(self, operation: "StackOperation") -> "SQLResult | ArrowResult | None":
+        kwargs = dict(operation.keyword_arguments) if operation.keyword_arguments else {}
+
+        if operation.method == "execute":
+            return await self.execute(operation.statement, *operation.arguments, **kwargs)
+
+        if operation.method == "execute_many":
+            if not operation.arguments:
+                msg = "execute_many stack operation requires parameter sets"
+                raise ValueError(msg)
+            parameter_sets = operation.arguments[0]
+            filters = operation.arguments[1:]
+            return await self.execute_many(operation.statement, parameter_sets, *filters, **kwargs)
+
+        if operation.method == "execute_script":
+            return await self.execute_script(operation.statement, *operation.arguments, **kwargs)
+
+        if operation.method == "execute_arrow":
+            return await self.select_to_arrow(operation.statement, *operation.arguments, **kwargs)
+
+        msg = f"Unsupported stack operation method: {operation.method}"
+        raise ValueError(msg)
+
 
 class AsyncDataDictionaryBase(DataDictionaryMixin):
     """Base class for asynchronous data dictionary implementations."""
