@@ -1,24 +1,39 @@
 """Common driver attributes and utilities."""
 
+import hashlib
+import logging
 import re
 from contextlib import suppress
-from typing import TYPE_CHECKING, Any, Final, NamedTuple, NoReturn, Optional, TypeVar, cast
+from time import perf_counter
+from typing import TYPE_CHECKING, Any, Final, Literal, NamedTuple, NoReturn, Optional, TypeVar, cast
 
 from mypy_extensions import trait
 from sqlglot import exp
 
 from sqlspec.builder import QueryBuilder
-from sqlspec.core import SQL, ParameterStyle, SQLResult, Statement, StatementConfig, TypedParameter
-from sqlspec.core.cache import CachedStatement, get_cache, get_cache_config
-from sqlspec.core.splitter import split_sql_script
+from sqlspec.core import (
+    SQL,
+    CachedStatement,
+    ParameterStyle,
+    SQLResult,
+    Statement,
+    StatementConfig,
+    TypedParameter,
+    get_cache,
+    get_cache_config,
+    split_sql_script,
+)
+from sqlspec.core.metrics import StackExecutionMetrics
 from sqlspec.exceptions import ImproperConfigurationError, NotFoundError
-from sqlspec.utils.logging import get_logger
+from sqlspec.utils.logging import get_logger, log_with_context
 from sqlspec.utils.type_guards import is_statement_filter
 
 if TYPE_CHECKING:
     from collections.abc import Sequence
 
-    from sqlspec.core.filters import FilterTypeT, StatementFilter
+    from sqlspec.core import FilterTypeT, StatementFilter
+    from sqlspec.core.stack import StatementStack
+    from sqlspec.observability import ObservabilityRuntime
     from sqlspec.typing import StatementParameters
 
 
@@ -31,8 +46,11 @@ __all__ = (
     "DataDictionaryMixin",
     "ExecutionResult",
     "ScriptExecutionResult",
+    "StackExecutionObserver",
     "VersionInfo",
+    "describe_stack_statement",
     "handle_single_row_error",
+    "hash_stack_operations",
     "make_cache_key_hashable",
 )
 
@@ -97,6 +115,122 @@ def make_cache_key_hashable(obj: Any) -> Any:
     return obj
 
 
+def hash_stack_operations(stack: "StatementStack") -> "tuple[str, ...]":
+    """Return SHA256 fingerprints for statements contained in the stack."""
+
+    hashes: list[str] = []
+    for operation in stack.operations:
+        summary = describe_stack_statement(operation.statement)
+        if not isinstance(summary, str):
+            summary = str(summary)
+        digest = hashlib.sha256(summary.encode("utf-8")).hexdigest()
+        hashes.append(digest[:16])
+    return tuple(hashes)
+
+
+class StackExecutionObserver:
+    """Context manager that aggregates telemetry for stack execution."""
+
+    __slots__ = (
+        "continue_on_error",
+        "driver",
+        "hashed_operations",
+        "metrics",
+        "native_pipeline",
+        "runtime",
+        "span",
+        "stack",
+        "started",
+    )
+
+    def __init__(
+        self,
+        driver: "CommonDriverAttributesMixin",
+        stack: "StatementStack",
+        continue_on_error: bool,
+        native_pipeline: bool,
+    ) -> None:
+        self.driver = driver
+        self.stack = stack
+        self.continue_on_error = continue_on_error
+        self.native_pipeline = native_pipeline
+        self.runtime = driver.observability
+        self.metrics = StackExecutionMetrics(
+            adapter=type(driver).__name__,
+            statement_count=len(stack.operations),
+            continue_on_error=continue_on_error,
+            native_pipeline=native_pipeline,
+            forced_disable=driver.stack_native_disabled,
+        )
+        self.hashed_operations = hash_stack_operations(stack)
+        self.span: Any | None = None
+        self.started = 0.0
+
+    def __enter__(self) -> "StackExecutionObserver":
+        self.started = perf_counter()
+        attributes = {
+            "sqlspec.stack.statement_count": len(self.stack.operations),
+            "sqlspec.stack.continue_on_error": self.continue_on_error,
+            "sqlspec.stack.native_pipeline": self.native_pipeline,
+            "sqlspec.stack.forced_disable": self.driver.stack_native_disabled,
+        }
+        self.span = self.runtime.start_span("sqlspec.stack.execute", attributes=attributes)
+        log_with_context(
+            logger,
+            logging.DEBUG,
+            "stack.execute.start",
+            driver=type(self.driver).__name__,
+            stack_size=len(self.stack.operations),
+            continue_on_error=self.continue_on_error,
+            native_pipeline=self.native_pipeline,
+            forced_disable=self.driver.stack_native_disabled,
+            hashed_operations=self.hashed_operations,
+        )
+        return self
+
+    def __exit__(self, exc_type: Any, exc: Exception | None, exc_tb: Any) -> Literal[False]:
+        duration = perf_counter() - self.started
+        self.metrics.record_duration(duration)
+        if exc is not None:
+            self.metrics.record_error(exc)
+        self.runtime.span_manager.end_span(self.span, error=exc if exc is not None else None)
+        self.metrics.emit(self.runtime)
+        level = logging.ERROR if exc is not None else logging.DEBUG
+        log_with_context(
+            logger,
+            level,
+            "stack.execute.failed" if exc is not None else "stack.execute.complete",
+            driver=type(self.driver).__name__,
+            stack_size=len(self.stack.operations),
+            continue_on_error=self.continue_on_error,
+            native_pipeline=self.native_pipeline,
+            forced_disable=self.driver.stack_native_disabled,
+            hashed_operations=self.hashed_operations,
+            duration_s=duration,
+            error_type=type(exc).__name__ if exc is not None else None,
+        )
+        return False
+
+    def record_operation_error(self, error: Exception) -> None:
+        """Record an operation error when continue-on-error is enabled."""
+
+        self.metrics.record_operation_error(error)
+
+
+def describe_stack_statement(statement: Any) -> str:
+    """Return a readable representation of a stack statement for diagnostics."""
+
+    if isinstance(statement, str):
+        return statement
+    raw_sql = getattr(statement, "raw_sql", None)
+    if isinstance(raw_sql, str):
+        return raw_sql
+    sql_attr = getattr(statement, "sql", None)
+    if isinstance(sql_attr, str):
+        return sql_attr
+    return repr(statement)
+
+
 def handle_single_row_error(error: ValueError) -> "NoReturn":
     """Normalize single-row selection errors to SQLSpec exceptions."""
 
@@ -175,12 +309,7 @@ class DataDictionaryMixin:
         Returns:
             VersionInfo instance or None if parsing fails
         """
-        # Try common version patterns
-        patterns = [
-            r"(\d+)\.(\d+)\.(\d+)",  # x.y.z
-            r"(\d+)\.(\d+)",  # x.y
-            r"(\d+)",  # x
-        ]
+        patterns = [r"(\d+)\.(\d+)\.(\d+)", r"(\d+)\.(\d+)", r"(\d+)"]
 
         for pattern in patterns:
             match = re.search(pattern, version_str)
@@ -283,13 +412,17 @@ DEFAULT_EXECUTION_RESULT: Final[tuple[Any, int | None, Any]] = (None, None, None
 class CommonDriverAttributesMixin:
     """Common attributes and methods for driver adapters."""
 
-    __slots__ = ("connection", "driver_features", "statement_config")
+    __slots__ = ("_observability", "connection", "driver_features", "statement_config")
     connection: "Any"
     statement_config: "StatementConfig"
     driver_features: "dict[str, Any]"
 
     def __init__(
-        self, connection: "Any", statement_config: "StatementConfig", driver_features: "dict[str, Any] | None" = None
+        self,
+        connection: "Any",
+        statement_config: "StatementConfig",
+        driver_features: "dict[str, Any] | None" = None,
+        observability: "ObservabilityRuntime | None" = None,
     ) -> None:
         """Initialize driver adapter with connection and configuration.
 
@@ -297,10 +430,33 @@ class CommonDriverAttributesMixin:
             connection: Database connection instance
             statement_config: Statement configuration for the driver
             driver_features: Driver-specific features like extensions, secrets, and connection callbacks
+            observability: Optional runtime handling lifecycle hooks, observers, and spans
         """
         self.connection = connection
         self.statement_config = statement_config
         self.driver_features = driver_features or {}
+        self._observability = observability
+
+    def attach_observability(self, runtime: "ObservabilityRuntime") -> None:
+        """Attach or replace the observability runtime."""
+
+        self._observability = runtime
+
+    @property
+    def observability(self) -> "ObservabilityRuntime":
+        """Return the observability runtime, creating a disabled instance when absent."""
+
+        if self._observability is None:
+            from sqlspec.observability import ObservabilityRuntime
+
+            self._observability = ObservabilityRuntime(config_name=type(self).__name__)
+        return self._observability
+
+    @property
+    def stack_native_disabled(self) -> bool:
+        """Return True when native stack execution is disabled for this driver."""
+
+        return bool(self.driver_features.get("stack_native_disabled", False))
 
     def create_execution_result(
         self,
@@ -492,6 +648,31 @@ class CommonDriverAttributesMixin:
 
         return sql_statement
 
+    def _connection_in_transaction(self) -> bool:
+        """Best-effort detection of whether the underlying connection is inside a transaction."""
+
+        connection = getattr(self, "connection", None)
+        if connection is None:
+            return False
+
+        indicator = getattr(connection, "in_transaction", None)
+        if isinstance(indicator, bool):
+            return indicator
+
+        checker = getattr(connection, "is_in_transaction", None)
+        if callable(checker):
+            try:
+                return bool(checker())
+            except Exception:  # pragma: no cover - driver-specific edge cases
+                return False
+
+        status = getattr(connection, "transaction_status", None)
+        if isinstance(status, str):
+            lowered = status.lower()
+            return "idle" not in lowered
+
+        return False
+
     def split_script_statements(
         self, script: str, statement_config: "StatementConfig", strip_trailing_semicolon: bool = False
     ) -> list[str]:
@@ -662,7 +843,10 @@ class CommonDriverAttributesMixin:
         compiled_sql, execution_parameters = prepared_statement.compile()
 
         prepared_parameters = self.prepare_driver_parameters(
-            execution_parameters, statement_config, is_many=statement.is_many, prepared_statement=statement
+            execution_parameters,
+            statement_config,
+            is_many=prepared_statement.is_many,
+            prepared_statement=prepared_statement,
         )
 
         if statement_config.parameter_config.output_transformer:
@@ -685,7 +869,7 @@ class CommonDriverAttributesMixin:
                         else prepared_parameters
                     )
                 ),
-                expression=statement.expression,
+                expression=prepared_statement.expression,
             )
             cache.put("statement", cache_key, cached_statement, str(statement.dialect) if statement.dialect else None)
 
@@ -699,18 +883,16 @@ class CommonDriverAttributesMixin:
         Creates a deterministic cache key that includes all factors that affect SQL compilation,
         preventing cache contamination between different compilation contexts.
         """
-        context_hash = hash(
-            (
-                config.parameter_config.hash(),
-                config.dialect,
-                statement.is_script,
-                statement.is_many,
-                flatten_single_parameters,
-                bool(config.parameter_config.output_transformer),
-                bool(config.parameter_config.ast_transformer),
-                bool(config.parameter_config.needs_static_script_compilation),
-            )
-        )
+        context_hash = hash((
+            config.parameter_config.hash(),
+            config.dialect,
+            statement.is_script,
+            statement.is_many,
+            flatten_single_parameters,
+            bool(config.parameter_config.output_transformer),
+            bool(config.parameter_config.ast_transformer),
+            bool(config.parameter_config.needs_static_script_compilation),
+        ))
 
         params = statement.parameters
 
@@ -803,6 +985,13 @@ class CommonDriverAttributesMixin:
         expr = original_sql.expression
 
         if isinstance(expr, exp.Select):
+            if not expr.args.get("from"):
+                msg = (
+                    "Cannot create COUNT query: SELECT statement missing FROM clause. "
+                    "COUNT queries require a FROM clause to determine which table to count rows from."
+                )
+                raise ImproperConfigurationError(msg)
+
             if expr.args.get("group"):
                 subquery = expr.subquery(alias="grouped_data")
                 count_expr = exp.select(exp.Count(this=exp.Star())).from_(subquery)
