@@ -2,5 +2,6 @@
 
 from sqlspec.driver.mixins._result_tools import ToSchemaMixin
 from sqlspec.driver.mixins._sql_translator import SQLTranslatorMixin
+from sqlspec.driver.mixins._storage import StorageDriverMixin
 
-__all__ = ("SQLTranslatorMixin", "ToSchemaMixin")
+__all__ = ("SQLTranslatorMixin", "StorageDriverMixin", "ToSchemaMixin")
