@@ -1,31 +1,57 @@
-"""Migration execution engine for SQLSpec.
-
-This module provides separate sync and async migration runners with clean separation
-of concerns and proper type safety.
-"""
+"""Migration execution engine for SQLSpec."""
 
+import ast
+import hashlib
 import inspect
+import re
 import time
 from abc import ABC, abstractmethod
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Literal, Union, cast, overload
 
-from sqlspec.core.statement import SQL
+from sqlspec.core import SQL
 from sqlspec.migrations.context import MigrationContext
 from sqlspec.migrations.loaders import get_migration_loader
+from sqlspec.migrations.templates import TemplateDescriptionHints
 from sqlspec.utils.logging import get_logger
 from sqlspec.utils.sync_tools import async_, await_
+from sqlspec.utils.version import parse_version
 
 if TYPE_CHECKING:
     from collections.abc import Awaitable, Callable, Coroutine
 
     from sqlspec.driver import AsyncDriverAdapterBase, SyncDriverAdapterBase
+    from sqlspec.observability import ObservabilityRuntime
 
 __all__ = ("AsyncMigrationRunner", "SyncMigrationRunner", "create_migration_runner")
 
 logger = get_logger("migrations.runner")
 
 
+class _CachedMigrationMetadata:
+    """Cached migration metadata keyed by file path."""
+
+    __slots__ = ("metadata", "mtime_ns", "size")
+
+    def __init__(self, metadata: "dict[str, Any]", mtime_ns: int, size: int) -> None:
+        self.metadata = metadata
+        self.mtime_ns = mtime_ns
+        self.size = size
+
+    def clone(self) -> "dict[str, Any]":
+        return dict(self.metadata)
+
+
+class _MigrationFileEntry:
+    """Represents a migration file discovered during directory scanning."""
+
+    __slots__ = ("extension_name", "path")
+
+    def __init__(self, path: Path, extension_name: "str | None") -> None:
+        self.path = path
+        self.extension_name = extension_name
+
+
 class BaseMigrationRunner(ABC):
     """Base migration runner with common functionality shared between sync and async implementations."""
 
@@ -35,6 +61,8 @@ class BaseMigrationRunner(ABC):
         extension_migrations: "dict[str, Path] | None" = None,
         context: "MigrationContext | None" = None,
         extension_configs: "dict[str, dict[str, Any]] | None" = None,
+        runtime: "ObservabilityRuntime | None" = None,
+        description_hints: "TemplateDescriptionHints | None" = None,
     ) -> None:
         """Initialize the migration runner.
 
@@ -43,15 +71,125 @@ class BaseMigrationRunner(ABC):
             extension_migrations: Optional mapping of extension names to their migration paths.
             context: Optional migration context for Python migrations.
             extension_configs: Optional mapping of extension names to their configurations.
+            runtime: Observability runtime shared with command/context consumers.
+            description_hints: Hints for extracting migration descriptions.
         """
         self.migrations_path = migrations_path
         self.extension_migrations = extension_migrations or {}
         from sqlspec.loader import SQLFileLoader
 
-        self.loader = SQLFileLoader()
+        self.runtime = runtime
+        self.loader = SQLFileLoader(runtime=runtime)
         self.project_root: Path | None = None
         self.context = context
         self.extension_configs = extension_configs or {}
+        self._listing_digest: str | None = None
+        self._listing_cache: list[tuple[str, Path]] | None = None
+        self._listing_signatures: dict[str, tuple[int, int]] = {}
+        self._metadata_cache: dict[str, _CachedMigrationMetadata] = {}
+        self.description_hints = description_hints or TemplateDescriptionHints()
+
+    def _metric(self, name: str, amount: float = 1.0) -> None:
+        if self.runtime is None:
+            return
+        self.runtime.increment_metric(name, amount)
+
+    def _iter_directory_entries(self, base_path: Path, extension_name: "str | None") -> "list[_MigrationFileEntry]":
+        """Collect migration files discovered under a base path."""
+
+        if not base_path.exists():
+            return []
+
+        entries: list[_MigrationFileEntry] = []
+        for pattern in ("*.sql", "*.py"):
+            for file_path in sorted(base_path.glob(pattern)):
+                if file_path.name.startswith("."):
+                    continue
+                entries.append(_MigrationFileEntry(path=file_path, extension_name=extension_name))
+        return entries
+
+    def _collect_listing_entries(self) -> "tuple[list[_MigrationFileEntry], dict[str, tuple[int, int]], str]":
+        """Gather migration files, stat signatures, and digest for cache validation."""
+
+        entries: list[_MigrationFileEntry] = []
+        signatures: dict[str, tuple[int, int]] = {}
+        digest_source = hashlib.md5(usedforsecurity=False)
+
+        for entry in self._iter_directory_entries(self.migrations_path, None):
+            self._record_entry(entry, entries, signatures, digest_source)
+
+        for ext_name, ext_path in self.extension_migrations.items():
+            for entry in self._iter_directory_entries(ext_path, ext_name):
+                self._record_entry(entry, entries, signatures, digest_source)
+
+        return entries, signatures, digest_source.hexdigest()
+
+    def _record_entry(
+        self,
+        entry: _MigrationFileEntry,
+        entries: "list[_MigrationFileEntry]",
+        signatures: "dict[str, tuple[int, int]]",
+        digest_source: Any,
+    ) -> None:
+        """Record entry metadata for cache decisions."""
+
+        try:
+            stat_result = entry.path.stat()
+        except FileNotFoundError:
+            return
+
+        path_str = str(entry.path)
+        token = (stat_result.st_mtime_ns, stat_result.st_size)
+        signatures[path_str] = token
+        digest_source.update(path_str.encode("utf-8"))
+        digest_source.update(f"{token[0]}:{token[1]}".encode())
+        entries.append(entry)
+
+    def _build_sorted_listing(self, entries: "list[_MigrationFileEntry]") -> "list[tuple[str, Path]]":
+        """Construct sorted migration listing from directory entries."""
+
+        migrations: list[tuple[str, Path]] = []
+
+        for entry in entries:
+            version = self._extract_version(entry.path.name)
+            if not version:
+                continue
+            if entry.extension_name:
+                version = f"ext_{entry.extension_name}_{version}"
+            migrations.append((version, entry.path))
+
+        def version_sort_key(migration_tuple: "tuple[str, Path]") -> "Any":
+            version_str = migration_tuple[0]
+            try:
+                return parse_version(version_str)
+            except ValueError:
+                return version_str
+
+        return sorted(migrations, key=version_sort_key)
+
+    def _log_listing_invalidation(
+        self, previous: "dict[str, tuple[int, int]]", current: "dict[str, tuple[int, int]]"
+    ) -> None:
+        """Log cache invalidation details at INFO level."""
+
+        prev_keys = set(previous)
+        curr_keys = set(current)
+        added = curr_keys - prev_keys
+        removed = prev_keys - curr_keys
+        modified = {key for key in prev_keys & curr_keys if previous[key] != current[key]}
+        logger.info(
+            "Migration listing cache invalidated (added=%d, removed=%d, modified=%d)",
+            len(added),
+            len(removed),
+            len(modified),
+        )
+        self._metric("migrations.listing.cache_invalidations")
+        if added:
+            self._metric("migrations.listing.added", float(len(added)))
+        if removed:
+            self._metric("migrations.listing.removed", float(len(removed)))
+        if modified:
+            self._metric("migrations.listing.modified", float(len(modified)))
 
     def _extract_version(self, filename: str) -> "str | None":
         """Extract version from filename.
@@ -95,9 +233,6 @@ class BaseMigrationRunner(ABC):
         Returns:
             MD5 checksum hex string.
         """
-        import hashlib
-        import re
-
         canonical_content = re.sub(r"^--\s*name:\s*migrate-[^-]+-(?:up|down)\s*$", "", content, flags=re.MULTILINE)
 
         return hashlib.md5(canonical_content.encode()).hexdigest()  # noqa: S324
@@ -114,57 +249,38 @@ class BaseMigrationRunner(ABC):
             For async implementations, returns a coroutine.
         """
 
-    def _get_migration_files_sync(self) -> "list[tuple[str, Path]]":
-        """Get all migration files sorted by version.
+    def _load_migration_listing(self) -> "list[tuple[str, Path]]":
+        """Build the cached migration listing shared by sync/async runners."""
+        entries, signatures, digest = self._collect_listing_entries()
+        cached_listing = self._listing_cache
 
-        Returns:
-            List of tuples containing (version, file_path).
-        """
+        if cached_listing is not None and self._listing_digest == digest:
+            self._metric("migrations.listing.cache_hit")
+            self._metric("migrations.listing.files_cached", float(len(cached_listing)))
+            logger.debug("Migration listing cache hit (%d files)", len(cached_listing))
+            return cached_listing
 
-        migrations = []
+        files = self._build_sorted_listing(entries)
+        previous_digest = self._listing_digest
+        previous_signatures = self._listing_signatures
 
-        # Scan primary migration path
-        if self.migrations_path.exists():
-            for pattern in ("*.sql", "*.py"):
-                for file_path in self.migrations_path.glob(pattern):
-                    if file_path.name.startswith("."):
-                        continue
-                    version = self._extract_version(file_path.name)
-                    if version:
-                        migrations.append((version, file_path))
+        self._metric("migrations.listing.cache_miss")
+        self._metric("migrations.listing.files_scanned", float(len(files)))
 
-        # Scan extension migration paths
-        for ext_name, ext_path in self.extension_migrations.items():
-            if ext_path.exists():
-                for pattern in ("*.sql", "*.py"):
-                    for file_path in ext_path.glob(pattern):
-                        if file_path.name.startswith("."):
-                            continue
-                        # Prefix extension migrations to avoid version conflicts
-                        version = self._extract_version(file_path.name)
-                        if version:
-                            # Use ext_ prefix to distinguish extension migrations
-                            prefixed_version = f"ext_{ext_name}_{version}"
-                            migrations.append((prefixed_version, file_path))
+        self._listing_cache = files
+        self._listing_signatures = signatures
+        self._listing_digest = digest
 
-        from sqlspec.utils.version import parse_version
+        if previous_digest is None:
+            logger.debug("Primed migration listing cache with %d files", len(files))
+        else:
+            self._log_listing_invalidation(previous_signatures, signatures)
 
-        def version_sort_key(migration_tuple: "tuple[str, Path]") -> "Any":
-            version_str = migration_tuple[0]
-            try:
-                return parse_version(version_str)
-            except ValueError:
-                return version_str
+        return files
 
-        return sorted(migrations, key=version_sort_key)
-
-    def get_migration_files(self) -> "list[tuple[str, Path]]":
-        """Get all migration files sorted by version.
-
-        Returns:
-            List of (version, path) tuples sorted by version.
-        """
-        return self._get_migration_files_sync()
+    @abstractmethod
+    def get_migration_files(self) -> "list[tuple[str, Path]] | Awaitable[list[tuple[str, Path]]]":
+        """Get all migration files sorted by version."""
 
     def _load_migration_metadata_common(self, file_path: Path, version: "str | None" = None) -> "dict[str, Any]":
         """Load common migration metadata that doesn't require async operations.
@@ -176,13 +292,30 @@ class BaseMigrationRunner(ABC):
         Returns:
             Partial migration metadata dictionary.
         """
-        import re
+        cache_key = str(file_path)
+        stat_result = file_path.stat()
+        cached_metadata = self._metadata_cache.get(cache_key)
+        if (
+            cached_metadata
+            and cached_metadata.mtime_ns == stat_result.st_mtime_ns
+            and cached_metadata.size == stat_result.st_size
+        ):
+            self._metric("migrations.metadata.cache_hit")
+            logger.debug("Migration metadata cache hit: %s", cache_key)
+            metadata = cached_metadata.clone()
+            metadata["file_path"] = file_path
+            return metadata
+
+        self._metric("migrations.metadata.cache_miss")
+        self._metric("migrations.metadata.bytes", float(stat_result.st_size))
 
         content = file_path.read_text(encoding="utf-8")
         checksum = self._calculate_checksum(content)
         if version is None:
             version = self._extract_version(file_path.name)
-        description = file_path.stem.split("_", 1)[1] if "_" in file_path.stem else ""
+        description = self._extract_description(content, file_path)
+        if not description:
+            description = file_path.stem.split("_", 1)[1] if "_" in file_path.stem else ""
 
         transactional_match = re.search(
             r"^--\s*transactional:\s*(true|false)\s*$", content, re.MULTILINE | re.IGNORECASE
@@ -191,7 +324,7 @@ class BaseMigrationRunner(ABC):
         if transactional_match:
             transactional = transactional_match.group(1).lower() == "true"
 
-        return {
+        metadata = {
             "version": version,
             "description": description,
             "file_path": file_path,
@@ -199,6 +332,57 @@ class BaseMigrationRunner(ABC):
             "content": content,
             "transactional": transactional,
         }
+        self._metadata_cache[cache_key] = _CachedMigrationMetadata(
+            metadata=dict(metadata), mtime_ns=stat_result.st_mtime_ns, size=stat_result.st_size
+        )
+        if cached_metadata:
+            logger.info("Migration metadata cache invalidated: %s", cache_key)
+        else:
+            logger.debug("Cached migration metadata: %s", cache_key)
+        return metadata
+
+    def _extract_description(self, content: str, file_path: Path) -> str:
+        if file_path.suffix == ".sql":
+            return self._extract_sql_description(content)
+        if file_path.suffix == ".py":
+            return self._extract_python_description(content)
+        return ""
+
+    def _extract_sql_description(self, content: str) -> str:
+        keys = self.description_hints.sql_keys
+        for line in content.splitlines():
+            stripped = line.strip()
+            if not stripped:
+                continue
+            if stripped.startswith("--"):
+                body = stripped.lstrip("-").strip()
+                if not body:
+                    continue
+                if ":" in body:
+                    key, value = body.split(":", 1)
+                    if key.strip() in keys:
+                        return value.strip()
+                continue
+            break
+        return ""
+
+    def _extract_python_description(self, content: str) -> str:
+        try:
+            module = ast.parse(content)
+        except SyntaxError:
+            return ""
+        docstring = ast.get_docstring(module) or ""
+        keys = self.description_hints.python_keys
+        for line in docstring.splitlines():
+            stripped = line.strip()
+            if not stripped:
+                continue
+            if ":" in stripped:
+                key, value = stripped.split(":", 1)
+                if key.strip() in keys:
+                    return value.strip()
+            return stripped
+        return ""
 
     def _get_context_for_migration(self, file_path: Path) -> "MigrationContext | None":
         """Get the appropriate context for a migration file.
@@ -263,6 +447,14 @@ class BaseMigrationRunner(ABC):
 class SyncMigrationRunner(BaseMigrationRunner):
     """Synchronous migration runner with pure sync methods."""
 
+    def get_migration_files(self) -> "list[tuple[str, Path]]":
+        """Get all migration files sorted by version.
+
+        Returns:
+            List of (version, path) tuples sorted by version.
+        """
+        return self._load_migration_listing()
+
     def load_migration(self, file_path: Path, version: "str | None" = None) -> "dict[str, Any]":
         """Load a migration file and extract its components.
 
@@ -287,7 +479,7 @@ class SyncMigrationRunner(BaseMigrationRunner):
             has_upgrade, has_downgrade = self.loader.has_query(up_query), self.loader.has_query(down_query)
         else:
             try:
-                has_downgrade = bool(self._get_migration_sql_sync({"loader": loader, "file_path": file_path}, "down"))
+                has_downgrade = bool(self._get_migration_sql({"loader": loader, "file_path": file_path}, "down"))
             except Exception:
                 has_downgrade = False
 
@@ -313,36 +505,55 @@ class SyncMigrationRunner(BaseMigrationRunner):
         Returns:
             Tuple of (sql_content, execution_time_ms).
         """
-        upgrade_sql_list = self._get_migration_sql_sync(migration, "up")
+        upgrade_sql_list = self._get_migration_sql(migration, "up")
         if upgrade_sql_list is None:
+            self._metric("migrations.upgrade.skipped")
             return None, 0
 
         if use_transaction is None:
             config = self.context.config if self.context else None
             use_transaction = self.should_use_transaction(migration, config) if config else False
 
-        start_time = time.time()
+        runtime = self.runtime
+        span = None
+        if runtime is not None:
+            version = cast("str | None", migration.get("version"))
+            span = runtime.start_migration_span("upgrade", version=version)
+            runtime.increment_metric("migrations.upgrade.invocations")
 
-        if use_transaction:
-            try:
+        start_time = time.perf_counter()
+        execution_time = 0
+
+        try:
+            if use_transaction:
                 driver.begin()
                 for sql_statement in upgrade_sql_list:
                     if sql_statement.strip():
                         driver.execute_script(sql_statement)
-                execution_time = int((time.time() - start_time) * 1000)
+                execution_time = int((time.perf_counter() - start_time) * 1000)
                 if on_success:
                     on_success(execution_time)
                 driver.commit()
-            except Exception:
+            else:
+                for sql_statement in upgrade_sql_list:
+                    if sql_statement.strip():
+                        driver.execute_script(sql_statement)
+                execution_time = int((time.perf_counter() - start_time) * 1000)
+                if on_success:
+                    on_success(execution_time)
+        except Exception as exc:
+            if use_transaction:
                 driver.rollback()
-                raise
-        else:
-            for sql_statement in upgrade_sql_list:
-                if sql_statement.strip():
-                    driver.execute_script(sql_statement)
-            execution_time = int((time.time() - start_time) * 1000)
-            if on_success:
-                on_success(execution_time)
+            if runtime is not None:
+                duration_ms = int((time.perf_counter() - start_time) * 1000)
+                runtime.increment_metric("migrations.upgrade.errors")
+                runtime.end_migration_span(span, duration_ms=duration_ms, error=exc)
+            raise
+
+        if runtime is not None:
+            runtime.increment_metric("migrations.upgrade.applied")
+            runtime.increment_metric("migrations.upgrade.duration_ms", float(execution_time))
+            runtime.end_migration_span(span, duration_ms=execution_time)
 
         return None, execution_time
 
@@ -365,40 +576,59 @@ class SyncMigrationRunner(BaseMigrationRunner):
         Returns:
             Tuple of (sql_content, execution_time_ms).
         """
-        downgrade_sql_list = self._get_migration_sql_sync(migration, "down")
+        downgrade_sql_list = self._get_migration_sql(migration, "down")
         if downgrade_sql_list is None:
+            self._metric("migrations.downgrade.skipped")
             return None, 0
 
         if use_transaction is None:
             config = self.context.config if self.context else None
             use_transaction = self.should_use_transaction(migration, config) if config else False
 
-        start_time = time.time()
+        runtime = self.runtime
+        span = None
+        if runtime is not None:
+            version = cast("str | None", migration.get("version"))
+            span = runtime.start_migration_span("downgrade", version=version)
+            runtime.increment_metric("migrations.downgrade.invocations")
 
-        if use_transaction:
-            try:
+        start_time = time.perf_counter()
+        execution_time = 0
+
+        try:
+            if use_transaction:
                 driver.begin()
                 for sql_statement in downgrade_sql_list:
                     if sql_statement.strip():
                         driver.execute_script(sql_statement)
-                execution_time = int((time.time() - start_time) * 1000)
+                execution_time = int((time.perf_counter() - start_time) * 1000)
                 if on_success:
                     on_success(execution_time)
                 driver.commit()
-            except Exception:
+            else:
+                for sql_statement in downgrade_sql_list:
+                    if sql_statement.strip():
+                        driver.execute_script(sql_statement)
+                execution_time = int((time.perf_counter() - start_time) * 1000)
+                if on_success:
+                    on_success(execution_time)
+        except Exception as exc:
+            if use_transaction:
                 driver.rollback()
-                raise
-        else:
-            for sql_statement in downgrade_sql_list:
-                if sql_statement.strip():
-                    driver.execute_script(sql_statement)
-            execution_time = int((time.time() - start_time) * 1000)
-            if on_success:
-                on_success(execution_time)
+            if runtime is not None:
+                duration_ms = int((time.perf_counter() - start_time) * 1000)
+                runtime.increment_metric("migrations.downgrade.errors")
+                runtime.end_migration_span(span, duration_ms=duration_ms, error=exc)
+            raise
+
+        if runtime is not None:
+            runtime.increment_metric("migrations.downgrade.applied")
+            runtime.increment_metric("migrations.downgrade.duration_ms", float(execution_time))
+            runtime.end_migration_span(span, duration_ms=execution_time)
 
         return None, execution_time
 
-    def _get_migration_sql_sync(self, migration: "dict[str, Any]", direction: str) -> "list[str] | None":
+    def _get_migration_sql(self, migration: "dict[str, Any]", direction: str) -> "list[str] | None":
         """Get migration SQL for given direction (sync version).
 
         Args:
@@ -475,13 +705,13 @@ class SyncMigrationRunner(BaseMigrationRunner):
 class AsyncMigrationRunner(BaseMigrationRunner):
     """Asynchronous migration runner with pure async methods."""
 
-    async def get_migration_files(self) -> "list[tuple[str, Path]]":  # type: ignore[override]
+    async def get_migration_files(self) -> "list[tuple[str, Path]]":
         """Get all migration files sorted by version.
 
         Returns:
             List of (version, path) tuples sorted by version.
         """
-        return self._get_migration_files_sync()
+        return await async_(self._load_migration_listing)()
 
     async def load_migration(self, file_path: Path, version: "str | None" = None) -> "dict[str, Any]":
         """Load a migration file and extract its components.
@@ -537,34 +767,53 @@ class AsyncMigrationRunner(BaseMigrationRunner):
         """
         upgrade_sql_list = await self._get_migration_sql_async(migration, "up")
         if upgrade_sql_list is None:
+            self._metric("migrations.upgrade.skipped")
             return None, 0
 
         if use_transaction is None:
             config = self.context.config if self.context else None
             use_transaction = self.should_use_transaction(migration, config) if config else False
 
-        start_time = time.time()
+        runtime = self.runtime
+        span = None
+        if runtime is not None:
+            version = cast("str | None", migration.get("version"))
+            span = runtime.start_migration_span("upgrade", version=version)
+            runtime.increment_metric("migrations.upgrade.invocations")
 
-        if use_transaction:
-            try:
+        start_time = time.perf_counter()
+        execution_time = 0
+
+        try:
+            if use_transaction:
                 await driver.begin()
                 for sql_statement in upgrade_sql_list:
                     if sql_statement.strip():
                         await driver.execute_script(sql_statement)
-                execution_time = int((time.time() - start_time) * 1000)
+                execution_time = int((time.perf_counter() - start_time) * 1000)
                 if on_success:
                     await on_success(execution_time)
                 await driver.commit()
-            except Exception:
+            else:
+                for sql_statement in upgrade_sql_list:
+                    if sql_statement.strip():
+                        await driver.execute_script(sql_statement)
+                execution_time = int((time.perf_counter() - start_time) * 1000)
+                if on_success:
+                    await on_success(execution_time)
+        except Exception as exc:
+            if use_transaction:
                 await driver.rollback()
-                raise
-        else:
-            for sql_statement in upgrade_sql_list:
-                if sql_statement.strip():
-                    await driver.execute_script(sql_statement)
-            execution_time = int((time.time() - start_time) * 1000)
-            if on_success:
-                await on_success(execution_time)
+            if runtime is not None:
+                duration_ms = int((time.perf_counter() - start_time) * 1000)
+                runtime.increment_metric("migrations.upgrade.errors")
+                runtime.end_migration_span(span, duration_ms=duration_ms, error=exc)
+            raise
+
+        if runtime is not None:
+            runtime.increment_metric("migrations.upgrade.applied")
+            runtime.increment_metric("migrations.upgrade.duration_ms", float(execution_time))
+            runtime.end_migration_span(span, duration_ms=execution_time)
 
         return None, execution_time
 
@@ -589,34 +838,53 @@ class AsyncMigrationRunner(BaseMigrationRunner):
         """
         downgrade_sql_list = await self._get_migration_sql_async(migration, "down")
         if downgrade_sql_list is None:
+            self._metric("migrations.downgrade.skipped")
             return None, 0
 
         if use_transaction is None:
             config = self.context.config if self.context else None
             use_transaction = self.should_use_transaction(migration, config) if config else False
 
-        start_time = time.time()
+        runtime = self.runtime
+        span = None
+        if runtime is not None:
+            version = cast("str | None", migration.get("version"))
+            span = runtime.start_migration_span("downgrade", version=version)
+            runtime.increment_metric("migrations.downgrade.invocations")
 
-        if use_transaction:
-            try:
+        start_time = time.perf_counter()
+        execution_time = 0
+
+        try:
+            if use_transaction:
                 await driver.begin()
                 for sql_statement in downgrade_sql_list:
                     if sql_statement.strip():
                         await driver.execute_script(sql_statement)
-                execution_time = int((time.time() - start_time) * 1000)
+                execution_time = int((time.perf_counter() - start_time) * 1000)
                 if on_success:
                     await on_success(execution_time)
                 await driver.commit()
-            except Exception:
+            else:
+                for sql_statement in downgrade_sql_list:
+                    if sql_statement.strip():
+                        await driver.execute_script(sql_statement)
+                execution_time = int((time.perf_counter() - start_time) * 1000)
+                if on_success:
+                    await on_success(execution_time)
+        except Exception as exc:
+            if use_transaction:
                 await driver.rollback()
-                raise
-        else:
-            for sql_statement in downgrade_sql_list:
-                if sql_statement.strip():
-                    await driver.execute_script(sql_statement)
-            execution_time = int((time.time() - start_time) * 1000)
-            if on_success:
-                await on_success(execution_time)
+            if runtime is not None:
+                duration_ms = int((time.perf_counter() - start_time) * 1000)
+                runtime.increment_metric("migrations.downgrade.errors")
+                runtime.end_migration_span(span, duration_ms=duration_ms, error=exc)
+            raise
+
+        if runtime is not None:
+            runtime.increment_metric("migrations.downgrade.applied")
+            runtime.increment_metric("migrations.downgrade.duration_ms", float(execution_time))
+            runtime.end_migration_span(span, duration_ms=execution_time)
 
         return None, execution_time
 
@@ -697,6 +965,8 @@ def create_migration_runner(
     context: "MigrationContext | None",
     extension_configs: "dict[str, Any]",
     is_async: "Literal[False]" = False,
+    runtime: "ObservabilityRuntime | None" = None,
+    description_hints: "TemplateDescriptionHints | None" = None,
 ) -> SyncMigrationRunner: ...
 
 
@@ -707,6 +977,8 @@ def create_migration_runner(
     context: "MigrationContext | None",
     extension_configs: "dict[str, Any]",
     is_async: "Literal[True]",
+    runtime: "ObservabilityRuntime | None" = None,
+    description_hints: "TemplateDescriptionHints | None" = None,
 ) -> AsyncMigrationRunner: ...
 
 
@@ -716,6 +988,8 @@ def create_migration_runner(
     context: "MigrationContext | None",
     extension_configs: "dict[str, Any]",
     is_async: bool = False,
+    runtime: "ObservabilityRuntime | None" = None,
+    description_hints: "TemplateDescriptionHints | None" = None,
 ) -> "SyncMigrationRunner | AsyncMigrationRunner":
     """Factory function to create the appropriate migration runner.
 
@@ -725,10 +999,26 @@ def create_migration_runner(
         context: Migration context.
         extension_configs: Extension configurations.
         is_async: Whether to create async or sync runner.
+        runtime: Observability runtime shared with loaders and execution steps.
+        description_hints: Optional description extraction hints from template profiles.
 
     Returns:
         Appropriate migration runner instance.
     """
     if is_async:
-        return AsyncMigrationRunner(migrations_path, extension_migrations, context, extension_configs)
-    return SyncMigrationRunner(migrations_path, extension_migrations, context, extension_configs)
+        return AsyncMigrationRunner(
+            migrations_path,
+            extension_migrations,
+            context,
+            extension_configs,
+            runtime=runtime,
+            description_hints=description_hints,
+        )
+    return SyncMigrationRunner(
+        migrations_path,
+        extension_migrations,
+        context,
+        extension_configs,
+        runtime=runtime,
+        description_hints=description_hints,
+    )
