@@ -11,9 +11,9 @@ from typing import TYPE_CHECKING, Any
 
 from sqlspec.storage import storage_registry
 from sqlspec.utils.serializers import from_json as decode_json
+from sqlspec.utils.serializers import schema_dump
 from sqlspec.utils.serializers import to_json as encode_json
 from sqlspec.utils.sync_tools import async_
-from sqlspec.utils.type_guards import schema_dump
 
 if TYPE_CHECKING:
     from sqlspec.typing import SupportedSchemaModel
@@ -38,12 +38,10 @@ def _read_compressed_file(file_path: Path) -> str:
             return f.read()
     elif file_path.suffix == ".zip":
         with zipfile.ZipFile(file_path, "r") as zf:
-            # Assume the JSON file inside has the same name without .zip
             json_name = file_path.stem + ".json"
             if json_name in zf.namelist():
                 with zf.open(json_name) as f:
                     return f.read().decode("utf-8")
-            # If not found, try the first JSON file in the archive
             json_files = [name for name in zf.namelist() if name.endswith(".json")]
             if json_files:
                 with zf.open(json_files[0]) as f:
@@ -70,13 +68,11 @@ def _find_fixture_file(fixtures_path: Any, fixture_name: str) -> Path:
     """
     base_path = Path(fixtures_path)
 
-    # Try different file extensions in order of preference
     for extension in [".json", ".json.gz", ".json.zip"]:
         fixture_path = base_path / f"{fixture_name}{extension}"
         if fixture_path.exists():
             return fixture_path
 
-    # If no file found, raise error
     msg = f"Could not find the {fixture_name} fixture"
     raise FileNotFoundError(msg)
 
@@ -102,7 +98,6 @@ def open_fixture(fixtures_path: Any, fixture_name: str) -> Any:
     if fixture_path.suffix in {".gz", ".zip"}:
         f_data = _read_compressed_file(fixture_path)
     else:
-        # Regular JSON file
         with fixture_path.open(mode="r", encoding="utf-8") as f:
             f_data = f.read()
 
@@ -128,15 +123,12 @@ async def open_fixture_async(fixtures_path: Any, fixture_name: str) -> Any:
     Returns:
         The parsed JSON data
     """
-    # Use sync path finding since it's fast
     fixture_path = _find_fixture_file(fixtures_path, fixture_name)
 
     if fixture_path.suffix in {".gz", ".zip"}:
-        # For compressed files, run in thread pool since they don't have async equivalents
         read_func = async_(_read_compressed_file)
         f_data = await read_func(fixture_path)
     else:
-        # For regular JSON files, use async file reading
         async_read = async_(lambda p: p.read_text(encoding="utf-8"))
         f_data = await async_read(fixture_path)
 
@@ -153,18 +145,18 @@ def _serialize_data(data: Any) -> str:
         JSON string representation of the data
     """
     if isinstance(data, (list, tuple)):
-        # List of models or dicts - convert each item, handling primitives
         serialized_items: list[Any] = []
+
         for item in data:
-            # Use schema_dump for structured data, pass primitives through
             if isinstance(item, (str, int, float, bool, type(None))):
                 serialized_items.append(item)
             else:
                 serialized_items.append(schema_dump(item))
+
         return encode_json(serialized_items)
-    # Single model, dict, or other type - try schema_dump first, fallback for primitives
     if isinstance(data, (str, int, float, bool, type(None))):
         return encode_json(data)
+
     return encode_json(schema_dump(data))
 
 
@@ -189,8 +181,6 @@ def write_fixture(
     Raises:
         ValueError: If storage backend is not found
     """
-    # Get the storage backend using URI-based registration
-    # For "local" backend, use file:// URI with base_path parameter
     if storage_backend == "local":
         uri = "file://"
         storage_kwargs["base_path"] = str(Path(fixtures_path).resolve())
@@ -203,10 +193,8 @@ def write_fixture(
         msg = f"Failed to get storage backend for '{storage_backend}': {exc}"
         raise ValueError(msg) from exc
 
-    # Serialize the data
     json_content = _serialize_data(data)
 
-    # Determine file path and content - use relative path from the base path
     if compress:
         file_path = f"{table_name}.json.gz"
         content = gzip.compress(json_content.encode("utf-8"))
@@ -237,8 +225,6 @@ async def write_fixture_async(
     Raises:
         ValueError: If storage backend is not found
     """
-    # Get the storage backend using URI-based registration
-    # For "local" backend, use file:// URI with base_path parameter
     if storage_backend == "local":
         uri = "file://"
         storage_kwargs["base_path"] = str(Path(fixtures_path).resolve())
@@ -251,14 +237,11 @@ async def write_fixture_async(
         msg = f"Failed to get storage backend for '{storage_backend}': {exc}"
         raise ValueError(msg) from exc
 
-    # Serialize the data in a thread pool since it might be CPU intensive
     serialize_func = async_(_serialize_data)
     json_content = await serialize_func(data)
 
-    # Determine file path and content
     if compress:
         file_path = f"{table_name}.json.gz"
-        # Compress in thread pool since gzip is CPU intensive
         compress_func = async_(lambda content: gzip.compress(content.encode("utf-8")))
         content = await compress_func(json_content)
         await storage.write_bytes_async(file_path, content)
