@@ -8,9 +8,10 @@ for adapter implementations that need to support both sync and async patterns.
 import asyncio
 import functools
 import inspect
+import os
 import sys
 from contextlib import AbstractAsyncContextManager, AbstractContextManager
-from typing import TYPE_CHECKING, Any, Generic, Optional, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Generic, TypeVar, cast
 
 from typing_extensions import ParamSpec
 
@@ -46,13 +47,21 @@ class CapacityLimiter:
             total_tokens: Maximum number of concurrent operations allowed
         """
         self._total_tokens = total_tokens
-        self._semaphore_instance: Optional[asyncio.Semaphore] = None
+        self._semaphore_instance: asyncio.Semaphore | None = None
+        self._pid: int | None = None
 
     @property
     def _semaphore(self) -> asyncio.Semaphore:
-        """Lazy initialization of asyncio.Semaphore for Python 3.9 compatibility."""
-        if self._semaphore_instance is None:
+        """Lazy initialization of asyncio.Semaphore with per-process tracking.
+
+        Reinitializes the semaphore if running in a new process (detected via PID).
+        This ensures pytest-xdist workers each get their own semaphore bound to
+        their event loop, preventing cross-process deadlocks.
+        """
+        current_pid = os.getpid()
+        if self._semaphore_instance is None or self._pid != current_pid:
             self._semaphore_instance = asyncio.Semaphore(self._total_tokens)
+            self._pid = current_pid
         return self._semaphore_instance
 
     async def acquire(self) -> None:
@@ -72,22 +81,20 @@ class CapacityLimiter:
     def total_tokens(self, value: int) -> None:
         self._total_tokens = value
         self._semaphore_instance = None
+        self._pid = None
 
     async def __aenter__(self) -> None:
         """Async context manager entry."""
         await self.acquire()
 
     async def __aexit__(
-        self,
-        exc_type: "Optional[type[BaseException]]",
-        exc_val: "Optional[BaseException]",
-        exc_tb: "Optional[TracebackType]",
+        self, exc_type: "type[BaseException] | None", exc_val: "BaseException | None", exc_tb: "TracebackType | None"
     ) -> None:
         """Async context manager exit."""
         self.release()
 
 
-_default_limiter = CapacityLimiter(15)
+_default_limiter = CapacityLimiter(1000)
 
 
 def run_(async_function: "Callable[ParamSpecT, Coroutine[Any, Any, ReturnT]]") -> "Callable[ParamSpecT, ReturnT]":
@@ -125,14 +132,18 @@ def run_(async_function: "Callable[ParamSpecT, Coroutine[Any, Any, ReturnT]]") -
 
 
 def await_(
-    async_function: "Callable[ParamSpecT, Coroutine[Any, Any, ReturnT]]", raise_sync_error: bool = True
+    async_function: "Callable[ParamSpecT, Coroutine[Any, Any, ReturnT]]", raise_sync_error: bool = False
 ) -> "Callable[ParamSpecT, ReturnT]":
     """Convert an async function to a blocking one, running in the main async loop.
 
+    When no event loop exists, automatically creates and uses a global portal for
+    async-to-sync bridging via background thread. Set raise_sync_error=True to
+    disable this behavior and raise errors instead.
+
     Args:
         async_function: The async function to convert.
-        raise_sync_error: If False, runs in a new event loop if no loop is present.
-                         If True (default), raises RuntimeError if no loop is running.
+        raise_sync_error: If True, raises RuntimeError when no loop exists.
+                         If False (default), uses portal pattern for automatic bridging.
 
     Returns:
         A blocking function that runs the async function.
@@ -147,7 +158,10 @@ def await_(
             if raise_sync_error:
                 msg = "Cannot run async function"
                 raise RuntimeError(msg) from None
-            return asyncio.run(partial_f())
+            from sqlspec.utils.portal import get_global_portal
+
+            portal = get_global_portal()
+            return portal.call(async_function, *args, **kwargs)
         else:
             if loop.is_running():
                 try:
@@ -163,13 +177,16 @@ def await_(
             if raise_sync_error:
                 msg = "Cannot run async function"
                 raise RuntimeError(msg)
-            return asyncio.run(partial_f())
+            from sqlspec.utils.portal import get_global_portal
+
+            portal = get_global_portal()
+            return portal.call(async_function, *args, **kwargs)
 
     return wrapper
 
 
 def async_(
-    function: "Callable[ParamSpecT, ReturnT]", *, limiter: "Optional[CapacityLimiter]" = None
+    function: "Callable[ParamSpecT, ReturnT]", *, limiter: "CapacityLimiter | None" = None
 ) -> "Callable[ParamSpecT, Awaitable[ReturnT]]":
     """Convert a blocking function to an async one using asyncio.to_thread().
 
@@ -192,7 +209,7 @@ def async_(
 
 
 def ensure_async_(
-    function: "Callable[ParamSpecT, Union[Awaitable[ReturnT], ReturnT]]",
+    function: "Callable[ParamSpecT, Awaitable[ReturnT] | ReturnT]",
 ) -> "Callable[ParamSpecT, Awaitable[ReturnT]]":
     """Convert a function to an async one if it is not already.
 
@@ -223,16 +240,13 @@ class _ContextManagerWrapper(Generic[T]):
         return self._cm.__enter__()
 
     async def __aexit__(
-        self,
-        exc_type: "Optional[type[BaseException]]",
-        exc_val: "Optional[BaseException]",
-        exc_tb: "Optional[TracebackType]",
-    ) -> "Optional[bool]":
+        self, exc_type: "type[BaseException] | None", exc_val: "BaseException | None", exc_tb: "TracebackType | None"
+    ) -> "bool | None":
         return self._cm.__exit__(exc_type, exc_val, exc_tb)
 
 
 def with_ensure_async_(
-    obj: "Union[AbstractContextManager[T], AbstractAsyncContextManager[T]]",
+    obj: "AbstractContextManager[T] | AbstractAsyncContextManager[T]",
 ) -> "AbstractAsyncContextManager[T]":
     """Convert a context manager to an async one if it is not already.
 
