@@ -7,9 +7,8 @@ from typing import Any, Literal
 
 import pytest
 
+from sqlspec import SQL, SQLResult, StatementStack
 from sqlspec.adapters.aiosqlite import AiosqliteDriver
-from sqlspec.core.result import SQLResult
-from sqlspec.core.statement import SQL
 
 pytestmark = pytest.mark.xdist_group("sqlite")
 ParamStyle = Literal["tuple_binds", "dict_binds", "named_binds"]
@@ -174,7 +173,7 @@ async def test_aiosqlite_data_types(aiosqlite_session: AiosqliteDriver) -> None:
     """Test SQLite data type handling with aiosqlite."""
 
     await aiosqlite_session.execute_script("""
-        CREATE TABLE data_types_test_unique (
+        CREATE TABLE aiosqlite_data_types_test (
             id INTEGER PRIMARY KEY,
             text_col TEXT,
             integer_col INTEGER,
@@ -187,14 +186,14 @@ async def test_aiosqlite_data_types(aiosqlite_session: AiosqliteDriver) -> None:
     test_data = ("text_value", 42, math.pi, b"binary_data", None)
 
     insert_result = await aiosqlite_session.execute(
-        "INSERT INTO data_types_test_unique (text_col, integer_col, real_col, blob_col, null_col) VALUES (?, ?, ?, ?, ?)",
+        "INSERT INTO aiosqlite_data_types_test (text_col, integer_col, real_col, blob_col, null_col) VALUES (?, ?, ?, ?, ?)",
         test_data,
     )
     assert isinstance(insert_result, SQLResult)
     assert insert_result.rows_affected == 1
 
     select_result = await aiosqlite_session.execute(
-        "SELECT text_col, integer_col, real_col, blob_col, null_col FROM data_types_test_unique"
+        "SELECT text_col, integer_col, real_col, blob_col, null_col FROM aiosqlite_data_types_test"
     )
     assert isinstance(select_result, SQLResult)
     assert select_result.data is not None
@@ -207,7 +206,55 @@ async def test_aiosqlite_data_types(aiosqlite_session: AiosqliteDriver) -> None:
     assert row["blob_col"] == b"binary_data"
     assert row["null_col"] is None
 
-    await aiosqlite_session.execute_script("DROP TABLE data_types_test_unique")
+    await aiosqlite_session.execute_script("DROP TABLE aiosqlite_data_types_test")
+
+
+async def test_aiosqlite_statement_stack_sequential(aiosqlite_session: AiosqliteDriver) -> None:
+    """StatementStack execution should remain sequential for aiosqlite."""
+
+    await aiosqlite_session.execute("DELETE FROM test_table")
+    await aiosqlite_session.commit()
+
+    stack = (
+        StatementStack()
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES (?, ?, ?)", (1, "aiosqlite-stack-one", 100))
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES (?, ?, ?)", (2, "aiosqlite-stack-two", 200))
+        .push_execute("SELECT COUNT(*) AS total FROM test_table WHERE name LIKE ?", ("aiosqlite-stack-%",))
+    )
+
+    results = await aiosqlite_session.execute_stack(stack)
+
+    assert len(results) == 3
+    assert results[0].rows_affected == 1
+    assert results[1].rows_affected == 1
+    assert results[2].result is not None
+    assert results[2].result.data is not None
+    assert results[2].result.data[0]["total"] == 2
+
+
+async def test_aiosqlite_statement_stack_continue_on_error(aiosqlite_session: AiosqliteDriver) -> None:
+    """Sequential execution should continue when continue_on_error is enabled."""
+
+    await aiosqlite_session.execute("DELETE FROM test_table")
+    await aiosqlite_session.commit()
+
+    stack = (
+        StatementStack()
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES (?, ?, ?)", (1, "aiosqlite-initial", 5))
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES (?, ?, ?)", (1, "aiosqlite-duplicate", 15))
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES (?, ?, ?)", (2, "aiosqlite-final", 25))
+    )
+
+    results = await aiosqlite_session.execute_stack(stack, continue_on_error=True)
+
+    assert len(results) == 3
+    assert results[0].rows_affected == 1
+    assert results[1].error is not None
+    assert results[2].rows_affected == 1
+
+    verify = await aiosqlite_session.execute("SELECT COUNT(*) AS total FROM test_table")
+    assert verify.data is not None
+    assert verify.data[0]["total"] == 2
 
 
 async def test_aiosqlite_transactions(aiosqlite_session: AiosqliteDriver) -> None:
@@ -366,7 +413,7 @@ async def test_aiosqlite_sqlite_specific_features(aiosqlite_session: AiosqliteDr
     except Exception:
         pass
 
-    from sqlspec.core.statement import StatementConfig
+    from sqlspec.core import StatementConfig
 
     non_strict_config = StatementConfig(enable_parsing=False, enable_validation=False)
 
