@@ -5,18 +5,14 @@ covering all core functionality including CRUD operations, parameter styles,
 transaction management, and error handling.
 """
 
-from __future__ import annotations
-
 import math
-from collections.abc import AsyncGenerator
 from typing import Literal
 
 import pytest
 from pytest_databases.docker.mysql import MySQLService
 
-from sqlspec.adapters.asyncmy import AsyncmyConfig, AsyncmyDriver, asyncmy_statement_config
-from sqlspec.core.result import SQLResult
-from sqlspec.core.statement import SQL
+from sqlspec import SQL, SQLResult, StatementStack
+from sqlspec.adapters.asyncmy import AsyncmyConfig, AsyncmyDriver
 from sqlspec.utils.serializers import from_json, to_json
 
 ParamStyle = Literal["tuple_binds", "dict_binds", "named_binds"]
@@ -25,7 +21,7 @@ pytestmark = pytest.mark.xdist_group("mysql")
 
 
 @pytest.fixture
-async def asyncmy_driver(asyncmy_session: AsyncmyDriver) -> AsyncmyDriver:
+async def asyncmy_driver(asyncmy_clean_driver: AsyncmyDriver) -> AsyncmyDriver:
     """Create and manage test table lifecycle."""
 
     create_sql = """
@@ -36,30 +32,10 @@ async def asyncmy_driver(asyncmy_session: AsyncmyDriver) -> AsyncmyDriver:
             created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
         )
     """
-    await asyncmy_session.execute_script(create_sql)
+    await asyncmy_clean_driver.execute_script(create_sql)
+    await asyncmy_clean_driver.execute_script("TRUNCATE TABLE test_table")
 
-    await asyncmy_session.execute_script("TRUNCATE TABLE test_table")
-
-    return asyncmy_session
-
-
-@pytest.fixture
-async def asyncmy_session(mysql_service: MySQLService) -> AsyncGenerator[AsyncmyDriver, None]:
-    """Create an asyncmy session with test database."""
-    config = AsyncmyConfig(
-        pool_config={
-            "host": mysql_service.host,
-            "port": mysql_service.port,
-            "user": mysql_service.user,
-            "password": mysql_service.password,
-            "database": mysql_service.db,
-            "autocommit": True,
-        },
-        statement_config=asyncmy_statement_config,
-    )
-
-    async with config.provide_session() as session:
-        yield session
+    return asyncmy_clean_driver
 
 
 async def test_asyncmy_basic_crud(asyncmy_driver: AsyncmyDriver) -> None:
@@ -150,7 +126,7 @@ async def test_asyncmy_data_types(asyncmy_driver: AsyncmyDriver) -> None:
     driver = asyncmy_driver
 
     await driver.execute_script("""
-        CREATE TABLE IF NOT EXISTS data_types_test (
+        CREATE TABLE IF NOT EXISTS asyncmy_data_types_test (
             id INT AUTO_INCREMENT PRIMARY KEY,
             text_col VARCHAR(255),
             int_col INT,
@@ -167,7 +143,7 @@ async def test_asyncmy_data_types(asyncmy_driver: AsyncmyDriver) -> None:
     test_data = ("test_string", 42, math.pi, True, date(2023, 1, 1), datetime(2023, 1, 1, 12, 0, 0), '{"key": "value"}')
 
     result = await driver.execute(
-        """INSERT INTO data_types_test
+        """INSERT INTO asyncmy_data_types_test
            (text_col, int_col, float_col, bool_col, date_col, datetime_col, json_col)
            VALUES (?, ?, ?, ?, ?, ?, ?)""",
         test_data,
@@ -175,7 +151,7 @@ async def test_asyncmy_data_types(asyncmy_driver: AsyncmyDriver) -> None:
     assert result.rows_affected == 1
 
     select_result = await driver.execute(
-        "SELECT * FROM data_types_test WHERE text_col = ? AND int_col = ?", ("test_string", 42)
+        "SELECT * FROM asyncmy_data_types_test WHERE text_col = ? AND int_col = ?", ("test_string", 42)
     )
     assert len(select_result.get_data()) == 1
     row = select_result.get_data()[0]
@@ -187,6 +163,53 @@ async def test_asyncmy_data_types(asyncmy_driver: AsyncmyDriver) -> None:
     assert row["json_col"]["key"] == "value"
 
 
+async def test_asyncmy_statement_stack_sequential(asyncmy_driver: AsyncmyDriver) -> None:
+    """StatementStack should execute sequentially for asyncmy (no native batching)."""
+
+    await asyncmy_driver.execute_script("TRUNCATE TABLE test_table")
+
+    stack = (
+        StatementStack()
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES (?, ?, ?)", (1, "mysql-stack-one", 11))
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES (?, ?, ?)", (2, "mysql-stack-two", 22))
+        .push_execute("SELECT COUNT(*) AS total FROM test_table WHERE name LIKE ?", ("mysql-stack-%",))
+    )
+
+    results = await asyncmy_driver.execute_stack(stack)
+
+    assert len(results) == 3
+    assert results[0].rows_affected == 1
+    assert results[1].rows_affected == 1
+    final_result = results[2].result
+    assert isinstance(final_result, SQLResult)
+    data = final_result.get_data()
+    assert data
+    assert data[0]["total"] == 2
+
+
+async def test_asyncmy_statement_stack_continue_on_error(asyncmy_driver: AsyncmyDriver) -> None:
+    """Continue-on-error should still work with sequential fallback."""
+
+    await asyncmy_driver.execute_script("TRUNCATE TABLE test_table")
+
+    stack = (
+        StatementStack()
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES (?, ?, ?)", (1, "mysql-initial", 5))
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES (?, ?, ?)", (1, "mysql-duplicate", 15))
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES (?, ?, ?)", (2, "mysql-final", 25))
+    )
+
+    results = await asyncmy_driver.execute_stack(stack, continue_on_error=True)
+
+    assert len(results) == 3
+    assert results[0].rows_affected == 1
+    assert results[1].error is not None
+    assert results[2].rows_affected == 1
+
+    verify = await asyncmy_driver.execute("SELECT COUNT(*) AS total FROM test_table WHERE name LIKE ?", ("mysql-%",))
+    assert verify.get_data()[0]["total"] == 2
+
+
 async def test_asyncmy_driver_features_custom_serializers(mysql_service: MySQLService) -> None:
     """Ensure custom serializer and deserializer driver features are applied."""
 
