@@ -1,15 +1,13 @@
 """Integration tests for asyncpg driver implementation."""
 
-from __future__ import annotations
-
 from collections.abc import AsyncGenerator
 from typing import Any, Literal
 
 import pytest
 from pytest_databases.docker.postgres import PostgresService
 
+from sqlspec import SQLResult, StatementStack
 from sqlspec.adapters.asyncpg import AsyncpgConfig, AsyncpgDriver
-from sqlspec.core.result import SQLResult
 
 ParamStyle = Literal["tuple_binds", "dict_binds", "named_binds"]
 
@@ -17,31 +15,24 @@ pytestmark = pytest.mark.xdist_group("postgres")
 
 
 @pytest.fixture
-async def asyncpg_session(postgres_service: PostgresService) -> AsyncGenerator[AsyncpgDriver, None]:
+async def asyncpg_session(asyncpg_async_driver: AsyncpgDriver) -> AsyncGenerator[AsyncpgDriver, None]:
     """Create an asyncpg session with test table."""
-    config = AsyncpgConfig(
-        pool_config={
-            "dsn": f"postgres://{postgres_service.user}:{postgres_service.password}@{postgres_service.host}:{postgres_service.port}/{postgres_service.database}",
-            "min_size": 1,
-            "max_size": 5,
-        }
-    )
 
     try:
-        async with config.provide_session() as session:
-            await session.execute_script("""
+        await asyncpg_async_driver.execute_script(
+            """
                 CREATE TABLE IF NOT EXISTS test_table (
                     id SERIAL PRIMARY KEY,
                     name TEXT NOT NULL,
                     value INTEGER DEFAULT 0,
                     created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
                 )
-            """)
-            yield session
-
-            await session.execute_script("DROP TABLE IF EXISTS test_table")
+            """
+        )
+        await asyncpg_async_driver.execute_script("TRUNCATE TABLE test_table")
+        yield asyncpg_async_driver
     finally:
-        await config.close_pool()
+        await asyncpg_async_driver.execute_script("DROP TABLE IF EXISTS test_table")
 
 
 async def test_asyncpg_basic_crud(asyncpg_session: AsyncpgDriver) -> None:
@@ -205,7 +196,7 @@ async def test_asyncpg_data_types(asyncpg_session: AsyncpgDriver) -> None:
     import uuid
 
     await asyncpg_session.execute_script("""
-        CREATE TABLE data_types_test (
+        CREATE TABLE asyncpg_data_types_test (
             id SERIAL PRIMARY KEY,
             text_col TEXT,
             integer_col INTEGER,
@@ -221,7 +212,7 @@ async def test_asyncpg_data_types(asyncpg_session: AsyncpgDriver) -> None:
 
     await asyncpg_session.execute(
         """
-        INSERT INTO data_types_test (
+        INSERT INTO asyncpg_data_types_test (
             text_col, integer_col, numeric_col, boolean_col, json_col,
             array_col, date_col, timestamp_col, uuid_col
         ) VALUES (
@@ -242,7 +233,7 @@ async def test_asyncpg_data_types(asyncpg_session: AsyncpgDriver) -> None:
     )
 
     select_result = await asyncpg_session.execute(
-        "SELECT text_col, integer_col, numeric_col, boolean_col, json_col, array_col FROM data_types_test"
+        "SELECT text_col, integer_col, numeric_col, boolean_col, json_col, array_col FROM asyncpg_data_types_test"
     )
     assert isinstance(select_result, SQLResult)
     assert select_result is not None
@@ -254,7 +245,7 @@ async def test_asyncpg_data_types(asyncpg_session: AsyncpgDriver) -> None:
     assert row["boolean_col"] is True
     assert row["array_col"] == [1, 2, 3]
 
-    await asyncpg_session.execute_script("DROP TABLE data_types_test")
+    await asyncpg_session.execute_script("DROP TABLE asyncpg_data_types_test")
 
 
 async def test_asyncpg_transactions(asyncpg_session: AsyncpgDriver) -> None:
@@ -658,7 +649,6 @@ async def test_for_update_skip_locked(postgres_service: PostgresService) -> None
     import asyncio
 
     from sqlspec import sql
-    from sqlspec.adapters.asyncpg import AsyncpgConfig
 
     config = AsyncpgConfig(
         pool_config={
@@ -828,3 +818,68 @@ async def test_for_update_of_tables(asyncpg_session: AsyncpgDriver) -> None:
         raise
     finally:
         await asyncpg_session.execute_script("DROP TABLE IF EXISTS test_users")
+
+
+async def test_asyncpg_statement_stack_batch(asyncpg_session: AsyncpgDriver) -> None:
+    """Ensure StatementStack batches operations under asyncpg native path."""
+
+    await asyncpg_session.execute_script("TRUNCATE TABLE test_table RESTART IDENTITY")
+
+    stack = (
+        StatementStack()
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES ($1, $2, $3)", (1, "stack-one", 10))
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES ($1, $2, $3)", (2, "stack-two", 20))
+        .push_execute("SELECT COUNT(*) AS total_rows FROM test_table WHERE name LIKE $1", ("stack-%",))
+    )
+
+    results = await asyncpg_session.execute_stack(stack)
+
+    assert len(results) == 3
+    assert results[0].rows_affected == 1
+    assert results[1].rows_affected == 1
+    assert results[2].result is not None
+    assert results[2].result.data is not None
+    assert results[2].result.data[0]["total_rows"] == 2
+
+
+async def test_asyncpg_statement_stack_continue_on_error(asyncpg_session: AsyncpgDriver) -> None:
+    """Stack execution should surface errors while continuing operations when requested."""
+
+    await asyncpg_session.execute_script("TRUNCATE TABLE test_table RESTART IDENTITY")
+
+    stack = (
+        StatementStack()
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES ($1, $2, $3)", (1, "stack-initial", 5))
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES ($1, $2, $3)", (1, "stack-duplicate", 10))
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES ($1, $2, $3)", (2, "stack-final", 15))
+    )
+
+    results = await asyncpg_session.execute_stack(stack, continue_on_error=True)
+
+    assert len(results) == 3
+    assert results[0].rows_affected == 1
+    assert results[1].error is not None
+    assert results[2].rows_affected == 1
+
+    verify = await asyncpg_session.execute("SELECT COUNT(*) AS total FROM test_table")
+    assert verify.data is not None
+    assert verify.data[0]["total"] == 2
+
+
+async def test_asyncpg_statement_stack_marks_prepared(asyncpg_session: AsyncpgDriver) -> None:
+    """Prepared statement metadata should be attached to stack results."""
+
+    await asyncpg_session.execute_script("TRUNCATE TABLE test_table RESTART IDENTITY")
+
+    stack = (
+        StatementStack()
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES ($1, $2, $3)", (1, "stack-prepared", 50))
+        .push_execute("SELECT value FROM test_table WHERE id = $1", (1,))
+    )
+
+    results = await asyncpg_session.execute_stack(stack)
+
+    assert results[0].metadata is not None
+    assert results[0].metadata.get("prepared_statement") is True
+    assert results[1].metadata is not None
+    assert results[1].metadata.get("prepared_statement") is True
