@@ -3,7 +3,7 @@
 import pytest
 
 from sqlspec.adapters.bigquery import BigQueryConfig
-from sqlspec.core.result import SQLResult
+from sqlspec.core import SQLResult
 
 pytestmark = pytest.mark.xdist_group("bigquery")
 
