@@ -5,8 +5,8 @@ from typing import Any, Literal
 
 import pytest
 
-from sqlspec.adapters.duckdb import DuckDBConfig, DuckDBDriver
-from sqlspec.core.result import SQLResult
+from sqlspec import SQLResult, StatementStack
+from sqlspec.adapters.duckdb import DuckDBDriver
 
 pytestmark = pytest.mark.xdist_group("duckdb")
 
@@ -14,29 +14,24 @@ ParamStyle = Literal["tuple_binds", "dict_binds"]
 
 
 @pytest.fixture
-def duckdb_session() -> Generator[DuckDBDriver, None, None]:
-    """Create a DuckDB session with a test table.
+def duckdb_session(duckdb_basic_session: DuckDBDriver) -> Generator[DuckDBDriver, None, None]:
+    """Create a DuckDB session with a test table."""
+
+    duckdb_basic_session.execute_script("CREATE SEQUENCE IF NOT EXISTS test_id_seq START 1")
+    duckdb_basic_session.execute_script(
+        """
+            CREATE TABLE IF NOT EXISTS test_table (
+                id INTEGER PRIMARY KEY DEFAULT nextval('test_id_seq'),
+                name TEXT NOT NULL
+            )
+        """
+    )
 
-    Returns:
-        A DuckDB session with a test table.
-    """
-    adapter = DuckDBConfig(pool_config={"database": ":memory:"})
     try:
-        with adapter.provide_session() as session:
-            session.execute_script("CREATE SEQUENCE IF NOT EXISTS test_id_seq START 1")
-            create_table_sql = """
-                CREATE TABLE IF NOT EXISTS test_table (
-                    id INTEGER PRIMARY KEY DEFAULT nextval('test_id_seq'),
-                    name TEXT NOT NULL
-                )
-            """
-            session.execute_script(create_table_sql)
-            yield session
-
-            session.execute_script("DROP TABLE IF EXISTS test_table")
-            session.execute_script("DROP SEQUENCE IF EXISTS test_id_seq")
+        yield duckdb_basic_session
     finally:
-        adapter.close_pool()
+        duckdb_basic_session.execute_script("DROP TABLE IF EXISTS test_table")
+        duckdb_basic_session.execute_script("DROP SEQUENCE IF EXISTS test_id_seq")
 
 
 @pytest.mark.parametrize(
@@ -216,7 +211,7 @@ def test_duckdb_data_types(duckdb_session: DuckDBDriver) -> None:
     """Test DuckDB-specific data types and functionality."""
 
     duckdb_session.execute_script("""
-        CREATE TABLE data_types_test (
+        CREATE TABLE duckdb_data_types_test (
             id INTEGER,
             text_col TEXT,
             numeric_col DECIMAL(10,2),
@@ -229,7 +224,7 @@ def test_duckdb_data_types(duckdb_session: DuckDBDriver) -> None:
     """)
 
     insert_sql = """
-        INSERT INTO data_types_test VALUES (
+        INSERT INTO duckdb_data_types_test VALUES (
             1,
             'test_text',
             123.45,
@@ -243,7 +238,7 @@ def test_duckdb_data_types(duckdb_session: DuckDBDriver) -> None:
     result = duckdb_session.execute(insert_sql)
     assert result.rows_affected == 1
 
-    select_result = duckdb_session.execute("SELECT * FROM data_types_test")
+    select_result = duckdb_session.execute("SELECT * FROM duckdb_data_types_test")
     assert len(select_result.data) == 1
     row = select_result.data[0]
 
@@ -254,7 +249,7 @@ def test_duckdb_data_types(duckdb_session: DuckDBDriver) -> None:
     assert row["array_col"] is not None
     assert row["json_col"] is not None
 
-    duckdb_session.execute_script("DROP TABLE data_types_test")
+    duckdb_session.execute_script("DROP TABLE duckdb_data_types_test")
 
 
 def test_duckdb_complex_queries(duckdb_session: DuckDBDriver) -> None:
@@ -608,3 +603,49 @@ def test_duckdb_for_share_locking(duckdb_session: DuckDBDriver) -> None:
         raise
     finally:
         duckdb_session.execute_script("DROP TABLE IF EXISTS test_table")
+
+
+def test_duckdb_statement_stack_sequential(duckdb_session: DuckDBDriver) -> None:
+    """DuckDB drivers should use sequential stack execution."""
+
+    duckdb_session.execute("DELETE FROM test_table")
+
+    stack = (
+        StatementStack()
+        .push_execute("INSERT INTO test_table (id, name) VALUES (?, ?)", (1, "duckdb-stack-one"))
+        .push_execute("INSERT INTO test_table (id, name) VALUES (?, ?)", (2, "duckdb-stack-two"))
+        .push_execute("SELECT COUNT(*) AS total FROM test_table WHERE name LIKE ?", ("duckdb-stack-%",))
+    )
+
+    results = duckdb_session.execute_stack(stack)
+
+    assert len(results) == 3
+    assert results[0].rows_affected == 1
+    assert results[1].rows_affected == 1
+    assert results[2].result is not None
+    assert results[2].result.data is not None
+    assert results[2].result.data[0]["total"] == 2
+
+
+def test_duckdb_statement_stack_continue_on_error(duckdb_session: DuckDBDriver) -> None:
+    """DuckDB sequential stack execution should honor continue-on-error."""
+
+    duckdb_session.execute("DELETE FROM test_table")
+
+    stack = (
+        StatementStack()
+        .push_execute("INSERT INTO test_table (id, name) VALUES (?, ?)", (1, "duckdb-initial"))
+        .push_execute("INSERT INTO test_table (id, name) VALUES (?, ?)", (1, "duckdb-duplicate"))
+        .push_execute("INSERT INTO test_table (id, name) VALUES (?, ?)", (2, "duckdb-final"))
+    )
+
+    results = duckdb_session.execute_stack(stack, continue_on_error=True)
+
+    assert len(results) == 3
+    assert results[0].rows_affected == 1
+    assert results[1].error is not None
+    assert results[2].rows_affected == 1
+
+    verify = duckdb_session.execute("SELECT COUNT(*) AS total FROM test_table")
+    assert verify.data is not None
+    assert verify.data[0]["total"] == 2
