@@ -9,7 +9,7 @@ from uuid import uuid4
 import pytest
 
 from sqlspec.adapters.duckdb import DuckDBConfig, DuckDBDriver
-from sqlspec.core.result import SQLResult
+from sqlspec.core import SQLResult
 
 pytestmark = pytest.mark.xdist_group("duckdb")
 
@@ -174,7 +174,7 @@ def test_duckdb_parameter_with_in_clause(duckdb_parameters_session: DuckDBDriver
 
 def test_duckdb_parameter_with_sql_object(duckdb_parameters_session: DuckDBDriver) -> None:
     """Test parameters with SQL object."""
-    from sqlspec.core.statement import SQL
+    from sqlspec.core import SQL
 
     sql_obj = SQL("SELECT * FROM test_parameters WHERE value > ?", [150])
     result = duckdb_parameters_session.execute(sql_obj)
