@@ -6,9 +6,8 @@ from typing import TYPE_CHECKING, Any, Literal
 
 import pytest
 
+from sqlspec import SQL, SQLResult, StatementStack
 from sqlspec.adapters.psqlpy import PsqlpyDriver
-from sqlspec.core.result import SQLResult
-from sqlspec.core.statement import SQL
 
 if TYPE_CHECKING:
     pass
@@ -200,6 +199,51 @@ async def test_multiple_positional_parameters(psqlpy_session: PsqlpyDriver) -> N
     assert len(mixed_result.data) == 1
 
 
+async def test_psqlpy_statement_stack_sequential(psqlpy_session: PsqlpyDriver) -> None:
+    """psqlpy uses sequential stack execution."""
+
+    await psqlpy_session.execute("DELETE FROM test_table")
+
+    stack = (
+        StatementStack()
+        .push_execute("INSERT INTO test_table (id, name) VALUES (?, ?)", (1, "psqlpy-stack-one"))
+        .push_execute("INSERT INTO test_table (id, name) VALUES (?, ?)", (2, "psqlpy-stack-two"))
+        .push_execute("SELECT COUNT(*) AS total FROM test_table WHERE name LIKE ?", ("psqlpy-stack-%",))
+    )
+
+    results = await psqlpy_session.execute_stack(stack)
+
+    assert len(results) == 3
+
+    verify = await psqlpy_session.execute(
+        "SELECT COUNT(*) AS total FROM test_table WHERE name LIKE ?", ("psqlpy-stack-%",)
+    )
+    assert verify.data is not None
+    assert verify.data[0]["total"] == 2
+
+
+async def test_psqlpy_statement_stack_continue_on_error(psqlpy_session: PsqlpyDriver) -> None:
+    """Sequential stack execution should honor continue-on-error flag."""
+
+    await psqlpy_session.execute("DELETE FROM test_table")
+
+    stack = (
+        StatementStack()
+        .push_execute("INSERT INTO test_table (id, name) VALUES (?, ?)", (1, "psqlpy-initial"))
+        .push_execute("INSERT INTO test_table (id, name) VALUES (?, ?)", (1, "psqlpy-duplicate"))
+        .push_execute("INSERT INTO test_table (id, name) VALUES (?, ?)", (2, "psqlpy-final"))
+    )
+
+    results = await psqlpy_session.execute_stack(stack, continue_on_error=True)
+
+    assert len(results) == 3
+    assert results[1].error is not None
+
+    verify = await psqlpy_session.execute("SELECT COUNT(*) AS total FROM test_table")
+    assert verify.data is not None
+    assert verify.data[0]["total"] == 2
+
+
 async def test_scalar_parameter_handling(psqlpy_session: PsqlpyDriver) -> None:
     """Test handling of scalar parameters in various contexts."""
 
