@@ -1,15 +1,12 @@
 """Integration tests for psycopg driver implementation."""
 
-from __future__ import annotations
-
 from collections.abc import Generator
 from typing import Any, Literal
 
 import pytest
-from pytest_databases.docker.postgres import PostgresService
 
+from sqlspec import SQLResult, StatementStack
 from sqlspec.adapters.psycopg import PsycopgSyncConfig, PsycopgSyncDriver
-from sqlspec.core.result import SQLResult
 
 ParamStyle = Literal["tuple_binds", "dict_binds", "named_binds"]
 
@@ -17,50 +14,44 @@ pytestmark = pytest.mark.xdist_group("postgres")
 
 
 @pytest.fixture
-def psycopg_session(postgres_service: PostgresService) -> Generator[PsycopgSyncDriver, None, None]:
+def psycopg_session(psycopg_sync_config: PsycopgSyncConfig) -> Generator[PsycopgSyncDriver, None, None]:
     """Create a psycopg session with test table."""
-    config = PsycopgSyncConfig(
-        pool_config={
-            "conninfo": f"postgresql://{postgres_service.user}:{postgres_service.password}@{postgres_service.host}:{postgres_service.port}/{postgres_service.database}"
-        }
-    )
 
-    try:
-        with config.provide_session() as session:
-            session.execute_script("""
+    with psycopg_sync_config.provide_session() as session:
+        session.execute_script("DROP TABLE IF EXISTS test_table")
+        session.execute_script(
+            """
                 CREATE TABLE IF NOT EXISTS test_table (
                     id SERIAL PRIMARY KEY,
                     name TEXT NOT NULL,
                     value INTEGER DEFAULT 0,
                     created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
                 )
-            """)
+            """
+        )
 
-            session.commit()
+        session.commit()
+        session.begin()
+        yield session
 
-            session.begin()
-            yield session
+        try:
+            session.rollback()
+        except Exception:
+            pass
 
-            try:
-                session.rollback()
-            except Exception:
-                pass
+        try:
+            session.execute_script("DROP TABLE IF EXISTS test_table")
+        except Exception:
+            if hasattr(session.connection, "rollback"):
+                try:
+                    session.connection.rollback()
+                except Exception:
+                    pass
 
             try:
                 session.execute_script("DROP TABLE IF EXISTS test_table")
             except Exception:
-                if hasattr(session.connection, "rollback"):
-                    try:
-                        session.connection.rollback()
-                    except Exception:
-                        pass
-
-                try:
-                    session.execute_script("DROP TABLE IF EXISTS test_table")
-                except Exception:
-                    pass
-    finally:
-        config.close_pool()
+                pass
 
 
 def test_psycopg_basic_crud(psycopg_session: PsycopgSyncDriver) -> None:
@@ -208,11 +199,60 @@ def test_psycopg_error_handling(psycopg_session: PsycopgSyncDriver) -> None:
         psycopg_session.execute("SELECT nonexistent_column FROM test_table")
 
 
+def test_psycopg_statement_stack_pipeline(psycopg_session: PsycopgSyncDriver) -> None:
+    """StatementStack should leverage psycopg pipeline mode when available."""
+
+    psycopg_session.execute("TRUNCATE TABLE test_table RESTART IDENTITY")
+
+    stack = (
+        StatementStack()
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES (%s, %s, %s)", (1, "sync-stack-one", 5))
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES (%s, %s, %s)", (2, "sync-stack-two", 15))
+        .push_execute("SELECT COUNT(*) AS total FROM test_table WHERE name LIKE %s", ("sync-stack-%",))
+    )
+
+    results = psycopg_session.execute_stack(stack)
+
+    assert len(results) == 3
+    total_result = psycopg_session.execute(
+        "SELECT COUNT(*) AS total FROM test_table WHERE name LIKE %s", "sync-stack-%"
+    )
+    assert total_result.data is not None
+    assert total_result.data[0]["total"] == 2
+
+
+def test_psycopg_statement_stack_continue_on_error(psycopg_session: PsycopgSyncDriver) -> None:
+    """Pipeline execution should continue when instructed to handle errors."""
+
+    psycopg_session.execute("TRUNCATE TABLE test_table RESTART IDENTITY")
+    psycopg_session.commit()
+
+    stack = (
+        StatementStack()
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES (%s, %s, %s)", (1, "sync-initial", 10))
+        .push_execute(  # duplicate PK triggers error
+            "INSERT INTO test_table (id, name, value) VALUES (%s, %s, %s)", (1, "sync-duplicate", 20)
+        )
+        .push_execute("INSERT INTO test_table (id, name, value) VALUES (%s, %s, %s)", (2, "sync-success-final", 30))
+    )
+
+    results = psycopg_session.execute_stack(stack, continue_on_error=True)
+
+    assert len(results) == 3
+    assert results[1].error is not None
+    assert results[0].error is None
+    assert results[2].error is None
+
+    verify = psycopg_session.execute("SELECT COUNT(*) AS total FROM test_table")
+    assert verify.data is not None
+    assert verify.data[0]["total"] == 2
+
+
 def test_psycopg_data_types(psycopg_session: PsycopgSyncDriver) -> None:
     """Test PostgreSQL data type handling with psycopg."""
 
     psycopg_session.execute_script("""
-        CREATE TABLE data_types_test (
+        CREATE TABLE psycopg_data_types_test (
             id SERIAL PRIMARY KEY,
             text_col TEXT,
             integer_col INTEGER,
@@ -228,7 +268,7 @@ def test_psycopg_data_types(psycopg_session: PsycopgSyncDriver) -> None:
 
     psycopg_session.execute(
         """
-        INSERT INTO data_types_test (
+        INSERT INTO psycopg_data_types_test (
             text_col, integer_col, numeric_col, boolean_col, json_col,
             array_col, date_col, timestamp_col, uuid_col
         ) VALUES (
@@ -247,7 +287,7 @@ def test_psycopg_data_types(psycopg_session: PsycopgSyncDriver) -> None:
     )
 
     select_result = psycopg_session.execute(
-        "SELECT text_col, integer_col, numeric_col, boolean_col, json_col, array_col FROM data_types_test"
+        "SELECT text_col, integer_col, numeric_col, boolean_col, json_col, array_col FROM psycopg_data_types_test"
     )
     assert isinstance(select_result, SQLResult)
     assert select_result.data is not None
@@ -259,12 +299,15 @@ def test_psycopg_data_types(psycopg_session: PsycopgSyncDriver) -> None:
     assert row["boolean_col"] is True
     assert row["array_col"] == [1, 2, 3]
 
-    psycopg_session.execute_script("DROP TABLE data_types_test")
+    psycopg_session.execute_script("DROP TABLE psycopg_data_types_test")
 
 
 def test_psycopg_transactions(psycopg_session: PsycopgSyncDriver) -> None:
     """Test transaction behavior."""
 
+    psycopg_session.execute("TRUNCATE TABLE test_table RESTART IDENTITY")
+    psycopg_session.commit()
+
     psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", "transaction_test", 100)
 
     result = psycopg_session.execute("SELECT COUNT(*) as count FROM test_table WHERE name = %s", ("transaction_test"))
@@ -276,6 +319,9 @@ def test_psycopg_transactions(psycopg_session: PsycopgSyncDriver) -> None:
 def test_psycopg_complex_queries(psycopg_session: PsycopgSyncDriver) -> None:
     """Test complex SQL queries."""
 
+    psycopg_session.execute("TRUNCATE TABLE test_table RESTART IDENTITY")
+    psycopg_session.commit()
+
     test_data = [("Alice", 25), ("Bob", 30), ("Charlie", 35), ("Diana", 28)]
 
     psycopg_session.execute_many("INSERT INTO test_table (name, value) VALUES (%s, %s)", test_data)
