@@ -2,13 +2,14 @@
 
 import tempfile
 from pathlib import Path
+from typing import Any
 
 import pytest
 from pytest_databases.docker.postgres import PostgresService
 
 from sqlspec.adapters.psycopg import PsycopgAsyncConfig
 from sqlspec.adapters.psycopg.config import PsycopgSyncConfig
-from sqlspec.migrations.commands import AsyncMigrationCommands, create_migration_commands
+from sqlspec.migrations.commands import AsyncMigrationCommands, SyncMigrationCommands, create_migration_commands
 
 pytestmark = pytest.mark.xdist_group("postgres")
 
@@ -29,7 +30,7 @@ def test_psycopg_sync_migration_full_workflow(postgres_service: PostgresService)
             },
             migration_config={"script_location": str(migration_dir), "version_table_name": migration_table},
         )
-        commands = create_migration_commands(config)
+        commands: SyncMigrationCommands[Any] | AsyncMigrationCommands[Any] = create_migration_commands(config)
 
         commands.init(str(migration_dir), package=True)
 
@@ -192,7 +193,7 @@ def test_psycopg_sync_multiple_migrations_workflow(postgres_service: PostgresSer
             },
             migration_config={"script_location": str(migration_dir), "version_table_name": migration_table},
         )
-        commands = create_migration_commands(config)
+        commands: SyncMigrationCommands[Any] | AsyncMigrationCommands[Any] = create_migration_commands(config)
 
         commands.init(str(migration_dir), package=True)
 
@@ -408,7 +409,7 @@ def test_psycopg_sync_migration_current_command(postgres_service: PostgresServic
             },
             migration_config={"script_location": str(migration_dir), "version_table_name": migration_table},
         )
-        commands = create_migration_commands(config)
+        commands: SyncMigrationCommands[Any] | AsyncMigrationCommands[Any] = create_migration_commands(config)
 
         try:
             commands.init(str(migration_dir), package=True)
@@ -535,7 +536,7 @@ def test_psycopg_sync_migration_error_handling(postgres_service: PostgresService
                 "version_table_name": "sqlspec_migrations_psycopg_sync_error",
             },
         )
-        commands = create_migration_commands(config)
+        commands: SyncMigrationCommands[Any] | AsyncMigrationCommands[Any] = create_migration_commands(config)
 
         try:
             commands.init(str(migration_dir), package=True)
@@ -554,15 +555,15 @@ def down():
 '''
             (migration_dir / "0001_invalid.py").write_text(migration_content)
 
-            with pytest.raises(Exception):
-                commands.upgrade()
+            commands.upgrade()
 
             with config.provide_session() as driver:
                 try:
-                    result = driver.execute("SELECT COUNT(*) as count FROM sqlspec_migrations_psycopg_sync_error")
-                    assert result.data[0]["count"] == 0
-                except Exception:
-                    pass
+                    driver.execute("SELECT version FROM sqlspec_migrations_psycopg_sync_error ORDER BY version")
+                    msg = "Expected migration table to not exist, but it does"
+                    raise AssertionError(msg)
+                except Exception as e:
+                    assert "no such" in str(e).lower() or "does not exist" in str(e).lower()
         finally:
             if config.pool_instance:
                 config.close_pool()
@@ -606,17 +607,15 @@ def down():
 '''
             (migration_dir / "0001_invalid.py").write_text(migration_content)
 
-            with pytest.raises(Exception):
-                await commands.upgrade()
+            await commands.upgrade()
 
             async with config.provide_session() as driver:
                 try:
-                    result = await driver.execute(
-                        "SELECT COUNT(*) as count FROM sqlspec_migrations_psycopg_async_error"
-                    )
-                    assert result.data[0]["count"] == 0
-                except Exception:
-                    pass
+                    await driver.execute("SELECT version FROM sqlspec_migrations_psycopg_async_error ORDER BY version")
+                    msg = "Expected migration table to not exist, but it does"
+                    raise AssertionError(msg)
+                except Exception as e:
+                    assert "no such" in str(e).lower() or "does not exist" in str(e).lower()
         finally:
             if config.pool_instance:
                 import asyncio
@@ -648,7 +647,7 @@ def test_psycopg_sync_migration_with_transactions(postgres_service: PostgresServ
             },
             migration_config={"script_location": str(migration_dir), "version_table_name": migration_table},
         )
-        commands = create_migration_commands(config)
+        commands: SyncMigrationCommands[Any] | AsyncMigrationCommands[Any] = create_migration_commands(config)
 
         try:
             commands.init(str(migration_dir), package=True)
