@@ -3,6 +3,7 @@
 import os
 import sys
 import tempfile
+import uuid
 from collections.abc import Iterator
 from pathlib import Path
 from typing import TYPE_CHECKING
@@ -13,6 +14,8 @@ from click.testing import CliRunner
 
 from sqlspec.cli import add_migration_commands
 
+MODULE_PREFIX = "cli_test_config_"
+
 if TYPE_CHECKING:
     from unittest.mock import Mock
 
@@ -24,12 +27,18 @@ def cleanup_test_modules() -> Iterator[None]:
     yield
     # Remove any test modules that were imported during the test
     modules_after = set(sys.modules.keys())
-    test_modules = {m for m in modules_after - modules_before if m.startswith("test_config")}
+    test_modules = {m for m in modules_after - modules_before if m.startswith(MODULE_PREFIX)}
     for module in test_modules:
         if module in sys.modules:
             del sys.modules[module]
 
 
+def _create_module(content: str, directory: "Path") -> str:
+    module_name = f"{MODULE_PREFIX}{uuid.uuid4().hex}"
+    (directory / f"{module_name}.py").write_text(content)
+    return module_name
+
+
 def test_show_config_command(cleanup_test_modules: None) -> None:
     """Test show-config command displays migration configurations."""
     runner = CliRunner()
@@ -52,9 +61,9 @@ def get_config():
     )
     return config
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
-            result = runner.invoke(add_migration_commands(), ["--config", "test_config.get_config", "show-config"])
+            result = runner.invoke(add_migration_commands(), ["--config", f"{module_name}.get_config", "show-config"])
 
         finally:
             os.chdir(original_dir)
@@ -91,9 +100,9 @@ def get_configs():
 
     return [sqlite_config, duckdb_config]
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
-            result = runner.invoke(add_migration_commands(), ["--config", "test_config.get_configs", "show-config"])
+            result = runner.invoke(add_migration_commands(), ["--config", f"{module_name}.get_configs", "show-config"])
 
         finally:
             os.chdir(original_dir)
@@ -123,9 +132,9 @@ def get_config():
     )
     return config
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
-            result = runner.invoke(add_migration_commands(), ["--config", "test_config.get_config", "show-config"])
+            result = runner.invoke(add_migration_commands(), ["--config", f"{module_name}.get_config", "show-config"])
 
         finally:
             os.chdir(original_dir)
@@ -161,10 +170,10 @@ def get_config():
     )
     return config
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             result = runner.invoke(
-                add_migration_commands(), ["--config", "test_config.get_config", "show-current-revision"]
+                add_migration_commands(), ["--config", f"{module_name}.get_config", "show-current-revision"]
             )
 
         finally:
@@ -198,10 +207,11 @@ def get_config():
     )
     return config
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             result = runner.invoke(
-                add_migration_commands(), ["--config", "test_config.get_config", "show-current-revision", "--verbose"]
+                add_migration_commands(),
+                ["--config", f"{module_name}.get_config", "show-current-revision", "--verbose"],
             )
 
         finally:
@@ -233,10 +243,10 @@ def get_config():
     config.migration_config = {"script_location": "test_migrations"}
     return config
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             result = runner.invoke(
-                add_migration_commands(), ["--config", "test_config.get_config", "init", "--no-prompt"]
+                add_migration_commands(), ["--config", f"{module_name}.get_config", "init", "--no-prompt"]
             )
 
         finally:
@@ -268,11 +278,11 @@ def get_config():
     config.migration_config = {"script_location": "migrations"}
     return config
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             result = runner.invoke(
                 add_migration_commands(),
-                ["--config", "test_config.get_config", "init", "custom_migrations", "--no-prompt"],
+                ["--config", f"{module_name}.get_config", "init", "custom_migrations", "--no-prompt"],
             )
 
         finally:
@@ -304,18 +314,18 @@ def get_config():
     config.migration_config = {"enabled": True}
     return config
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             result = runner.invoke(
                 add_migration_commands(),
-                ["--config", "test_config.get_config", "create-migration", "-m", "test migration", "--no-prompt"],
+                ["--config", f"{module_name}.get_config", "create-migration", "-m", "test migration", "--no-prompt"],
             )
 
         finally:
             os.chdir(original_dir)
 
         assert result.exit_code == 0
-        mock_commands.revision.assert_called_once_with(message="test migration")
+        mock_commands.revision.assert_called_once_with(message="test migration", file_type=None)
 
 
 @patch("sqlspec.migrations.commands.create_migration_commands")
@@ -340,18 +350,108 @@ def get_config():
     config.migration_config = {"enabled": True}
     return config
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             result = runner.invoke(
                 add_migration_commands(),
-                ["--config", "test_config.get_config", "make-migration", "-m", "test migration", "--no-prompt"],
+                ["--config", f"{module_name}.get_config", "make-migration", "-m", "test migration", "--no-prompt"],
             )
 
         finally:
             os.chdir(original_dir)
 
         assert result.exit_code == 0
-        mock_commands.revision.assert_called_once_with(message="test migration")
+        mock_commands.revision.assert_called_once_with(message="test migration", file_type=None)
+
+
+@patch("sqlspec.migrations.commands.create_migration_commands")
+def test_create_migration_command_with_format(mock_create_commands: "Mock", cleanup_test_modules: None) -> None:
+    runner = CliRunner()
+
+    mock_commands = Mock()
+    mock_commands.revision = Mock(return_value=None)
+    mock_create_commands.return_value = mock_commands
+
+    with tempfile.TemporaryDirectory() as temp_dir:
+        original_dir = os.getcwd()
+        os.chdir(temp_dir)
+        try:
+            config_module = """
+from sqlspec.adapters.sqlite.config import SqliteConfig
+
+def get_config():
+    config = SqliteConfig(pool_config={"database": ":memory:"})
+    config.bind_key = "revision_test"
+    config.migration_config = {"enabled": True}
+    return config
+"""
+            module_name = _create_module(config_module, Path(temp_dir))
+
+            result = runner.invoke(
+                add_migration_commands(),
+                [
+                    "--config",
+                    f"{module_name}.get_config",
+                    "create-migration",
+                    "-m",
+                    "test migration",
+                    "--format",
+                    "py",
+                    "--no-prompt",
+                ],
+            )
+
+        finally:
+            os.chdir(original_dir)
+
+        assert result.exit_code == 0
+        mock_commands.revision.assert_called_once_with(message="test migration", file_type="py")
+
+
+@patch("sqlspec.migrations.commands.create_migration_commands")
+def test_create_migration_command_with_file_type_alias(
+    mock_create_commands: "Mock", cleanup_test_modules: None
+) -> None:
+    runner = CliRunner()
+
+    mock_commands = Mock()
+    mock_commands.revision = Mock(return_value=None)
+    mock_create_commands.return_value = mock_commands
+
+    with tempfile.TemporaryDirectory() as temp_dir:
+        original_dir = os.getcwd()
+        os.chdir(temp_dir)
+        try:
+            config_module = """
+from sqlspec.adapters.sqlite.config import SqliteConfig
+
+def get_config():
+    config = SqliteConfig(pool_config={"database": ":memory:"})
+    config.bind_key = "revision_test"
+    config.migration_config = {"enabled": True}
+    return config
+"""
+            module_name = _create_module(config_module, Path(temp_dir))
+
+            result = runner.invoke(
+                add_migration_commands(),
+                [
+                    "--config",
+                    f"{module_name}.get_config",
+                    "create-migration",
+                    "-m",
+                    "test migration",
+                    "--file-type",
+                    "sql",
+                    "--no-prompt",
+                ],
+            )
+
+        finally:
+            os.chdir(original_dir)
+
+        assert result.exit_code == 0
+        mock_commands.revision.assert_called_once_with(message="test migration", file_type="sql")
 
 
 @patch("sqlspec.migrations.commands.create_migration_commands")
@@ -376,10 +476,10 @@ def get_config():
     config.migration_config = {"enabled": True}
     return config
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             result = runner.invoke(
-                add_migration_commands(), ["--config", "test_config.get_config", "upgrade", "--no-prompt"]
+                add_migration_commands(), ["--config", f"{module_name}.get_config", "upgrade", "--no-prompt"]
             )
 
         finally:
@@ -411,10 +511,10 @@ def get_config():
     config.migration_config = {"enabled": True}
     return config
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             result = runner.invoke(
-                add_migration_commands(), ["--config", "test_config.get_config", "upgrade", "abc123", "--no-prompt"]
+                add_migration_commands(), ["--config", f"{module_name}.get_config", "upgrade", "abc123", "--no-prompt"]
             )
 
         finally:
@@ -446,10 +546,10 @@ def get_config():
     config.migration_config = {"enabled": True}
     return config
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             result = runner.invoke(
-                add_migration_commands(), ["--config", "test_config.get_config", "downgrade", "--no-prompt"]
+                add_migration_commands(), ["--config", f"{module_name}.get_config", "downgrade", "--no-prompt"]
             )
 
         finally:
@@ -481,9 +581,11 @@ def get_config():
     config.migration_config = {"enabled": True}
     return config
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
-            result = runner.invoke(add_migration_commands(), ["--config", "test_config.get_config", "stamp", "abc123"])
+            result = runner.invoke(
+                add_migration_commands(), ["--config", f"{module_name}.get_config", "stamp", "abc123"]
+            )
 
         finally:
             os.chdir(original_dir)
@@ -520,11 +622,11 @@ def get_configs():
 
     return [sqlite_config, duckdb_config]
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             result = runner.invoke(
                 add_migration_commands(),
-                ["--config", "test_config.get_configs", "show-current-revision", "--include", "sqlite_multi"],
+                ["--config", f"{module_name}.get_configs", "show-current-revision", "--include", "sqlite_multi"],
             )
 
         finally:
@@ -562,10 +664,10 @@ def get_configs():
 
     return [config1, config2]
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             result = runner.invoke(
-                add_migration_commands(), ["--config", "test_config.get_configs", "upgrade", "--dry-run"]
+                add_migration_commands(), ["--config", f"{module_name}.get_configs", "upgrade", "--dry-run"]
             )
 
         finally:
@@ -595,7 +697,7 @@ def get_config():
     config.migration_config = {"enabled": True}
     return config
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             with patch("sqlspec.migrations.commands.create_migration_commands") as mock_create:
                 mock_commands = Mock()
@@ -604,7 +706,7 @@ def get_config():
 
                 result = runner.invoke(
                     add_migration_commands(),
-                    ["--config", "test_config.get_config", "upgrade", "--execution-mode", "sync", "--no-prompt"],
+                    ["--config", f"{module_name}.get_config", "upgrade", "--execution-mode", "sync", "--no-prompt"],
                 )
 
         finally:
@@ -632,11 +734,11 @@ def get_config():
         migration_config={"enabled": True, "script_location": "migrations"}
     )
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             result = runner.invoke(
                 add_migration_commands(),
-                ["--config", "test_config.get_config", "show-config", "--bind-key", "target_config"],
+                ["--config", f"{module_name}.get_config", "show-config", "--bind-key", "target_config"],
             )
 
         finally:
@@ -679,12 +781,12 @@ def get_configs():
 
     return [sqlite_config, duckdb_config, postgres_config]
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             # Test filtering for sqlite_db only
             result = runner.invoke(
                 add_migration_commands(),
-                ["--config", "test_config.get_configs", "show-config", "--bind-key", "sqlite_db"],
+                ["--config", f"{module_name}.get_configs", "show-config", "--bind-key", "sqlite_db"],
             )
 
         finally:
@@ -718,11 +820,11 @@ def get_configs():
         )
     ]
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             result = runner.invoke(
                 add_migration_commands(),
-                ["--config", "test_config.get_configs", "show-config", "--bind-key", "nonexistent"],
+                ["--config", f"{module_name}.get_configs", "show-config", "--bind-key", "nonexistent"],
             )
 
         finally:
@@ -763,11 +865,18 @@ def get_multi_configs():
         )
     ]
 """
-            Path("test_config.py").write_text(config_module)
+            module_name = _create_module(config_module, Path(temp_dir))
 
             result = runner.invoke(
                 add_migration_commands(),
-                ["--config", "test_config.get_multi_configs", "upgrade", "--bind-key", "analytics_db", "--no-prompt"],
+                [
+                    "--config",
+                    f"{module_name}.get_multi_configs",
+                    "upgrade",
+                    "--bind-key",
+                    "analytics_db",
+                    "--no-prompt",
+                ],
             )
 
         finally:
