@@ -10,13 +10,16 @@ Tests for MigrationRunner core functionality including:
 """
 
 import tempfile
+import time
 from pathlib import Path
 from typing import Any
 from unittest.mock import Mock, patch
 
 import pytest
 
+from sqlspec.migrations import runner as runner_module
 from sqlspec.migrations.base import BaseMigrationRunner
+from sqlspec.migrations.runner import SyncMigrationRunner
 
 pytestmark = pytest.mark.xdist_group("migrations")
 
@@ -101,6 +104,66 @@ def create_migration_runner_with_metadata(migrations_path: Path) -> BaseMigratio
     return TestMigrationRunner(migrations_path)
 
 
+def _write_basic_sql(path: Path, version: str, body: str = "SELECT 1;") -> None:
+    path.write_text(
+        f"""
+-- name: migrate-{version}-up
+{body}
+
+-- name: migrate-{version}-down
+{body}
+""".strip()
+    )
+
+
+def test_load_migration_metadata_uses_cache(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> None:
+    """Ensure metadata caching prevents redundant checksum calculations."""
+
+    file_path = tmp_path / "0001_cached.sql"
+    _write_basic_sql(file_path, "0001")
+    runner = SyncMigrationRunner(tmp_path, {}, None, {})
+
+    checksum_calls = 0
+    original_checksum = runner_module.BaseMigrationRunner._calculate_checksum
+
+    def _tracked_checksum(self: Any, content: str) -> str:
+        nonlocal checksum_calls
+        checksum_calls += 1
+        return original_checksum(self, content)
+
+    monkeypatch.setattr(runner_module.BaseMigrationRunner, "_calculate_checksum", _tracked_checksum)
+
+    runner.load_migration(file_path)
+    runner.load_migration(file_path)
+
+    assert checksum_calls == 1
+
+
+def test_load_migration_metadata_invalidates_on_change(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> None:
+    """Metadata cache invalidates when file content changes."""
+
+    file_path = tmp_path / "0001_mutated.sql"
+    _write_basic_sql(file_path, "0001")
+    runner = SyncMigrationRunner(tmp_path, {}, None, {})
+
+    checksum_calls = 0
+    original_checksum = runner_module.BaseMigrationRunner._calculate_checksum
+
+    def _tracked_checksum(self: Any, content: str) -> str:
+        nonlocal checksum_calls
+        checksum_calls += 1
+        return original_checksum(self, content)
+
+    monkeypatch.setattr(runner_module.BaseMigrationRunner, "_calculate_checksum", _tracked_checksum)
+
+    runner.load_migration(file_path)
+    time.sleep(0.01)
+    _write_basic_sql(file_path, "0001", body="SELECT 2;")
+    runner.load_migration(file_path)
+
+    assert checksum_calls == 2
+
+
 def test_migration_runner_initialization() -> None:
     """Test basic MigrationRunner initialization."""
     migrations_path = Path("/test/migrations")
@@ -211,6 +274,57 @@ DROP TABLE users;
             assert "loader" in metadata
 
 
+def test_load_migration_metadata_prefers_sql_description() -> None:
+    with tempfile.TemporaryDirectory() as temp_dir:
+        migrations_path = Path(temp_dir)
+        migration_file = migrations_path / "0001_custom.sql"
+        migration_file.write_text(
+            """
+-- SQLSpec Migration
+-- Description: Custom summary
+-- Author: Example
+
+-- name: migrate-0001-up
+SELECT 1;
+"""
+        )
+
+        runner = create_migration_runner_with_metadata(migrations_path)
+
+        with (
+            patch.object(type(runner.loader), "clear_cache"),
+            patch.object(type(runner.loader), "load_sql"),
+            patch.object(type(runner.loader), "has_query", return_value=True),
+        ):
+            metadata = runner.load_migration(migration_file)
+
+        assert metadata["description"] == "Custom summary"
+
+
+def test_load_migration_metadata_prefers_python_docstring() -> None:
+    with tempfile.TemporaryDirectory() as temp_dir:
+        migrations_path = Path(temp_dir)
+        migration_file = migrations_path / "0002_feature.py"
+        migration_file.write_text('"""Description: Add feature"""\n\ndef up():\n    return "SELECT 1"\n')
+
+        runner = create_migration_runner_with_metadata(migrations_path)
+
+        with (
+            patch("sqlspec.migrations.base.get_migration_loader") as mock_get_loader,
+            patch("sqlspec.migrations.base.await_") as mock_await,
+        ):
+            mock_loader = Mock()
+            mock_loader.validate_migration_file = Mock()
+            mock_loader.get_up_sql = Mock(return_value=["SELECT 1"])
+            mock_loader.get_down_sql = Mock(return_value=None)
+            mock_get_loader.return_value = mock_loader
+            mock_await.return_value = Mock(return_value=True)
+
+            metadata = runner.load_migration(migration_file)
+
+        assert metadata["description"] == "Add feature"
+
+
 def test_load_migration_metadata_python_file() -> None:
     """Test metadata loading for Python migration files."""
     with tempfile.TemporaryDirectory() as temp_dir:
